#!/usr/bin/env python
#Usage: $0 uni0E01 > code.txt
#or:    $0 --all

import os
import sys
import dfont

# cvt value
#NEW VALUE ***
#    "headdia":          257,    #384
#    "headstem":         258,    #120
#    "w_896":            256,    #896    =ko_kai
cvt_dict = {
#    "w_1001":           71,     #1001   =
    "w_129":            52,     #129
#
    "hstem":            16,     #354
    "hstem_num":        65,     #221
#
    "vstem":            162,    #121    =straight vstem
    "vstem_num":        53,     #152
    "vstem_113":        51,     #113    =curve vstem
#
    "headdia":          31,     #385
    "headhole":         181,    #170   
    "headstem":         9,      #106   
    "headstem_plus_hole":   8,  #272
    "headdia_small":    15,     #348
    "headstem_small":   159,    #98
    "headstem_small_plus_hole":   7,    #246
#
    "vheight":          156,    #1063   =normal height 
    "vheight_shoot":    158,    #1092   =overshoot height
    "vheight_po":       128,    #1556   =po_pla, fo_fa
#    "vheight_o":        179,    #1638   =sara_o, sara_i
    "vheight_lo":       112,    #29 
    "vheight_lu":       23,     #408    =lo_lu
#
    "vheight_below_do": 23,     #408
#
    "vheight_num":    0,    #905
    "special_1":      0,    #905
    "special_2":      0,    #905
    "w_852":      0,    #905
    "w_956":      0,    #905
    "headdia_tiny":      0,    #905
    "sarastem":      0,    #905
    "headstem_wan":      0,    #905
    "vstem_tiny":      0,    #905
    "gap_199":        56,
#    "vheight_sara1":    250,    #1262
#
    "gap_41":         84,     #41     =front/rear spacing
    "gap_61":         27,
    "gap_84":         50,
    "gap_102":        82,
    "gap_129":        52,
    "gap_152":        53,
    "gap_170":        181,
    "gap_190":        40,
    "gap_246":        7, 
    "gap_334":        98,
    "gap_395":        62,
    "gap_428":        37,
}

#SKEL
#hd1: head delta shift, top left
#f_deltap    x 13-8   x 14-8   x 24+8   x 25+8   x 26+8
#f_deltap    x2 17+8   x2 18+8   x2 19+8   x1 27+8  x1 28+8  
#f_deltap    y 17-8   y 23+8   y 24+8   y 25+8  y 26+8  y 27-8  y 39+8   y 40+8   y 41+8
#f_deltap    y1 25+8  y1 26+8   y2 27+8  y2 28+8  y1 42+8  y1 43+8

######### PSUEDO-CODE ##########
pseudo_code_dict = {
    #ko_kai
    "uni0E01": """
#NEW FUNCTION F_DELTAP, 
#DO NOT ENTER NUMBER OF PAIRS AND DEGREE OF DELTA
#JUST TYPE f_deltap NOT f_deltap1 OR deltap1
#FOLLOW BY tt_point_number AND ppem + OR - selector
#f_deltap    24 9+8 
# = MOVE point 24 TO +8 AT 9 ppem
#
f_deltap    24 9+8 
srp0            23
mirp[rp0,rnd,grey]  gap_170 13
mdrp[grey]  15
mdrp[grey]  8
mirp[rp0,min,rnd,grey]  hstem 11
mdrp[grey]  10
#
srp0            24
mirp[rp0,rnd,grey]  gap_170 21
mirp[rp0,min,rnd,grey]  hstem  1
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]           1
alignrp             13
mirp[rp0,rnd,grey]  vheight_shoot 18
ip  15
mirp[min,rnd,grey]  vstem_113  5
mdap[rnd]   15
alignrp     11
mirp[min,rnd,grey]  vstem   8
IUP[y]
""",

    #kho_khai
    "uni0E02":  """
f_deltap    56 9+8  56 10+8  56 11+8  56 12+8  56 13+8   56 32+8   56 33+8  56 38+8
srp0                55
mdrp[rp0,rnd,grey]  17
f_deltap    17 19-8   17 32-8  
mdrp[grey]  14
mirp[min,rnd,grey]  headstem 46
f_deltap    46 28-8  
mirp[rp0,rnd,grey]  headstem_plus_hole 52
f_deltap    52 27+8
mdrp[grey]  23
#
srp0    17
mdrp[rp0,rnd,white] 9
f_deltap    9 32-8
mdrp[grey]  29
f_deltap    29 10+2  29 11+2  29 17+2  29 22-2 29 23-2
mdrp[rp0,rnd,grey]  3
f_deltap    3 19+8
mdrp[grey]  1
mirp[min,rnd,grey]  hstem 34
#
srp0        56
mirp[rp0,rnd,white] gap_170 40
mirp[min,rnd,grey]  hstem 38
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]           0
mirp[min,rnd,grey]  vstem 36
shp[rp2]            3
mirp[rnd,grey]      vheight 40
mirp[rp0,rnd,grey]  vheight_shoot 26
mdrp[min,rnd,grey]  12
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  headstem 49
f_deltap    49 29+8  49 30+8  49 31+8  
mirp[rp0,rnd,grey]  headdia 20
f_deltap    20 9+8   20 10+8   20 13-8     20 14-8     20 15-8     20 16-8    20 20-8  20 26+8  20 27+8   20 34-8  20 40+8  20 41+8
mirp[min,rnd,grey]  headstem 43
f_deltap    43 28+8  
srp1    3
ip  5
ip  33
IUP[y]
""",

    #kho_khuad
    "uni0E03": """
f_deltap    59 9+8 59 10+8 59 16-8  59 19-8   59 21+8
srp0        58
mdrp[rp0,rnd,grey]  18
f_deltap    18 11-8   18 19-8
mdrp[grey]  15
mirp[min,rnd,grey]  headstem 49
f_deltap    49 28-8
mirp[rp0,rnd,grey]  headstem_plus_hole 55
f_deltap    55 27+8   
mdrp[grey]  24
#
srp0    18
mdrp[rp0,rnd,white] 9
f_deltap    9 23-8  9 24-8  9 34-8  
mdrp[grey]  32
srp1    24
sloop   6
ip  27 28 29 11 12 13
f_deltap    32 11+2 
mdrp[rp0,rnd,grey]  3
f_deltap    3 19+8
mdrp[grey]  1
mirp[min,rnd,grey]  hstem 37
#
srp0    59
mirp[rp0,rnd,grey]  gap_170 43
f_deltap    43 32+8  
mirp[min,rnd,grey]  hstem 41
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]           0
mirp[min,rnd,grey]  vstem 39
shp[rp2]    3
mirp[rnd,grey]      vheight 43
mirp[rp0,rnd,grey]  vheight_shoot 27
alignrp     29
mdrp[min,rnd,grey]  13
shp[rp2]    11
mdrp[rp0,min,rnd,grey]  28
mdrp[rp0,min,rnd,grey]  12
mdrp[rp0,rnd,white]     15
f_deltap    15 9+8  15 10+8   15 11+8  15 12+8  15 13+8   15 14+8  15 15+8  15 16+8  15 17+8  15 18+8  15 19+8  
mirp[min,rnd,grey]  headstem 52
mirp[rp0,rnd,grey]  headdia 21
f_deltap    21 9+8   21 10+8   21 13-8     21 14-8     21 15-8     21 16-8    21 20-8  21 26+8  21 27+8   21 29-8  21 30-8  21 31-8  21 34-8  21 40+8  21 41+8
mirp[min,rnd,grey]  headstem 46
f_deltap    46 28+8  
srp2    3
ip  5
ip  36
IUP[y]
""",

    #kho_kwai
    "uni0E04": """
f_deltap    46 9+8    46 10+8   46 11+8   46 16-8   46 17-8   46 18+8   46 21+8   46 22+8   
srp0                45
mirp[rp0,rnd,white] gap_190 23
mdrp[grey]  26
mirp[rp0,min,rnd,grey]  hstem 21
mdrp[grey]  8
ip  10
mdrp[rp0,rnd,grey]  16
f_deltap    16 13+8 16 14+8 16 15+8   16 20+8   16 25+8 16 26+8
mirp[min,rnd,grey]  headstem 36
f_deltap    36 25-4 36 26-4   36 27-4  36 28-4
mirp[rnd,grey]  headstem_plus_hole 42
f_deltap    42 25-4 42 26-4 42 27+4 42 28+4
#
srp0                46
mirp[rp0,rnd,white] gap_170 32
mirp[min,rnd,grey]  hstem 1
f_deltap    8 17-4  8 18-4   8 19-2  8 20-2  8 21-2     8 27-4 10 27-4  8 28-4 10 28-4
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]           0
ALIGNRP             22
MIRP[rp0,rnd,grey]  vheight_shoot  29
MIRP[rp0,min,rnd,grey]  vstem_113  5
mdrp[rp0,rnd,grey]   13
f_deltap    13 16-8   13 38-8   13 39-8   13 40-8  13 41-8   13 42-8   13 43-8  13 44-8
MIRP[min,rnd,grey]  headstem  39
f_deltap    39 25-4 39 26-4  39 27-4   39 28-4
MIRP[rp0,rnd,grey]  headdia  19
f_deltap    19 13-8   19 14-8   19 15-8   19 16-8   19 20-8   19 25-8   19 29-8  19 30-8  19 31-8   19 34-8  19 40+8  19 41+8
MIRP[min,rnd,grey]  headstem  33
f_deltap    33 25+4 33 26+4 33 27+4  33 28+4
mdrp[grey]  10
IUP[y]
""",

    #kho_kon
    "uni0E05": """
f_deltap    50 9+8    50 10+8   50 11+8   50 16-8   50 17-8   50 18+8    50 21+8   50 22+8   
srp0                49
mirp[rp0,rnd,white] gap_190 25
mdrp[grey]  28
mirp[rp0,min,rnd,grey]  hstem 23
mdrp[grey]  10
ip  12
mdrp[rp0,rnd,grey]  18
f_deltap    18 13+8 18 14+8 18 15+8   18 20+8   18 25+8 18 26+8
mirp[min,rnd,grey]  headstem 40
f_deltap    40 25-4 40 26-4   40 27-4  40 28-4
mirp[rnd,grey]  headstem_plus_hole 46
f_deltap    46 25-4 46 26-4 46 27+4 46 28+4
#
srp0                50
mirp[rp0,rnd,white] gap_170 36
mirp[min,rnd,grey]  hstem 1
srp1    10
sloop   6
ip  31 32 33 5 6 7
f_deltap    10 17-4  10 18-4   10 19-2  10 20-2  10 21-2     10 27-4 12 27-4  10 28-4 12 28-4
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]           0
ALIGNRP             24
MIRP[rp0,rnd,grey]  vheight_shoot  31
alignrp 33
MIRP[min,rnd,grey]  vstem_113  7
shp[rp2]    5
mdrp[rp0,min,rnd,grey]  32
mdrp[rp0,min,rnd,grey]  6
mdrp[rp0,min,rnd,white]   15
f_deltap    15 16-8   15 38-8   15 39-8   15 40-8  15 41-8   15 42-8   15 43-8  15 44-8
MIRP[min,rnd,grey]  headstem  43
f_deltap    43 25-4 43 26-4  43 27-4   43 28-4
MIRP[rp0,rnd,grey]  headdia  21
f_deltap    21 13-8   21 14-8   21 15-8   21 16-8   21 20-8   21 25-8   21 29-8  21 30-8  21 31-8   21 34-8  21 40+8  21 41+8
MIRP[min,rnd,grey]  headstem  37
f_deltap    37 25+4 37 26+4 37 27+4  37 28+4
mdrp[grey]  12
IUP[y]
""",

    #kho_rakhang
    "uni0E06": """
f_deltap    80 9+8   80 14-8   80 15-8   80 21+8 
srp0        79
mdrp[rp0,rnd,grey]  27
f_deltap    27 11-8  
mdrp[grey]  24
mirp[min,rnd,grey]  headstem 58
f_deltap    58 28-8
mirp[rp0,rnd,grey]  headstem_plus_hole 64
f_deltap    64 27+8   
mdrp[grey]  33
#
srp0    27
mdrp[rp0,rnd,white] 18
f_deltap    18 23-8  18 24-8  18 34-8  
mdrp[grey]  41
srp1    33
sloop   6
ip  36 37 38 20 21 22
f_deltap    41 11+2 
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  hstem 44
shp[rp2]    3
mdrp[rp0,rnd,grey]  9
mirp[min,rnd,grey]  headstem 76
mirp[rnd,grey]  headstem_plus_hole 70
#
srp0    80
mirp[rp0,rnd,grey]  gap_170 52
f_deltap    52 32+8  
mirp[min,rnd,grey]  hstem 50
mdrp[grey]  47
mdrp[grey]  1
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]           0
alignrp     6
mirp[min,rnd,grey]  vstem 47
mirp[rnd,grey]      vheight 52
mirp[rp0,rnd,grey]  vheight_shoot 36
alignrp     38
mdrp[min,rnd,grey]  22
shp[rp2]    20
mdrp[rp0,min,rnd,grey]  37
mdrp[rp0,min,rnd,grey]  21
mdrp[rp0,rnd,white]     24
f_deltap    24 9+8  24 10+8   24 11+8  24 12+8  24 13+8   24 14+8  24 15+8  24 16+8  24 17+8  24 18+8  24 19+8  
mirp[min,rnd,grey]  headstem 61
mirp[rp0,rnd,grey]  headdia 30
f_deltap    30 9+8   30 10+8   30 13-8     30 14-8     30 15-8     30 16-8    30 20-8  30 26+8  30 27+8   30 29-8  30 30-8  30 31-8  30 34-8  30 40+8  30 41+8
mirp[min,rnd,grey]  headstem 55
f_deltap    55 28+8  
srp2    6
ip  16
ip  43
#
srp0    6
mdrp[rp0,rnd,grey]  12
ip  45
ip  3
mirp[min,rnd,grey]  headstem 73
mirp[rnd,grey]  headstem_plus_hole 67
IUP[y]
""",

    #ngo_ngu
    "uni0E07": """
f_deltap    35 9+8
srp0    34
mdrp[rp0,grey]  2
mdrp[grey]  3
#
srp0    35
mirp[rp0,rnd,white]  gap_170 19
mdrp[grey]  4
mirp[rp0,min,rnd,grey]  hstem 7
mdrp[grey]  1
mdrp[rp0,rnd,grey]  13
f_deltap    13 13-8   13 14-8   13 24+8
mirp[min,rnd,grey]  headstem 31
f_deltap    31 25+4 31 26+4 31 27+4   31 28+4  
mirp[rnd,grey]  headstem_plus_hole 25
f_deltap    25 25+4 25 26+4 25 27-4 25 28-4
#
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
mirp[min,rnd,grey]  vstem 4
mirp[rp0,rnd,grey]  vheight 16
mdrp[rp0,rnd,grey]  10
f_deltap    10 18+8 10 19+8  10 23+8 10 24+8   10 28+8   10 39+8 10 40+8 10 41+8  
mirp[min,rnd,grey]  headstem 22
f_deltap    22 25+4 22 26+4 22 27+4   22 28+4
mirp[min,rnd,grey]  headstem_plus_hole 28
f_deltap     28 25+4  28 26+4 28 27-4  28 28-4
srp2    1
ip      3
ip      2
IUP[y]
""",

    #jo_jan
    "uni0E08": """
f_deltap    50 9+8   50 10+8   50 11+8   50 16-8   50 17-8   50 18+8   
srp0    49
mirp[rp0,rnd,grey] gap_334 2
f_deltap    2 13+8   2 14+8   2 15+8   
mirp[min,rnd,grey]  hstem 14
mdrp[rp0,rnd,grey]  8
f_deltap    8 13-8   8 14-8   8 24+8   8 27+8
mdrp[grey]  27
mirp[min,rnd,grey]  headstem 46
f_deltap    46 25+4 46 26+4 46 27+4   46 28+4
mirp[rnd,grey]  headstem_plus_hole 40
f_deltap    40 25+4 40 26+4 40 27-4 40 28-4
#

srp0    50
mirp[rp0,rnd,grey]  gap_170 34
mirp[min,rnd,grey]  hstem 19
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  0
mirp[min,rnd,grey]  vstem 17
mirp[rp0,rnd,grey]  vheight_shoot 31
mdrp[grey]  28
mirp[rp0,min,rnd,grey]  vstem_113 23
mdrp[rp0,grey]  27
mdrp[rp0,rnd,white] 11
mdap[rnd]   11
f_deltap    11 11-1  11 12-1  11 23-8   11 24-8   11 25-8   11 28+8   11 29+8   11 30+8   11 31+8   11 32+8   11 33+8   11 35+8   11 38-8   11 39-8   11 40-8   11 41-8
mdrp[rp0,rnd,grey]  5
f_deltap    5 18+8 5 19+8   5 23+8 5 24+8   5 28+8   5 39+8 5 40+8 5 41+8
mirp[min,rnd,grey]  headstem 37
f_deltap    37 25+4 37 26+4 37 27+4   37 28+4
mirp[rnd,grey]  headstem_plus_hole 43
f_deltap    43 25+4  43 26+4 43 27-4 43 28-4
IUP[y]
""",


    #cho_ching
    "uni0E09": """
f_deltap    69 9+8   69 10+8   69 13+8   69 22+8   69 28+8
srp0    68
mirp[rp0,rnd,grey] gap_334 1
f_deltap    1 13+8   1 14+8   1 15+8
mirp[min,rnd,grey]  hstem 13
shp[rp2]    0
mdrp[rp0,rnd,grey]  7
f_deltap    7 13-8   7 14-8   7 24+8   7 27+8
mdrp[grey]  24
mirp[min,rnd,grey]  headstem 53
f_deltap    53 25+4 53 26+4 53 27+4   53 28+4
mirp[rnd,grey]  headstem_plus_hole 47
f_deltap    47 25+4 47 26+4 47 27-4 47 28-4
#
srp0    69
mirp[rp0,rnd,grey]  gap_190 31
mirp[min,rnd,grey]  hstem 16
shp[rp2]    42
mdrp[rp0,rnd,grey]  36
mirp[min,rnd,grey]  headstem 59
mirp[rnd,grey]  headstem_plus_hole 65
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp     39
mdrp[grey]  14
mirp[rp0,rnd,grey]  vheight_shoot  28
mdrp[grey]  25
mirp[rp0,min,rnd,grey]  vstem_113 20
mdrp[rp0,grey]  24
mdrp[rp0,rnd,white]  10
mdap[rnd]   10
mdrp[rp0,rnd,grey]  4
f_deltap    4 18+8 4 19+8   4 23+8 4 24+8   4 28+8   4 39+8 4 40+8 4 41+8
mirp[min,rnd,grey]  headstem 44
f_deltap    44 25+4 44 26+4 44 27+4   44 28+4
mirp[rnd,grey]  headstem_plus_hole 50
f_deltap    50 25+4  50 26+4 50 27-4 50 28-4
#
srp0    39
mdrp[min,rnd,grey]  56
mdrp[rp0,rnd,grey]  33
ip      16
ip      42
mirp[min,rnd,grey]  headstem 62
IUP[y]
""",

    #cho_chang
    "uni0E0A": """
f_deltap    70 9+8  70 10+8  70 11+8  
srp0                69
mdrp[rp0,rnd,grey]  17
f_deltap    17 19-8  17 32-8  
mdrp[grey]  14
mirp[min,rnd,grey]  headstem 60
f_deltap    60 28-8  
mirp[rp0,rnd,grey]  headstem_plus_hole 66
f_deltap    66 27+8
mdrp[grey]  23
#
srp0    17
mdrp[rp0,rnd,white] 9
f_deltap    9 27+8   9 32-8   
mdrp[grey]  29
f_deltap    29 10+2  29 11+2  29 17+2  29 22-2 29 23-2
shp[rp2]    50
mdrp[rp0,rnd,grey]  3
f_deltap    3 19+8
mdrp[grey]  1
mirp[min,rnd,grey]  hstem 55
#
srp0        70
mirp[rp0,rnd,white] gap_170 39
mirp[min,rnd,grey]  hstem 46
srp2    29
ip  36
mdrp[rp0,grey]  33
mdrp[grey]  32
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]           0
mirp[min,rnd,grey]  vstem 43
shp[rp2]            3
mirp[rp0,rnd,grey]  vheight_shoot 26
sloop   3
ip  29 36 50
mdrp[min,rnd,grey]  32
mdrp[min,rnd,grey]  12
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  headstem 63
f_deltap    63 29+8  63 30+8  63 31+8  
mirp[rp0,rnd,grey]  headdia 20
f_deltap    20 9+8   20 10+8   20 13-8     20 14-8     20 15-8     20 16-8    20 20-8  20 26+8  20 27+8   20 34-8  20 40+8  20 41+8
mirp[min,rnd,grey]  headstem 57
f_deltap    57 28+8  
srp1    3
ip  5
ip  54
IUP[y]
""",

    #so_zo
    "uni0E0B": """
f_deltap    73 9+8 73 17-8  73 18-8 73 17+8 73 18+8 73 19-8  73 21+8
srp0        72
mdrp[rp0,rnd,grey]  18
f_deltap    18 11-8  18 19-8
mdrp[grey]  15
mirp[min,rnd,grey]  headstem 63
f_deltap    63 28-8
mirp[rp0,rnd,grey]  headstem_plus_hole 69
f_deltap    69 27+8   
mdrp[grey]  24
#
srp0    18
mdrp[rp0,rnd,white] 9
f_deltap    9 23-8  9 24-8  9 34-8  
mdrp[grey]  32
f_deltap    32 11+2 
shp[rp2]    53
mdrp[rp0,rnd,grey]  3
f_deltap    3 19+8
mdrp[grey]  1
mirp[min,rnd,grey]  hstem 58
#
srp0    73
mirp[rp0,rnd,grey]  gap_170 42
f_deltap    42 32+8  
mirp[min,rnd,grey]  hstem 49
srp2    32
ip  39
mdrp[rp0,grey]  36
mdrp[grey]  35
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]           0
mirp[min,rnd,grey]  vstem 46
shp[rp2]    3
mirp[rp0,rnd,grey]  vheight_shoot 27
alignrp     29
sloop   3
ip  32 39 53
mdrp[min,rnd,grey]  35
mdrp[min,rnd,grey]  13
shp[rp2]    11
mdrp[rp0,min,rnd,grey]  28
mdrp[rp0,min,rnd,grey]  12
mdrp[rp0,rnd,white]     15
f_deltap    15 9+8  15 10+8   15 11+8  15 12+8  15 13+8   15 14+8  15 15+8  15 16+8  15 17+8  15 18+8  15 19+8  
mirp[min,rnd,grey]  headstem 66
mirp[rp0,rnd,grey]  headdia 21
f_deltap    21 9+8   21 10+8   21 13-8     21 14-8     21 15-8     21 16-8    21 20-8  21 26+8  21 27+8   21 29-8  21 30-8  21 31-8  21 34-8  21 40+8  21 41+8
mirp[min,rnd,grey]  headstem 60
f_deltap    60 28+8  
srp2    3
ip  5
ip  57
IUP[y]
""",

    #cho_choe
    "uni0E0C": """
f_deltap    71 9+8   71 16-8   
srp0    78
mirp[rp0,rnd,grey] gap_170 35
mdrp[grey]   37
mdrp[grey]   20
mirp[rp0,min,rnd,grey]  hstem 23
mdrp[grey]   21
mdrp[rp0,rnd,grey]  29
f_deltap    29 14+8   29 27-8  
mirp[min,rnd,grey]  headstem 57
f_deltap    57 24-4 57 25-4 57 26-4 57 27-4 57 28-4
mirp[rnd,grey]  headstem_plus_hole 63
f_deltap    63 24-4 63 25-4 63 26-4 63 27+4 63 28+4
#
srp0    79
mirp[rp0,rnd,grey]  gap_170 51
mirp[min,rnd,grey]  hstem 49
srp1    35
ip  13
mdap[rnd]   13
mirp[min,rnd,grey]  hstem 43
shp[rp2]    3
srp1    49
ip  1
ip  46
srp1    29
ip  9
mdap[rnd]   9
mirp[min,rnd,grey]  headstem 75
f_deltap    75 24+4 75 25+4 75 26+4 75 27+4 75 28+4
mirp[rnd,grey]  headstem_plus_hole 69
f_deltap    69 24+4 69 25+4 69 26+4 69 27-4 69 28-4 
f_deltap    3 18+4
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  0
alignrp 6
alignrp 32
mirp[rnd,grey]  vheight 51
mirp[min,rnd,grey]  vstem 46
mirp[rp0,rnd,grey]  vheight_shoot 40
ip  37
mirp[min,rnd,grey]  vstem_113 17
srp0    6
mdrp[rp0,rnd,grey]  12
f_deltap    12 18-8 12 19-8   12 39-8   12 40-8   12 41-8
alignrp 26
ip  44
ip  3
mirp[min,rnd,grey]  headstem 72
f_deltap    72 24-4  72 25-4 72 26-4 72 27-4 72 28-4
shp[rp2]    60
mirp[rnd,grey]  headstem_plus_hole 66
f_deltap    66 24-4 66 25-4 66 26-4  66 27+4 66 28+4
shp[rp2]    54
#
mdap[rnd]   37
alignrp 23
mirp[min,rnd,grey]  vstem 20
IUP[y]
""",

    #yo_ying
    "uni0E0D": """
f_deltap    89 9+8  89 10+8  89 22+8  89 27+8
srp0    88
mirp[rp0,rnd,grey]  gap_190 24
mdrp[grey]  26
mdrp[grey]  9
mirp[rp0,min,rnd,grey]  hstem 12
mdrp[min,rnd,grey]  10
mdrp[rp0,rnd,grey]  18
f_deltap    18 13+8   18 14+8   
mirp[min,rnd,grey]  headstem 45
f_deltap    45 25-4 45 26-4 45 27-4   45 28-4
mirp[rnd,grey]  headstem_plus_hole 51
f_deltap    51 25-4 51 26-4 51 27+4  51 28+4
#
srp0    89
mirp[rp0,rnd,grey]  gap_170 39
mirp[min,rnd,grey]  hstem 37
srp1    24
ip  2
mdap[rnd]   2
mirp[min,rnd,grey]  hstem 32
#
srp2    41
ip  57
ip  73
mdap[rnd]   57
f_deltap    57 13-8   57 14-8  57 15-8  57 16-8
mdrp[min,rnd,grey]  67
mdrp[min,rnd,grey]  85
mdrp[rp0,rnd,grey]  63
mdrp[min,rnd,grey]  79
mdap[rnd]   73
mdrp[min,rnd,grey]  72
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp     21
mirp[min,rnd,grey]  vstem 35
mirp[rnd,grey]  vheight 39
mirp[rp0,rnd,grey]  vheight_shoot 29
ip          26
mirp[min,rnd,grey]  vstem_113 6
srp0        21
mdrp[rp0,rnd,grey] 15
f_deltap    15 18-8 15 19-8   15 23-8 15 24-8  15 28-8   15 39-8 15 40-8 15 41-8
mirp[min,rnd,grey] headstem 48
f_deltap    48 25-4 48 26-4 48 27-4   48 28-4
mirp[rnd,grey] headstem_plus_hole 42
f_deltap    42 25-4  42 26-4 42 27+4  42 28+4
mdap[rnd]   26
alignrp     12
mdrp[min,rnd,grey]  9
#
srp0        0
mdrp[rp0,rnd,white] 60
mdrp[grey]  73
mdrp[min,rnd,grey]  82
mdrp[rp0,grey]  54
mdrp[grey]  76
mdrp[grey]  69
IUP[y]
""",

    #yo_ying
    "uni0E0D.descless": """
f_deltap    55 9+8  55 10+8  55 22+8  55 27+8
srp0    54
mirp[rp0,rnd,grey]  gap_190 24
mdrp[grey]  26
mdrp[grey]  9
mirp[rp0,min,rnd,grey]  hstem 12
mdrp[min,rnd,grey]  10
mdrp[rp0,rnd,grey]  18
f_deltap    18 13+8   18 14+8
mirp[min,rnd,grey]  headstem 45
f_deltap    45 25-4 45 26-4 45 27-4   45 28-4
mirp[rnd,grey]  headstem_plus_hole 51
f_deltap    51 25-4 51 26-4 51 27+4  51 28+4
#
srp0    55
mirp[rp0,rnd,grey]  gap_170 39
mirp[min,rnd,grey]  hstem 37
srp1    24
ip  2
mdap[rnd]   2
mirp[min,rnd,grey]  hstem 32
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp     21
mirp[min,rnd,grey]  vstem 35
mirp[rnd,grey]  vheight 39
mirp[rp0,rnd,grey]  vheight_shoot 29
ip          26
mirp[min,rnd,grey]  vstem_113 6
srp0        21
mdrp[rp0,rnd,grey] 15
f_deltap    15 18-8 15 19-8   15 23-8 15 24-8  15 28-8   15 39-8 15 40-8 15 41-8
mirp[min,rnd,grey] headstem 48
f_deltap    48 25-4 48 26-4 48 27-4   48 28-4
mirp[rnd,grey] headstem_plus_hole 42
f_deltap    42 25-4  42 26-4 42 27+4  42 28+4
mdap[rnd]   26
alignrp     12
mdrp[min,rnd,grey]  9
IUP[y]
""",

    #do_chada
    "uni0E0E": """
f_deltap    83 9+8   83 10+8   83 15-8   83 16-8   83 30-8
srp0    82
mirp[rp0,rnd,grey]  gap_334 47
mdrp[grey]  49
mdrp[grey]  32
mirp[rp0,min,rnd,grey]  hstem 35
mdrp[grey]  33
srp0    47
mdrp[rp0,rnd,grey]  42
f_deltap    42 13-8   42 14-8
mirp[min,rnd,grey]  headstem 67
f_deltap    67 25+4 67 26+4 67 27+4   67 28+4
mirp[rnd,grey]  headstem_plus_hole 61
f_deltap    61 25+4 61 26+4 61 27-4  61 28-4
mdap[rnd]   9
mdrp[min,rnd,grey]  79
#
srp0    83
mirp[rp0,rnd,grey]  gap_170 55
mirp[min,rnd,grey]  hstem 25
mdrp[rp0,rnd,grey]  9
mdrp[min,rnd,grey]  79
srp1    25
sloop   8
ip  73 15 17 18 20 22 1 3
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   39
mirp[rp0,rnd,grey]  vheight_shoot 52
ip  49
mirp[min,rnd,grey]  vstem_113   29
mdap[rnd]   49
alignrp 35
mirp[min,rnd,grey]  vstem 32
srp0    39
mdrp[rp0,rnd,grey]  45
f_deltap    45 18-8 45 19-8   45 23-8 45 24-8 45 28-8  45 39-8 45 40-8 45 41-8
mirp[min,rnd,grey]  headstem 64
f_deltap    64 25-4 64 26-4 64 27-4   64 28-4
mirp[rnd,grey]  headstem_plus_hole 58
f_deltap    58 25-4  58 26-4 58 27+4  58 28+4
#
srp0    39
mdrp[rp0,min,rnd,white] 12
mirp[min,rnd,grey]  headstem   76
mdrp[rp0,rnd,grey]  6
sloop   6
ip  15 17 18 20 73 3
shp[rp2]    0
mirp[min,rnd,grey]  headstem   70
shp[rp2]    22
f_deltap    12 13+6   76 13+6
IUP[y]
""",

    #to_patak
    "uni0E0F": """
f_deltap    89 9+8   89 10+8   89 15-8   89 16-8   89 30-8
srp0    88
mirp[rp0,rnd,grey]  gap_334 53
mdrp[grey]  55
mdrp[grey]  38
mirp[rp0,min,rnd,grey]  hstem 41
mdrp[grey]  39
srp0    53
mdrp[rp0,rnd,grey]  48
f_deltap    48 13-8   48 14-8
mirp[min,rnd,grey]  headstem 73
f_deltap    73 25+4 73 26+4 73 27+4   73 28+4
mirp[rnd,grey]  headstem_plus_hole 67
f_deltap    67 25+4 67 26+4 67 27-4  67 28-4
#
srp0    89
mirp[rp0,rnd,grey]  gap_170 61
mirp[min,rnd,grey]  hstem 31
mdrp[rp0,rnd,grey]  12
mdrp[min,rnd,grey]  85
srp1    31
sloop   14
ip  79 18 20 21 23 25 26 27 28 1 2 3 4 6
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   45
mirp[rp0,rnd,grey]  vheight_shoot 58
ip  55
mirp[min,rnd,grey]  vstem_113   35
mdap[rnd]   55
alignrp 41
mirp[min,rnd,grey]  vstem 38
srp0    45
mdrp[rp0,rnd,grey]  51
f_deltap    51 18-8 51 19-8   51 23-8 51 24-8   51 28-8   51 39-8 51 40-8 51 41-8
mirp[min,rnd,grey]  headstem 70
f_deltap    70 25-4 70 26-4 70 27-4   70 28-4
mirp[rnd,grey]  headstem_plus_hole 64
f_deltap    64 25-4  64 26-4 64 27+4  64 28+4
#
srp0    45
mdrp[rp0,min,rnd,white] 15
mirp[min,rnd,grey]  headstem   82
mdrp[rp0,min,rnd,grey]  9
sloop   6
ip  79 18 20 21 23 26
alignrp     4
alignrp     1
mirp[min,rnd,grey]  headstem   76
sloop   4
shp[rp2]    6 25 2 28
f_deltap    15 13+6   82 13+6
IUP[y]
""",

    #tho_than
    "uni0E10": """
f_deltap    126 9+8   126 10+8   126 11+8   126 14-8    126 15-8   126 18+8   126 21+8   
srp0        125
mirp[rp0,rnd,grey]  gap_334 2
mirp[min,rnd,grey]  hstem 14
mdrp[rp0,rnd,grey]  8
f_deltap    8 13-8   8 14-8   8 24+8   8 27+8
mirp[min,rnd,grey]  headstem  55
f_deltap    55 25+4 55 26+4 55 27+4   55 28+4
mirp[rnd,grey]  headstem_plus_hole 49
f_deltap    49 25+4 49 26+4 49 27-4  49 28-4
mdrp[grey]  21
mdrp[grey]  42
srp0    21
mdrp[rp0,rnd,grey]  38
#
srp0        126
mirp[rp0,rnd,white] gap_170 43
alignrp     102
mirp[min,rnd,grey]  hstem 19
mdrp[rp0,grey]  32
mdrp[grey]  31
#
srp0        102
mdrp[min,rnd,grey]  116
mdrp[rp0,rnd,grey]  96
mdrp[min,rnd,grey]  122
srp0        102
mdrp[min,rnd,grey]  90
mdrp[rp0,rnd,grey]  71
mdrp[min,rnd,grey]  111
srp1        90
sloop       11
ip  107 76 78 79 81 88 87 59 63 64 66
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mirp[min,rnd,grey]  vstem 17
mirp[rp0,rnd,grey]  vheight_shoot   24
alignrp     31
mdrp[grey]  29
mirp[rp0,min,rnd,grey]  vstem_113 39
mdrp[grey]  34
srp0    24
mdrp[rp0,grey]  21
mdrp[grey]      20
mdrp[rp0,grey]  42
mdrp[grey]      43
#
srp0    21
mdrp[rp0,rnd,white] 11
mdap[rnd]   11
f_deltap    11 17-8 11 18-8 11 19-8
mdrp[rp0,rnd,grey]  5
f_deltap    5 18+8 5 19+8   5 23+8 5 24+8   5 28+8   5 39+8 5 40+8 5 41+8
mirp[min,rnd,grey]  headstem 46
f_deltap    46 25+4 46 26+4 46 27+4   46 28+4
mirp[rnd,grey]  headstem_plus_hole 52
f_deltap    52 25+4  52 26+4 52 27-4 52 28-4
#
srp0    0
mdrp[rp0,min,rnd,white]  99
mdrp[rp0,rnd,grey]  93
ip  119
ip  113
mdrp[rp0,rnd,grey]  58
alignrp 64
alignrp 68
mdrp[grey]  87
sloop   3
shp[rp2]    66 83 61
#
srp0    68
mdrp[min,rnd,grey]  74
ip  109
ip  105
sloop   6
ip  107 76 78 79 81 85
IUP[y]
""",

    #tho_than_descless
    "uni0E10.descless": """
f_deltap    59 9+8   59 10+8   59 11+8   59 14-8    59 15-8   59 18+8   59 21+8
srp0        58
mirp[rp0,rnd,grey]  gap_334 2
mirp[min,rnd,grey]  hstem 14
mdrp[rp0,rnd,grey]  8
f_deltap    8 13-8   8 14-8   8 24+8   8 27+8
mirp[min,rnd,grey]  headstem  55
f_deltap    55 25+4 55 26+4 55 27+4   55 28+4
mirp[rnd,grey]  headstem_plus_hole 49
f_deltap    49 25+4 49 26+4 49 27-4  49 28-4
mdrp[grey]  21
mdrp[grey]  42
srp0    21
mdrp[rp0,rnd,grey]  38
#
srp0        59
mirp[rp0,rnd,white] gap_170 43
mirp[min,rnd,grey]  hstem 19
mdrp[rp0,grey]  32
mdrp[grey]  31
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mirp[min,rnd,grey]  vstem 17
mirp[rp0,rnd,grey]  vheight_shoot   24
alignrp     31
mdrp[grey]  29
mirp[rp0,min,rnd,grey]  vstem_113 39
mdrp[grey]  34
srp0    24
mdrp[rp0,grey]  21
mdrp[grey]      20
mdrp[rp0,grey]  42
mdrp[grey]      43
#
srp0    21
mdrp[rp0,rnd,white] 11
mdap[rnd]   11
f_deltap    11 17-8 11 18-8 11 19-8
mdrp[rp0,rnd,grey]  5
f_deltap    5 18+8 5 19+8   5 23+8 5 24+8   5 28+8   5 39+8 5 40+8 5 41+8
mirp[min,rnd,grey]  headstem 46
f_deltap    46 25+4 46 26+4 46 27+4   46 28+4
mirp[rnd,grey]  headstem_plus_hole 52
f_deltap    52 25+4  52 26+4 52 27-4 52 28-4
#
IUP[y]
""",

    #tho_nangmontho
    "uni0E11": """
f_deltap    70 9+8  70 11+8  70 12+8  70 14-8  70 15-8  70 16-8  70 17-8  
srp0        69
mdrp[rp0,rnd,grey]  26
f_deltap    26 11-8  26 19-8
mdrp[grey]  23
mirp[min,rnd,grey]  headstem 60
f_deltap    60 28-8
mirp[rp0,rnd,grey]  headstem_plus_hole 66
f_deltap    66 27+8   
mdrp[grey]  32
#
srp0    26
mdrp[rp0,rnd,white] 17
f_deltap    17 23-8  17 24-8  17 34-8  
mdrp[grey]  40
srp1    32
sloop   6
ip  35 36 37 19 20 21
f_deltap    40 11+2 
mdrp[rp0,rnd,grey]  11
f_deltap    11 20-8
mirp[min,rnd,grey]  hstem 45
shp[rp2]    10
#
srp0    70
mirp[rp0,rnd,grey]  gap_170 56
mirp[min,rnd,grey]  hstem 1
srp1    40
ip  50
srp0    50
mdrp[grey]  6
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   10
alignrp     1
mdrp[grey]  46
mirp[rp0,rnd,grey]      vheight 53
mdrp[grey]  4
srp0    10
mirp[rp0,rnd,grey]  vheight_shoot 35
alignrp     37
mdrp[min,rnd,grey]  21
shp[rp2]    19
mdrp[rp0,min,rnd,grey]  36
mdrp[rp0,min,rnd,grey]  20
mdrp[rp0,rnd,white]     23
f_deltap    23 9+8  23 10+8   23 11+8  23 12+8  23 13+8   23 14+8  23 15+8  23 16+8  23 17+8  23 18+8  23 19+8  
mirp[min,rnd,grey]  headstem 63
mirp[rp0,rnd,grey]  headdia 29
f_deltap    29 9+8   29 10+8   29 13-8     29 14-8     29 15-8     29 16-8    29 20-8  29 26+8  29 27+8   29 29-8  29 30-8  29 31-8  29 34-8  29 40+8  29 41+8
mirp[min,rnd,grey]  headstem 57
f_deltap    57 28+8  
srp2    46
ip  13
ip  44
IUP[y]
""",

    #tho_phuthao
    "uni0E12": """
f_deltap    97 9+8   97 10+8   97 11+8   97 18+8   97 21+8   97 22+8   
SRP0                96
mirp[rp0,rnd,grey]  gap_190 47
mdrp[grey]  53
mirp[rp0,min,rnd,grey]  hstem 45
mdrp[grey]  22
ip  28
mdrp[rp0,rnd,grey]  40
f_deltap    40 10-8  40 14+8 40 15+8   40 20+8   40 25+8   40 26+8  40 28-8
mdrp[grey]  31
mirp[min,rnd,grey]  headstem 75
f_deltap    75 25-4 75 26-4  75 27-4  75 28-4
mirp[rp0,rnd,grey]  headdia 34
f_deltap    34 14-8 34 15-8  34 16-8   34 20-8  34 25-8  34 29-8 34 30-8 34 31-8
mirp[min,rnd,grey]  headstem 81
f_deltap    81 25+4 81 26+4  81 27+4 81 28+4
#
srp0    97
mirp[rp0,rnd,grey]  gap_170 69
mirp[min,rnd,grey]  hstem 67
srp1    47
ip      13
mdap[rnd]   13
srp2    22
sloop   6
ip      56 57 58 17 18 19
srp2    45
ip      9
mirp[min,rnd,grey]  hstem 61
srp1    67
ip      64
ip      1
#
mdap[rnd]   9
mirp[min,rnd,grey]  headstem 93
mirp[rnd,grey]  headstem_plus_hole 87
f_deltap    31 20-8  22 21-4  31 29-4 31 30-4 31 31-4
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
ALIGNRP     6
ALIGNRP     46
mirp[min,rnd,grey]      vstem 64
mirp[rnd,grey]          vheight 69
MIRP[rp0,rnd,grey]      vheight_shoot  56
alignrp     58
MIRP[min,rnd,grey]      vstem  19
shp[rp2]    17
mdrp[rp0,rnd,white]     57
mdrp[rp0,rnd,grey]      18
mdrp[rp0,rnd,white]     37
f_deltap    37 9-8
mirp[min,rnd,grey]      headstem 78
f_deltap    78 25-4 78 26-4 78 27-4  78 28-4
mirp[rp0,rnd,grey]      headdia 31
f_deltap    31 14-8 31 15-8  31 16-8  31 20-8  31 25-8 31 29-8 31 30-8 31 31-8
mirp[min,rnd,grey]      headstem 72
f_deltap    72 25+4  72 26+4 72 27+4  72 28+4
srp2        46
ip          28
srp0        6
mdrp[rp0,rnd,grey]  12
f_deltap    12 18-8  12 19-8  12 24-8  12 25-8 
ip      62
ip      3
mirp[min,rnd,grey]  headstem 90
mirp[rnd,grey]  headstem_plus_hole 84
IUP[y]
""",

    #no_nane
    "uni0E13": """
f_deltap    74 9+8  74 10+8  74 13+8   74 22+8   74 27+8   74 39+8
srp0    73
mirp[rp0,rnd,grey]  gap_190 23
mdrp[grey]  25
mdrp[grey]  8
mirp[rp0,min,rnd,grey]  hstem 11
mdrp[grey]  9
mdrp[rp0,rnd,grey]  17
f_deltap    17 13+8   17 14+8
mirp[min,rnd,grey]  headstem 52
f_deltap    52 25-4 52 26-4 52 27-4   52 28-4
mirp[rnd,grey]  headstem_plus_hole 58
f_deltap    58 25-4 58 26-4 58 27+4 58 28+4
#
srp0    74
mirp[rp0,rnd,grey]  gap_190 36
mirp[min,rnd,grey]  hstem 34
shp[rp2]    47
srp1    23
ip  1
mdrp[rp0,rnd,grey]  41
mirp[min,rnd,grey]  headstem 64
f_deltap    64 25-4 64 26-4 64 27-4 64 28-4
mirp[rnd,grey]  headstem_plus_hole 70
f_deltap    70 25-4 70 26-4  70 27+4  70 28+4
#
mdap[rnd]   1
mirp[min,rnd,grey]  hstem 31
shp[rp2]    0
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp     20
alignrp     44
mdrp[grey]  32
mirp[rnd,grey]  vheight 36
mirp[rp0,rnd,grey]  vheight_shoot 28
ip  25
mirp[min,rnd,grey]  vstem_113 5
mdap[rnd]   25
alignrp     11
mirp[min,rnd,grey] vstem 8
srp0    20
mdrp[rp0,rnd,grey]  14
f_deltap    14 18-8 14 19-8   14 23-8 14 24-8   14 28-8   14 39-8 14 40-8 14 41-8   
alignrp 38
ip  34
ip  47
mirp[min,rnd,grey] headstem 55
f_deltap    55 25-4 55 26-4 55 27-4   55 28-4
shp[rp2]    67
mirp[rnd,grey] headstem_plus_hole 49
f_deltap    49 25-4  49 26-4 49 27+4 49 28+4
shp[rp2]    61
IUP[y]
""",

    #do_dek
    "uni0E14": """
f_deltap    59 9+8  59 10+8  59 11+8   59 16-8   59 17-8  59 19-8   59 21+8
SRP0        58
MIRP[rp0,rnd,grey]  gap_190 33
mdrp[grey]  39
mirp[rp0,min,rnd,grey]  hstem 31
mdrp[grey]  8
ip  14
mdrp[rp0,rnd,grey]  26
f_deltap    26 13+8 26 14+8 26 15+8  26 20+8  26 22-8  26 25+8 26 26+8 26 28-8 
mirp[min,rnd,grey]  headstem 49
f_deltap    49 25-4 49 26-4 49 27-4 49 28-4
mirp[rp0,rnd,grey]  headdia 20
f_deltap    20 13-8 20 14-8 20 15-8 20 16-8  20 20-8  20 25-8   20 29-8 20 30-8 20 31-8
mirp[min,rnd,grey]  headstem 55
f_deltap    55 25+4 55 26+4 55 27+4 55 28+4
f_deltap    8 20-4 8 21-4
#
srp0    59
f_deltap 59 18+8 59 19+8
mirp[rp0,rnd,grey]  gap_170 45
mirp[min,rnd,grey]  hstem 1
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]           1
ALIGNRP             32
MIRP[rp0,rnd,grey]  vheight_shoot  42
MIRP[rp0,min,rnd,grey]  vstem_113  5
mdrp[rp0,rnd,white]  23
f_deltap    23 16-8
mirp[min,rnd,grey]  headstem 52
f_deltap    52 25-4 52 26-4 52 27-4 52 28-4
mirp[rp0,rnd,grey]  headdia 17
f_deltap    17 13-8 17 14-8 17 15-8 17 16-8  17 20-8  17 25-8   17 29-8 17 30-8 17 31-8 
mirp[min,rnd,grey]  headstem 46
f_deltap    46 25+4 46 26+4 46 27+4 46 28+4
srp2    32
ip      14
ip      27
ip      30
IUP[y]
""",

    #to_tao
    "uni0E15": """
f_deltap    63 9+8  63 10+8  63 11+8   63 16-8   63 17-8  63 19-8   63 21+8
SRP0        62
MIRP[rp0,rnd,grey]  gap_190 35
mdrp[grey]  41
mirp[rp0,min,rnd,grey]  hstem 33
mdrp[grey]  10
ip  16
mdrp[rp0,rnd,grey]  28
f_deltap    28 13+8 28 14+8 28 15+8  28 20+8  28 22-8  28 25+8 28 26+8 28 28-8
mirp[min,rnd,grey]  headstem 53
f_deltap    53 25-4 53 26-4 53 27-4 53 28-4
mirp[rp0,rnd,grey]  headdia 22
f_deltap    22 13-8 22 14-8 22 15-8 22 16-8  22 20-8  22 25-8   22 29-8 22 30-8 22 31-8
mirp[min,rnd,grey]  headstem 59
f_deltap    59 25+4 59 26+4 59 27+4 59 28+4
f_deltap    10 20-4 10 21-4 10 22-4
#
srp0    63
f_deltap 63 18+8 63 19+8
mirp[rp0,rnd,grey]  gap_170 49
mirp[min,rnd,grey]  hstem 1
srp1    10
sloop   6
ip  44 45 46 5 6 7
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
ALIGNRP     34
MIRP[rp0,rnd,grey]  vheight_shoot  44
alignrp     46
MIRP[rp0,min,rnd,grey]  vstem_113  7
shp[rp2]    5
mdrp[rp0,rnd,grey]  45
mdrp[rp0,min,rnd,grey]  6
mdrp[rp0,rnd,white]  25
f_deltap    25 11-8 25 12-8 25 13-8 25 14-8 25 15-8 
mirp[min,rnd,grey]  headstem 56
f_deltap    56 25-4 56 26-4 56 27-4 56 28-4
mirp[rp0,rnd,grey]  headdia 19
f_deltap    19 13-8 19 14-8 19 15-8 19 16-8  19 20-8  19 25-8   19 29-8 19 30-8 19 31-8
mirp[min,rnd,grey]  headstem 50
f_deltap    50 25+4 50 26+4 50 27+4 50 28+4
srp2    34
ip      16
ip      29
ip      32
IUP[y]
""",

    #to_tung
    "uni0E16": """
f_deltap    46 9+8   46 10+8   46 12+8   46 16-8   46 19+8   46 27+8
srp0                45
mirp[rp0,rnd,grey]  gap_190 23
mdrp[grey]  25
mdrp[grey]  8
mirp[rp0,min,rnd,grey]  hstem 11
mdrp[grey]  9
mdrp[rp0,rnd,grey]  17
f_deltap    17 13+8   17 14+8
mirp[min,rnd,grey]  headstem 36
f_deltap    36 25-4 36 26-4 36 27-4   36 28-4
mirp[rnd,grey]  headstem_plus_hole 42
f_deltap    42 25-4 42 26-4 42 27+4  42 28+4
#
srp0                46
mirp[rp0,rnd,white] gap_170 31
mirp[min,rnd,grey]  hstem   1
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]           1
alignrp             20
mirp[rp0,rnd,grey]  vheight_shoot    28
ip  25
mirp[min,rnd,grey]  vstem_113  5
mdap[rnd]   25
alignrp     11
mirp[min,rnd,grey]  vstem   8
srp0        20
mdrp[rp0,rnd,grey]  14
f_deltap    14 18-8 14 19-8    14 23-8 14 24-8   14 28-8   14 39-8 14 40-8 14 41-8
mirp[min,rnd,grey]  headstem 39
f_deltap    39 25-4 39 26-4 39 27-4   39 28-4
mirp[rnd,grey]  headstem_plus_hole 33
f_deltap    33 25-4  33 26-4 33 27+4 33 28+4
IUP[y]
""",

    #tho_thahan
    "uni0E17": """
f_deltap    44 9+8   44 10+8   44 11+8    44 28+8
srp0        43
mirp[rp0,rnd,grey]  gap_334 10
mirp[min,rnd,grey]  hstem 22
shp[rp2]    9
mdrp[rp0,rnd,grey]  16
f_deltap    16 13-8 16 14-8
mirp[min,rnd,grey]  headstem 40
f_deltap    40 25+4 40 26+4 40 27+4   40 28+4
mirp[rnd,grey]  headstem_plus_hole 34
f_deltap    34 25+4 34 26+4 34 27-4 34 28-4
#
srp0        44
mirp[rp0,rnd,white] gap_170 30
mirp[min,rnd,grey]  hstem 1
srp1        22
ip  24
srp0    24
mdrp[grey]  8
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp     9
mirp[rp0,rnd,grey]  vheight 27
alignrp     19
ip  23
mdrp[min,rnd,grey]  5
srp0        19
mdrp[rp0,rnd,grey]  13
f_deltap    13 18+8 13 19+8   13 23+8 13 24+8   13 28+8   13 39+8 13 40+8 31 41+8
mirp[min,rnd,grey]  headstem 31
f_deltap    31 25+4 31 26+4 31 27+4   31 28+4
mirp[rnd,grey]  headstem_plus_hole 37
f_deltap    37 25+4  37 26+4 37 27-4 37 28-4
IUP[y]
""",

    #to_thong
    "uni0E18": """
f_deltap    44 9+8   44 10+8   44 11+8
srp0        43
mirp[rp0,rnd,grey] gap_334 3
alignrp     39
mdrp[grey]  1
mirp[min,rnd,grey]  hstem 37
shp[rp2]    28
ip      27
mdrp[rp0,grey]  5
mdrp[grey]  42
#
srp0    44
mirp[rp0,rnd,grey] gap_170 30
ip  16
ip  17
mirp[min,rnd,grey]  hstem 35
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mirp[min,rnd,grey]  vstem 33
shp[rp2]    3
mirp[rp0,rnd,grey]  vheight_shoot 8
alignrp     16
mdrp[grey]  13
mirp[rp0,min,rnd,grey]  vstem_113 25
mdrp[grey]  20
srp0    8
mdrp[rp0,grey]  5
ip  27
ip  40
mdrp[grey]  36
ip  4
ip  37
mdrp[rp0,grey]  42
mdrp[grey]  30
ip  39
ip  29
IUP[y]
""",

    #no_nu
    "uni0E19": """
srp0    55
mirp[rp0,rnd,grey]  gap_334  1
mirp[min,rnd,grey]  hstem 13
shp[rp2]    0
mdrp[rp0,rnd,grey]  7
f_deltap    7 13-8 7 14-8
mirp[min,rnd,grey]  headstem 40
f_deltap    40 25+4 40 26+4 40 27+4   40 28+4
mirp[rnd,grey]  headstem_plus_hole 34
f_deltap    34 25+4 34 26+4 34 27-4 34 28-4
#
srp0    56
mirp[rp0,rnd,white]  gap_246 18
mirp[min,rnd,grey]  hstem 16
shp[rp2]    29
mdrp[rp0,rnd,grey]  23
mirp[min,rnd,grey]  headstem 46
mirp[rnd,grey]  headstem_plus_hole 52
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp     26
mdrp[grey]  14
mirp[rp0,rnd,grey]  vheight 10
alignrp     18
mdrp[rp0,rnd,grey]  4
f_deltap    4 18+8 4 19+8   4 23+8 4 24+8   4 28+8   4 39+8 4 40+8 4 41+8
mirp[min,rnd,grey]  headstem 31
f_deltap    31 25+4 31 26+4 31 27+4   31 28+4
mirp[rnd,grey]  headstem_plus_hole 37
f_deltap    37 25+4  37 26+4 37 27-4 37 28-4
#
srp0    26
mdrp[rp0,rnd,grey]  20
f_deltap    20 18-8 20 19-8   20 23-8 20 24-8   20 28-8
ip  16
ip  29
mirp[min,rnd,grey]  headstem 49
mirp[min,rnd,grey]  headstem_plus_hole 43
IUP[y]
""",

    #bo_baimai
    "uni0E1A": """
f_deltap    37 10+8    37 11+8   37 18+8   37 22+8   
srp0    36
mirp[rp0,rnd,grey]  gap_334 3
mdrp[grey]      1 
mirp[min,rnd,grey]  hstem 15
mdrp[rp0,rnd,grey]  9
f_deltap    9 13-8 9 14-8
mirp[min,rnd,grey]  headstem 33
f_deltap    33 25+4 33 26+4 33 27+4   33 28+4
mirp[rnd,grey]  headstem_plus_hole 27
f_deltap    27 25+4 27 26+4 27 27-4 27 28-4
#
srp0    37
mirp[rp0,rnd,grey]  gap_170 21
mirp[min,rnd,grey]  hstem 19
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  0
mirp[min,rnd,grey]  vstem 17
shp[rp2]    3
mirp[rp0,rnd,grey]  vheight 12
alignrp 21
mdrp[rp0,rnd,grey]  6
f_deltap    6 18+8 6 19+8   6 23+8 6 24+8   6 28+8   6 39+8 6 40+8 6 41+8
mirp[min,rnd,grey]  headstem 24
f_deltap    24 25+4 24 26+4 24 27+4   24 28+4
mirp[rnd,grey]  headstem_plus_hole 30
f_deltap    30 25+4  30 26+4 30 27-4 30 28-4
IUP[y]
""",

    #po_pla
    "uni0E1B": """
f_deltap    37 10+8    37 11+8   37 18+8   37 22+8   
srp0    36
mirp[rp0,rnd,grey]  gap_334 3
mdrp[grey]      1 
mirp[min,rnd,grey]  hstem 15
mdrp[rp0,rnd,grey]  9
f_deltap    9 13-8 9 14-8
mirp[min,rnd,grey]  headstem 33
f_deltap    33 25+4 33 26+4 33 27+4   33 28+4
mirp[rnd,grey]  headstem_plus_hole 27
f_deltap    27 25+4 27 26+4 27 27-4 27 28-4
#
srp0    37
mirp[rp0,rnd,grey]  gap_170 21
mirp[min,rnd,grey]  hstem 19
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  0
mirp[min,rnd,grey]  vstem 17
shp[rp2]    3
mirp[rnd,grey]  vheight_po 21
mirp[rp0,rnd,grey]  vheight 12
mdrp[rp0,rnd,grey]  6
f_deltap    6 18+8 6 19+8   6 23+8 6 24+8   6 28+8   6 39+8 6 40+8 6 41+8
mirp[min,rnd,grey]  headstem 24
f_deltap    24 25+4 24 26+4 24 27+4   24 28+4
mirp[rnd,grey]  headstem_plus_hole 30
f_deltap    30 25+4  30 26+4 30 27-4 30 28-4
IUP[y]
""",

    #po_pung
    "uni0E1C": """
f_deltap    38 10+8   38 11+8   38 18+8
srp0    37
mirp[rp0,rnd,grey]  gap_170 6
mirp[rp0,min,rnd,grey]  hstem 18
alignrp     4
mdrp[rp0,rnd,grey]  13
f_deltap    13 13+8 13 14+8
mirp[min,rnd,grey]  headstem 28
f_deltap    28 25-4 28 26-4 28 27-4   28 28-4
mirp[rnd,grey]  headstem_plus_hole 34
f_deltap    34 25-4 34 26-4 34 27+4 34 28+4
#
srp0    38
mdrp[rp0,rnd,grey] 23
mirp[min,rnd,grey]  hstem   21
shp[rp2]    1
srp1    18
ip  20
ip  3
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     5
mirp[rp0,rnd,grey]  vheight 10
alignrp 23
sloop   6
ip  19 20 21 2 3 4
mdrp[rp0,rnd,grey]  16
f_deltap    16 18+8 16 19+8   16 23+8 16 24+8   16 28+8   16 39+8 16 40+8 16 41+8
mirp[min,rnd,grey]  headstem 25
f_deltap    25 25+4 25 26+4 25 27+4   25 28+4
mirp[rnd,grey]  headstem_plus_hole 31
f_deltap    31 25+4  31 26+4 31 27-4 31 28-4
IUP[y]
""",

    #fo_fa
    "uni0E1D": """
f_deltap    38 10+8   38 11+8   38 18+8
srp0    37
mirp[rp0,rnd,grey]  gap_170 6
mirp[rp0,min,rnd,grey]  hstem 18
alignrp     4
mdrp[rp0,rnd,grey]  13
f_deltap    13 13+8 13 14+8
mirp[min,rnd,grey]  headstem 28
f_deltap    28 25-4 28 26-4 28 27-4   28 28-4
mirp[rnd,grey]  headstem_plus_hole 34
f_deltap    34 25-4 34 26-4 34 27+4 34 28+4
#
srp0    38
mdrp[rp0,rnd,grey] 23
mirp[min,rnd,grey]  hstem   21
shp[rp2]    1
srp1    18
ip  20
ip  3
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     5
mirp[rnd,grey]  vheight_po 23
mirp[rp0,rnd,grey]  vheight 10
sloop   6
ip  19 20 21 2 3 4
mdrp[rp0,rnd,grey]  16
f_deltap    16 18+8 16 19+8   16 23+8 16 24+8   16 28+8   16 39+8 16 40+8 16 41+8
mirp[min,rnd,grey]  headstem 25
f_deltap    25 25+4 25 26+4 25 27+4   25 28+4
mirp[rnd,grey]  headstem_plus_hole 31
f_deltap    31 25+4  31 26+4 31 27-4 31 28-4
IUP[y]
""",

    #po_pan
    "uni0E1E": """
f_deltap   36 9+8   36 10+8   36 11+8   36 18+8   36 22+8   36 28+8   36 29+8    36 34+8   36 40+8   36 41+8   
srp0    35
mirp[rp0,rnd,grey]  gap_334  4
mirp[min,rnd,grey]  hstem 16
shp[rp2]    3
mdrp[rp0,rnd,grey]  10
f_deltap    10 13-8 10 14-8
mirp[min,rnd,grey]  headstem 32
f_deltap    32 25+4 32 26+4 32 27+4   32 28+4
mirp[rnd,grey]  headstem_plus_hole 26
f_deltap    26 25+4 26 26+4 26 27-4 26 28-4
#
srp0    36
mirp[rp0,rnd,grey]  gap_170 22
mirp[min,rnd,grey]  hstem   20
shp[rp2]    1
srp1    16
sloop   3
ip      18 19 2
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mdrp[grey]  20
shp[rp2]    17
mirp[rp0,rnd,grey]  vheight 13
alignrp 19
alignrp 22
ip  2
mdrp[rp0,rnd,grey]  7
f_deltap    7 18+8 7 19+8   7 23+8 7 24+8   7 28+8   7 39+8 7 40+8 7 41+8
mirp[min,rnd,grey]  headstem 23
f_deltap    23 25+4 23 26+4 23 27+4   23 28+4
mirp[rnd,grey]  headstem_plus_hole 29
f_deltap    29 25+4  29 26+4 29 27-4 29 28-4
IUP[y]
""",

    #fo_fan
    "uni0E1F": """
f_deltap   36 9+8   36 10+8   36 11+8   36 18+8   36 22+8   36 28+8   36 29+8    36 34+8   36 40+8   36 41+8   
srp0    35
mirp[rp0,rnd,grey]  gap_334  4
mirp[min,rnd,grey]  hstem 16
shp[rp2]    3
mdrp[rp0,rnd,grey]  10
f_deltap    10 13-8 10 14-8
mirp[min,rnd,grey]  headstem 32
f_deltap    32 25+4 32 26+4 32 27+4   32 28+4
mirp[rnd,grey]  headstem_plus_hole 26
f_deltap    26 25+4 26 26+4 26 27-4 26 28-4
#
srp0    36
mirp[rp0,rnd,grey]  gap_170 22
mirp[min,rnd,grey]  hstem   20
shp[rp2]    1
srp1    16
sloop   3
ip      18 19 2
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mdrp[grey]  20
shp[rp2]    17
mirp[rnd,grey]  vheight_po  22
mirp[rp0,rnd,grey]  vheight 13
alignrp 19
ip  2
mdrp[rp0,rnd,grey]  7
f_deltap    7 18+8 7 19+8   7 23+8 7 24+8   7 28+8   7 39+8 7 40+8 7 41+8
mirp[min,rnd,grey]  headstem 23
f_deltap    23 25+4 23 26+4 23 27+4   23 28+4
mirp[rnd,grey]  headstem_plus_hole 29
f_deltap    29 25+4  29 26+4 29 27-4 29 28-4
IUP[y]
""",

    #po_sampao
    "uni0E20": """
f_deltap    46 9+8   46 10+8   46 15-8   46 16-8   46 30-8
srp0    45
mirp[rp0,rnd,grey]  gap_334 23
mdrp[grey]  25
mdrp[grey]  8
mirp[rp0,min,rnd,grey]  hstem 11
mdrp[grey]  9
srp0    23
mdrp[rp0,rnd,grey]  18
f_deltap    18 13-8   18 14-8
mirp[min,rnd,grey]  headstem 42
f_deltap    42 25+4 42 26+4 42 27+4   42 28+4
mirp[rnd,grey]  headstem_plus_hole 36
f_deltap    36 25+4 36 26+4 36 27-4  36 28-4
#
srp0    46
mirp[rp0,rnd,grey]  gap_170 31
mirp[min,rnd,grey]  hstem 1
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp 15
mirp[rp0,rnd,grey]  vheight_shoot 28
ip  25
mirp[min,rnd,grey]  vstem_113   5
mdap[rnd]   25
alignrp 11
mirp[min,rnd,grey]  vstem 8
srp0    15
mdrp[rp0,rnd,grey]  21
f_deltap    21 18-8 21 19-8   21 23-8 21 24-8 21 28-8  21 39-8 21 40-8 21 41-8
mirp[min,rnd,grey]  headstem 39
f_deltap    39 25-4 39 26-4 39 27-4   39 28-4
mirp[rnd,grey]  headstem_plus_hole 33
f_deltap    33 25-4  33 26-4 33 27+4  33 28+4
IUP[y]
""",

    #mo_ma
    "uni0E21": """
f_deltap    62 10+8   62 11+8   62 15-8   62 18+8   62 21+8   62 22+8
srp0        61
mirp[rp0,rnd,grey]  gap_334 14
mirp[min,rnd,grey]  hstem 26
shp[rp2]    3
mdrp[rp0,rnd,grey]  20
f_deltap    20 13-8 20 14-8
alignrp     9
mirp[min,rnd,grey]  headstem 46
f_deltap    46 25+4 46 26+4 46 27+4   46 28+4
shp[rp2]    58
mirp[rnd,grey]  headstem_plus_hole 40
f_deltap    40 25+4 40 26+4 40 27-4 40 28-4
shp[rp2]    52
#
srp0    62
mirp[rp0,rnd,grey]  gap_170 34
mirp[min,rnd,grey]  hstem 32
srp1    26
ip      1
ip      29
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp     6
mirp[min,rnd,grey]  vstem 30
mirp[rp0,rnd,grey]  vheight 23
alignrp     34
mdrp[rp0,rnd,grey]  17
f_deltap    17 18+8 17 19+8   17 23+8 17 24+8   17 28+8   17 39+8 17 40+8 17 41+8
mirp[min,rnd,grey]  headstem 37
f_deltap    37 25+4 37 26+4 37 27+4   37 28+4
mirp[rnd,grey]  headstem_plus_hole 43
f_deltap    43 25+4  43 26+4 43 27-4 43 28-4
srp0    6
mdrp[rp0,rnd,grey]  12
f_deltap    12 18-8 12 19-8   12 23-8 12 24-8   12 28-8   12 39-8 12 40-8 12 41-8
ip      27
ip      3
mirp[min,rnd,grey]  headstem 55
f_deltap    55 25-4 55 26-4 55 27-4   55 28-4
mirp[rnd,grey]  headstem_plus_hole 49
f_deltap    49 25-4  49 26-4 49 27+4 49 28+4
IUP[y]
""",

    #yo_yak
    "uni0E22": """
f_deltap    52 9+8   52 10+8   52 27+8   52 28+8   52 30+8   50 38+8   50 39+8   50 44+8   
srp0        51
mirp[rp0,rnd,grey]  gap_152 3
mdrp[grey]  10
mdrp[grey]  7
mirp[rp0,min,rnd,grey]  hstem 28
mdrp[grey]  24
mdrp[rp0,rnd,grey]  16
f_deltap    16 13+8 16 14+8
mirp[min,rnd,grey]  headstem 42
f_deltap    42 25-4 42 26-4 42 27-4   42 28-4
mirp[rp0,rnd,grey]  headstem_plus_hole 48
f_deltap    48 25-4 48 26-4 48 27+4 48 28+4
mdrp[grey]  21
#
srp0        52
mirp[rp0,rnd,grey]  gap_170 36
mirp[min,rnd,grey]  hstem 34
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mirp[min,rnd,grey]  vstem 32
mirp[rp0,rnd,grey]  vheight 13
alignrp     36
mdrp[rp0,rnd,grey]  19
f_deltap    19 18+8 19 19+8   19 23+8 19 24+8   19 28+8   19 39+8 19 40+8 19 41+8
mirp[min,rnd,grey]  headstem 39
f_deltap    39 25+4 39 26+4 39 27+4   39 28+4
mirp[rnd,grey]  headstem_plus_hole 45
f_deltap    45 25+4  45 26+4 45 27-4 45 28-4
srp2    32
ip      24
mdrp[rnd,grey]  21
mdap[rnd]   24
mdrp[grey]  25
mdrp[grey]  7
IUP[y]
""",

    #ro_ruar
    "uni0E23": """
srp0        50
mdrp[rp0,grey]  10
mdrp[grey]  33
#
srp0        51
mirp[rp0,rnd,grey]  gap_190 34
ip      21
ip      22
mirp[rp0,min,rnd,grey]  hstem 8
mdrp[rp0,rnd,grey]  3
f_deltap    3 13-8   3 14-8
mirp[min,rnd,grey]  headstem 47
f_deltap    47 25+4 47 26+4 47 27+4   47 28+4
mirp[rnd,grey]  headstem_plus_hole 41
f_deltap    41 25+4 41 26+4 41 27-4  41 28-4
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  0
mirp[rp0,rnd,grey]  vheight_shoot 13
alignrp     21
ip  10
mdrp[grey]  18
mirp[rp0,min,rnd,grey]  vstem_113 30
mdrp[grey]  25
#
srp0    0
mdrp[rp0,rnd,grey]  6
f_deltap    6 18-8 6 19-8   6 23-8 6 24-8   6 28-8   6 39-8 6 40-8 6 41-8
mirp[min,rnd,grey]  headstem 44
f_deltap    44 25-4 44 26-4 44 27-4   44 28-4
mirp[rnd,grey]  headstem_plus_hole 38
f_deltap    38 25-4  38 26-4 38 27+4 38 28+4
srp0    10
mdrp[grey]  9
mdrp[rp0,grey]  33
mdrp[grey]  34
IUP[y]
""",

    #ro_ru
    "uni0E24": """
f_deltap    46 9+8   46 10+8   46 12+8   46 16-8   46 19+8   46 27+8
srp0                45
mirp[rp0,rnd,grey]  gap_190 23
mdrp[grey]  25
mdrp[grey]  8
mirp[rp0,min,rnd,grey]  hstem 11
mdrp[grey]  9
mdrp[rp0,rnd,grey]  17
f_deltap    17 13+8   17 14+8
mirp[min,rnd,grey]  headstem 36
f_deltap    36 25-4 36 26-4 36 27-4   36 28-4
mirp[rnd,grey]  headstem_plus_hole 42
f_deltap    42 25-4 42 26-4 42 27+4  42 28+4
#
srp0                46
mirp[rp0,rnd,white] gap_170 31
mirp[min,rnd,grey]  hstem   1
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]           20
mirp[rnd,grey]  vheight_lu 1
mirp[rp0,rnd,grey]  vheight_shoot    28
ip  25
mirp[min,rnd,grey]  vstem_113  5
mdap[rnd]   25
alignrp     11
mirp[min,rnd,grey]  vstem   8
srp0        20
mdrp[rp0,rnd,grey]  14
f_deltap    14 18-8 14 19-8    14 23-8 14 24-8   14 28-8   14 39-8 14 40-8 14 41-8
mirp[min,rnd,grey]  headstem 39
f_deltap    39 25-4 39 26-4 39 27-4   39 28-4
mirp[rnd,grey]  headstem_plus_hole 33
f_deltap    33 25-4  33 26-4 33 27+4 33 28+4
IUP[y]
""",

    #lo_ling
    "uni0E25": """
f_deltap    56 9+8   56 10+8   56 12+8   56 18+8   56 21+8   56 30-8
srp0    55
mirp[rp0,rnd,grey]  gap_129 20
mdrp[grey]  35
mirp[rp0,min,rnd,grey]  hstem 8
mdrp[rp0,rnd,grey]  14
f_deltap    14 13+8 14 14+8
mirp[min,rnd,grey]  headstem 46
f_deltap    46 25-4 46 26-4 46 27-4   46 28-4
mirp[rnd,grey]  headstem_plus_hole 52
f_deltap    52 25-4 52 26-4 52 27+4  52 28+4
#
srp0    56 
mirp[rp0,rnd,white] gap_170    42
mirp[min,rnd,grey]  hstem   27
shp[rp2]    1
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     17
mirp[rp0,rnd,grey]  vheight_shoot 39
mdrp[grey]  36
mirp[rp0,min,rnd,grey]  vstem_113 31
srp1    1
ip      24
ip      27
mdrp[grey]  35
mdap[rnd]   24
mirp[min,rnd,grey]  vstem_113 5
#
srp0    17
mdrp[rp0,rnd,grey]  11
f_deltap    11 18-8 11 19-8    11 23-8 11 24-8   11 28-8   11 39-8 11 40-8 11 41-8
mirp[min,rnd,grey]  headstem 49
f_deltap    49 25-4 49 26-4 49 27-4   49 28-4
mirp[rnd,grey]  headstem_plus_hole 43
f_deltap    43 25-4  43 26-4 43 27+4 43 28+4
IUP[y]
""",

    #lo_lu
    "uni0E26": """
f_deltap    46 9+8   46 10+8   46 15-8   46 16-8   46 30-8
srp0    45
mirp[rp0,rnd,grey]  gap_334 23
mdrp[grey]  25
mdrp[grey]  8
mirp[rp0,min,rnd,grey]  hstem 11
mdrp[grey]  9
srp0    23
mdrp[rp0,rnd,grey]  18
f_deltap    18 13-8   18 14-8
mirp[min,rnd,grey]  headstem 42
f_deltap    42 25+4 42 26+4 42 27+4   42 28+4
mirp[rnd,grey]  headstem_plus_hole 36
f_deltap    36 25+4 36 26+4 36 27-4  36 28-4
#
srp0    46
mirp[rp0,rnd,grey]  gap_170 31
mirp[min,rnd,grey]  hstem 1
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   15
mirp[rnd,grey]  vheight_lu  1
mirp[rp0,rnd,grey]  vheight_shoot 28
ip  25
mirp[min,rnd,grey]  vstem_113   5
mdap[rnd]   25
alignrp 11
mirp[min,rnd,grey]  vstem 8
srp0    15
mdrp[rp0,rnd,grey]  21
f_deltap    21 18-8 21 19-8   21 23-8 21 24-8 21 28-8  21 39-8 21 40-8 21 41-8
mirp[min,rnd,grey]  headstem 39
f_deltap    39 25-4 39 26-4 39 27-4   39 28-4
mirp[rnd,grey]  headstem_plus_hole 33
f_deltap    33 25-4  33 26-4 33 27+4  33 28+4
IUP[y]
""",

    #wo_wan
    "uni0E27": """
srp0    39
mdrp[grey]  16
#
srp0    40
mirp[rp0,rnd,grey]  gap_170 23
mirp[rp0,min,rnd,grey]  hstem 8
mdrp[rp0,rnd,grey]  3
f_deltap    3 13-8   3 14-8
mirp[min,rnd,grey]  headstem 36
f_deltap    36 25+4 36 26+4 36 27+4   36 28+4
mirp[rnd,grey]  headstem_plus_hole 30
f_deltap    30 25+4 30 26+4 30 27-4  30 28-4
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mirp[rp0,rnd,grey]  vheight_shoot 20
mdrp[grey]  17
mirp[rp0,min,rnd,grey]  vstem_113   12
mdrp[grey]  16
srp0    0
mdrp[rp0,rnd,grey]  6
f_deltap    6 18-8 6 19-8   6 23-8 6 24-8   6 28-8   6 39-8 6 40-8 6 41-8
mirp[min,rnd,grey]  headstem 33
f_deltap    33 25-4 33 26-4 33 27-4   33 28-4
mirp[rnd,grey]  headstem_plus_hole 27
f_deltap    27 25-4  27 26-4 27 27+4 27 28+4
IUP[y]
""",

    #so_sala
    "uni0E28": """
f_deltap    61 9+8    61 10+8   61 11+8   61 16-8   61 17-8   61 18+8   61 22+8  61 27+8 
srp0                60
mirp[rp0,rnd,white] gap_190 17
mdrp[grey]  20
mirp[rp0,min,rnd,grey]  hstem 15
mdrp[grey]  43
ip  45
mdrp[rp0,rnd,grey]  10
f_deltap    10 13+8 10 14+8 10 15+8   10 20+8   10 25+8 10 26+8
mirp[min,rnd,grey]  headstem 51
f_deltap    51 25-4 51 26-4   51 27-4  51 28-4
ip  7
mirp[rnd,grey]  headstem_plus_hole 57
f_deltap    57 25-4 57 26-4 57 27+4 57 28+4
#
srp0                61
mirp[rp0,rnd,white] gap_190 34
mirp[min,rnd,grey]  hstem 1
sloop   4
ip  26 31 37 5
mdrp[rp0,grey]  29
mdrp[grey]  28
f_deltap    43 17-4  43 18-4   43 19-2  43 20-2  43 21-2     43 27-4 45 27-4  43 28-4 45 28-4
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]           0
ALIGNRP             16
MIRP[rp0,rnd,grey]  vheight_shoot  23
mdrp[min,rnd,grey]  28
MIRP[rp0,min,rnd,grey]  vstem_113  40
ip  26
ip  31
mdrp[rp0,rnd,white]   35
f_deltap    35 16-8   35 38-8   35 39-8   35 40-8  35 41-8   35 42-8   35 43-8  35 44-8
ip  37
ip  5 
MIRP[min,rnd,grey]  headstem  54
f_deltap    54 25-4 54 26-4  54 27-4   54 28-4
MIRP[rp0,rnd,grey]  headdia  13
f_deltap    13 13-8   13 14-8   13 15-8   13 16-8   13 20-8   13 25-8   13 29-8  13 30-8  13 31-8   13 34-8  13 40+8  13 41+8
MIRP[min,rnd,grey]  headstem  48
f_deltap    48 25+4 48 26+4 48 27+4  48 28+4
mdrp[grey]  45
IUP[y]
""",

    #so_rusi
    "uni0E29": """
f_deltap    63 10+8    63 11+8   63 18+8   63 22+8   63 27+8   63 28+8   63 38+8   63 39+8
srp0    62
mirp[rp0,rnd,grey]  gap_334 3
mdrp[grey]      1
mirp[min,rnd,grey]  hstem 48
shp[rp2]    15
mdrp[rp0,rnd,grey]  9
f_deltap    9 13-8 9 14-8
mirp[min,rnd,grey]  headstem 59
f_deltap    59 25+4 59 26+4 59 27+4   59 28+4
mirp[rnd,grey]  headstem_plus_hole 53
f_deltap    53 25+4 53 26+4 53 27-4 53 28-4
#
srp0    63
mirp[rp0,rnd,grey]  gap_190 33
alignrp     37
ip  35
mirp[min,rnd,grey]  hstem 31
shp[rp2]    42
srp1    48
sloop   3
ip  26 21 22
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  0
mirp[min,rnd,grey]  vstem 40
shp[rp2]    3
mirp[rp0,rnd,grey]  vheight 12
alignrp 33
sloop   11
ip      16 19 21 22 24 31 43 48 34 35 37
mdrp[rp0,rnd,grey]  6
f_deltap    6 18+8 6 19+8   6 23+8 6 24+8   6 28+8   6 39+8 6 40+8 6 41+8
mirp[min,rnd,grey]  headstem 50
f_deltap    50 25+4 50 26+4 50 27+4   50 28+4
mirp[rnd,grey]  headstem_plus_hole 56
f_deltap    56 25+4  56 26+4 56 27-4 56 28-4
IUP[y]
""",

    #so_sua
    "uni0E2A": """
f_deltap    70 9+8   70 10+8   70 12+8
srp0    69
mirp[rp0,rnd,grey]  gap_129 20
mdrp[grey]  33
mirp[rp0,min,rnd,grey]  hstem 8
mdrp[rp0,rnd,grey]  14
f_deltap    14 13+8 14 14+8
mirp[min,rnd,grey]  headstem 60
f_deltap    60 25-4 60 26-4 60 27-4   60 28-4
mirp[rnd,grey]  headstem_plus_hole 66
f_deltap    66 25-4 66 26-4 66 27+4  66 28+4
#
srp0    70
mirp[rp0,rnd,white] gap_190    48
mirp[min,rnd,grey]  hstem   49
shp[rp2]    1
sloop   4
ip  40 45 26 52
mdrp[rp0,grey]  43
mdrp[grey]  42
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     17
mirp[rp0,rnd,grey]  vheight_shoot 37
srp1    1
ip      24
ip      49
mdrp[grey]  34
mdrp[min,rnd,grey]  42
mirp[rp0,min,rnd,grey]  vstem_113 29
ip  40
ip  45
mdrp[grey]  33
#
mdap[rnd]   24
srp2    29
ip  26
ip  52
mirp[min,rnd,grey]  vstem_113 5
ip  54
#
srp0    17
mdrp[rp0,rnd,grey]  11
f_deltap    11 18-8 11 19-8    11 23-8 11 24-8   11 28-8   11 39-8 11 40-8 11 41-8
mirp[min,rnd,grey]  headstem 63
f_deltap    63 25-4 63 26-4 63 27-4   63 28-4
mirp[rnd,grey]  headstem_plus_hole 57
f_deltap    57 25-4  57 26-4 57 27+4 57 28+4
IUP[y]
""",

    #ho_hib
    "uni0E2B": """
f_deltap    68 11+8   68 19+8    68 28+8
srp0        67
mirp[rp0,rnd,grey]  gap_334 10
mirp[min,rnd,grey]  hstem 22
shp[rp2]    9
mdrp[rp0,rnd,grey]  16
f_deltap    16 13-8 16 14-8
mirp[min,rnd,grey]  headstem 52
f_deltap    52 25+4 52 26+4 52 27+4   52 28+4
mirp[rnd,grey]  headstem_plus_hole 46
f_deltap    46 25+4 46 26+4 46 27-4 46 28-4
#
srp0        68
mirp[rp0,rnd,white] gap_170 42
mirp[min,rnd,grey]  hstem 1
srp1        22
ip  24
mdrp[rp0,rnd,grey]  36
mdrp[min,rnd,grey]  58
f_deltap    58 25+4 58 26+4
mdrp[rp0,rnd,grey]  30
f_deltap    30 18+8 30 19+8   30 22+8 30 23+8 30 24+8 
ip  39
ip  27
mdrp[min,rnd,grey]  64
f_deltap    64 25-4 64 26-4
srp0    24
mdrp[grey]  8
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp     9
mirp[rp0,rnd,grey]  vheight 19
alignrp     33
ip  23
mdrp[rp0,rnd,grey]  13
f_deltap    13 18+8 13 19+8   13 23+8 13 24+8   13 28+8   13 39+8 13 40+8 13 41+8
sloop   3
ip  27 39 5
mirp[min,rnd,grey]  headstem 43
f_deltap    43 25+4 43 26+4 43 27+4   43 28+4
shp[rp2]    56
mirp[rnd,grey]  headstem_plus_hole 49
f_deltap    49 25+4  49 26+4 49 27-4 49 28-4
shp[rp2]    61
IUP[y]
""",

    #lo_jula
    "uni0E2C": """
f_deltap   61 10+8   61 11+8   61 15-8   61 18+8   61 22+8   61 26-8   61 28+8   61 29+8    61 34+8   61 40+8   61 41+8
srp0    60
mirp[rp0,rnd,grey]  gap_334  4
mirp[min,rnd,grey]  hstem 16
shp[rp2]    3
mdrp[rp0,rnd,grey]  10
f_deltap    10 13-8 10 14-8
mirp[min,rnd,grey]  headstem 45
f_deltap    45 25+4 45 26+4 45 27+4   45 28+4
mirp[rnd,grey]  headstem_plus_hole 39
f_deltap    39 25+4 39 26+4 39 27-4 39 28-4
#
srp0    61
mirp[rp0,rnd,grey]  gap_190 35
ip  33
ip  32
mirp[min,rnd,grey]  hstem   20
shp[rp2]    1
srp1    16
sloop   3
ip      18 19 2
mdrp[rp0,rnd,grey]  24
f_deltap    24 13-8
mirp[min,rnd,grey]  headstem 57
f_deltap    57 25+4 57 26+4 57 27+4   57 28+4
mirp[rnd,grey]  headstem_plus_hole 51
f_deltap    51 25+4 51 26+4 51 27-4 51 28-4
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mdrp[grey]  20
shp[rp2]    17
mirp[rp0,rnd,grey]  vheight 13
ip  18
ip  2
mdrp[rp0,rnd,grey]  7
f_deltap    7 18+8 7 19+8   7 23+8 7 24+8   7 28+8   7 39+8 7 40+8 7 41+8
mirp[min,rnd,grey]  headstem 36
f_deltap    36 25+4 36 26+4 36 27+4   36 28+4
mirp[rnd,grey]  headstem_plus_hole 42
f_deltap    42 25+4  42 26+4 42 27-4 42 28-4
srp0    13
mdrp[rp0,rnd,grey]  27
sloop   4
ip  30 32 33 35
mdrp[rp0,rnd,grey]  21
f_deltap    21 18+8 21 19+8   21 23+8 21 24+8   21 28+8   21 39+8 21 40+8 21 41+8
mirp[min,rnd,grey]  headstem 48
f_deltap    48 25+4 48 26+4 48 27+4   48 28+4
mirp[rnd,grey]  headstem_plus_hole 54
f_deltap    54 25+4  54 26+4 54 27-4 54 28-4
f_deltap    18 13-8 2 13-8   18 14-8 2 14-8
IUP[y]
""",

    #aw_ang
    "uni0E2D": """
f_deltap    52 9+8   52 10+8   52 18+8   
srp0    51
mirp[rp0,rnd,grey]  gap_152 3
mdrp[grey]  29
mirp[rp0,min,rnd,grey]  hstem 15
mdrp[rp0,rnd,grey]  10
f_deltap    10 13+8 10 14+8
mirp[min,rnd,grey]  headstem   42
f_deltap    42 25-4 42 26-4 42 27-4   42 28-4
mirp[rnd,grey]  headstem_plus_hole 48
f_deltap    48 25-4 48 26-4 48 27+4 48 28+4
#
srp0     52
mirp[rp0,rnd,white]  gap_170 36
mirp[min,rnd,grey]  hstem 21
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mirp[min,rnd,grey]  vstem   19
mirp[rp0,rnd,grey]  vheight_shoot  33
mdrp[grey]  30
mirp[rp0,min,rnd,grey]  vstem_113   25
mdrp[rp0,grey]  29
mdrp[rp0,min,rnd,white] 7
mdap[rnd]   7
f_deltap    7 9+8 7 10+8 
mdrp[rp0,rnd,grey]  13
f_deltap    13 18+8 13 19+8   13 23+8 13 24+8   13 28+8   13 39+8 13 40+8 13 41+8
mirp[min,rnd,grey]  headstem    39
f_deltap    39 25+4 39 26+4 39 27+4   39 28+4
mirp[rnd,grey]  headstem_plus_hole 45
f_deltap    45 25+4  45 26+4 45 27-4 45 28-4
IUP[y]
""",

    #ho_nokhuk
    "uni0E2E": """
f_deltap    72 9+8   72 10+8   72 11+8   72 12+8   72 18+8
srp0    71
mirp[rp0,rnd,grey]  gap_152 3
mdrp[grey]  30
mirp[rp0,min,rnd,grey]  hstem 15
mdrp[rnd,grey]  56
mdrp[rp0,rnd,grey]  10
f_deltap    10 13+8 10 14+8
mirp[min,rnd,grey]  headstem   62
f_deltap    62 25-4 62 26-4 62 27-4   62 28-4
mirp[rnd,grey]  headstem_plus_hole 68
f_deltap    68 25-4 68 26-4 68 27+4 68 28+4
#
srp0     72
mirp[rp0,rnd,white]  gap_190 44
mirp[rp0,min,rnd,grey]  hstem 21
mdrp[rnd,grey]  50
srp0    44
mdrp[rp0,grey]  39
mdrp[grey]  38
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mirp[min,rnd,grey]  vstem   19
mirp[rp0,rnd,grey]  vheight_shoot  33
ip      7
mirp[min,rnd,grey]  vstem_113   53
mdap[rnd]   7
f_deltap    7 9-4   7 10-4   7 12-8  7 13-8  
srp2    33
sloop   7
ip  39 36 41 50 24 47 27
mdrp[rp0,rnd,grey]  13
f_deltap    13 18+8 13 19+8   13 23+8 13 24+8   13 28+8   13 39+8 13 40+8 13 41+8
mirp[min,rnd,grey]  headstem    59
f_deltap    59 25+4 59 26+4 59 27+4   59 28+4
mirp[rnd,grey]  headstem_plus_hole 65
f_deltap    65 25+4  65 26+4 65 27-4 65 28-4
IUP[y]
""",

    #paiyannoi
    "uni0E2F": """
f_deltap    38 9+8   38 10+8   38 11+8   38 12+8
srp0    37
mirp[rp0,rnd,grey]  gap_102 14
mdrp[min,rnd,grey]  25
#
srp0    38
mirp[rp0,rnd,white]  gap_170 36
mirp[min,rnd,grey]  hstem 1
srp1    25
sloop   6
ip  19 20 31 32 7 8
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
mirp[rp0,rnd,grey]  vheight 35
ip  17
mdrp[min,rnd,grey]  4
mdap[rnd]   17
mdrp[min,rnd,grey]  22
mdrp[rp0,rnd,grey]  11
sloop   6
ip  19 20 31 32 7 8 
mdrp[min,rnd,grey]  28
IUP[y]
""",

    #sara_a
    "uni0E30": """
f_deltap    61 11+8  61 13+8  
srp0    60
mirp[rp0,rnd,white]  gap_129 3
alignrp 33
mirp[min,rnd,grey]  headstem 27
f_deltap    27 26+4   27 27+4 27 28+4   27 29-4 27 30-4 27 31-4   27 34-4
shp[rp2]    57
mirp[rp0,rnd,grey]  headdia 9
f_deltap    9 13+8    9 14+8   9 15+8   9 16+8
alignrp 39
mirp[min,rnd,grey]  headstem 21
f_deltap    21 26-4   21 27-4 21 28-4   21 29+4 21 30+4 21 31+4   21 34+4 
shp[rp2]    51
mdrp[rnd,grey]  11
#
shp[rp2]    41
srp0    61
mirp[rp0,rnd,white] gap_170 15
alignrp 45
mdrp[min,rnd,grey]  14
shp[rp2]    44
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]  0
mdrp[min,rnd,grey]  11
mdrp[rp0,rnd,grey]  6
f_deltap    6 21-8
mirp[min,rnd,grey]  headstem 24
f_deltap    24 27-4 24 28-4
mirp[rnd,grey]  headstem_plus_hole 18
f_deltap    18 20+8  18 27+4 18 28+4
mdrp[rnd,grey]  15
srp0    0
mirp[rp0,rnd,grey]  vheight 36
mirp[min,rnd,grey]  headstem 54
f_deltap    54 27-4 54 28-4
mirp[rnd,grey]  headstem_plus_hole 48
f_deltap    48 20+8  48 27+4 48 28+4
mdrp[rnd,grey]  45
mdrp[rp0,rnd,grey]  30
f_deltap    30 21+8
mdrp[min,rnd,grey]  41
IUP[y]
""",

    #sara_maihanakat
    "uni0E31": """
mdap[rnd]   3
mirp[min,rnd,grey]  headstem 27
f_deltap    27 26+4  27 27+4 27 28+4
mirp[rp0,rnd,grey]  headdia 9
f_deltap    9 13+8   9 14+8   9 15+8   9 16+8   9 29+8 9 30+8 9 31+8
mirp[min,rnd,grey]  headstem 21
f_deltap    21 26-4  21 27-4 21 28-4
mdrp[grey]  11
srp0    3
mdrp[rp0,rnd,grey]  15
mdrp[min,rnd,grey]  14
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
f_deltap    0 9+8  0 11+8  0 12+8  0 14+8  0 15+8  0 16+8  
mdrp[rp0,rnd,grey]  6
f_deltap    6 12-4   6 16-8   6 17-8  6 26-8  6 29+8
mirp[min,rnd,grey]  headstem 24
f_deltap    24 27-4 24 28-4
mirp[rnd,grey]  headstem_plus_hole 18
f_deltap    18 20+8  18 27+4 18 28+4   18 34+8
IUP[y]
""",

    #sara_aa
    "uni0E32": """
srp0    18
mdrp[white]  9
#
srp0    19
mirp[rp0,rnd,white] gap_170 16
mirp[min,rnd,grey]  hstem 1
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rp0,rnd,grey]  vheight_shoot 13
mdrp[grey]  10
mirp[rp0,min,rnd,grey]  vstem_113   5
mdrp[grey]  9
IUP[y]
""",

    #sara_am
    #uni0E33: use sara_aa with nikahit
    
    #sara_i
    "uni0E34": """
mdap[rnd]   0
mdrp[min,rnd,grey]   8
mdrp[rp0,rnd,grey]  4
mdrp[min,rnd,grey]   12
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
f_deltap    0 9+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8   0 19-8   0 21-8   0 24-8
mdrp[rp0,rnd,grey]  14
mdrp[grey]  2
mdrp[rp0,min,rnd,white]  10
mdrp[min,rnd,grey]  6
IUP[y]
""",

    #sara_ii
    "uni0E35": """
mdap[rnd]   0
mdrp[min,rnd,grey]   13
mdrp[min,rnd,grey]   9
mdrp[rp0,rnd,grey]  4
mdrp[min,rnd,grey]   17
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
f_deltap    0 9+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8   0 19-8   0 21-8   0 24-8
mdrp[rp0,rnd,grey]  19
mdrp[grey]  2
mdrp[rp0,rnd,white] 15
mdrp[rp0,rnd,grey]  6
mdrp[min,rnd,grey]  9
IUP[y]
""",

    #sara_ue
    "uni0E36": """
mdap[rnd]   0
mdrp[min,rnd,grey]   21
mdrp[rp0,rnd,grey]  4
ip  8
mdrp[min,rnd,grey]   25
mdap[rnd]   8
mirp[min,rnd,grey]  headstem 38
mirp[rp0,rnd,grey]  headdia 15
f_deltap    15 13+8   15 14+8   15 15+8  15 16+8 
mirp[min,rnd,grey]  headstem 32
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
f_deltap    0 9+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8   0 19-8   0 21-8   0 24-8
mdrp[rp0,rnd,grey]  27
mdrp[grey]  2
mdrp[rp0,rnd,white] 23
mdrp[rp0,rnd,grey]  6
mdrp[rp0,rnd,grey]  12
mirp[min,rnd,grey]  headstem 35
mirp[rp0,rnd,grey]  headdia 19
f_deltap    19 13-8   19 14-8   19 15-8  19 16-8
mirp[min,rnd,grey]  headstem 29
f_deltap    29 30+8
IUP[y]
""",

    #sara_uee
    "uni0E37": """
mdap[rnd]   0
mdrp[min,rnd,grey]   16
mdrp[rp0,rnd,grey]   12
mdrp[rp0,min,rnd,white] 9
mdrp[min,rnd,grey]  7 
srp0    0
mdrp[rp0,rnd,grey]  4
mdrp[min,rnd,grey]   20
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
f_deltap    0 9+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8   0 19-8   0 21-8   0 24-8
mdrp[rp0,rnd,grey]  22
mdrp[grey]  2
mdrp[rp0,rnd,white]  18
mdrp[rp0,rnd,grey]  6
ip  9
ip  11
mdrp[min,rnd,grey]  8
shp[rp2]    13
IUP[y]
""",

    #sara_u
    "uni0E38": """
mdap[rnd]   0
mdrp[min,rnd,grey]  2
mdrp[rp0,rnd,grey]  5
mirp[min,rnd,grey]  headstem_small 21
mirp[rnd,grey]  headstem_small_plus_hole 15
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   24
mdrp[rp0,min,rnd,white] 8
mirp[min,rnd,grey]  headstem_small 18
mirp[rp0,rnd,grey]  headdia_small 2
f_deltap    2 13-8  2 14-8  2 15-8  2 16-8
mirp[min,rnd,grey]  headstem_small 12
mdrp[min,rnd,grey]  0
IUP[y]
""",

    #sara_uu
    "uni0E39": """
mdap[rnd]   19
mdrp[rp0,min,rnd,grey]  17
mdrp[rp0,min,rnd,white]  12
mdrp[min,rnd,grey]  2
mirp[min,rnd,grey]  headstem_small 25
mirp[rp0,rnd,grey]  headdia_small 6
mirp[min,rnd,grey]  headstem_small 31
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   34
mdrp[rp0,min,rnd,white]     9
alignrp     19
mirp[min,rnd,grey]  headstem_small 28
mirp[rp0,rnd,grey]  headdia_small 3
mirp[min,rnd,grey]  headstem_small 22
mdrp[rp0,rnd,grey]  0
mdrp[min,rnd,grey]  15
IUP[y]
""",

    #pinthu
    "uni0E3A": """
mdap[rnd]   9
mirp[min,rnd,grey]  headdia_small 3
IUP[x]
SVTCA[y-axis]
mdap[rnd]   12
mdrp[rp0,min,rnd,white] 6
mirp[min,rnd,grey]  headdia_small 0
IUP[y]
""",

    #thai_baht
    "uni0E3F": """
f_deltap    48 9+8   48 10+8   48 12+8   48 13+8   48 17+8
srp0    47
mdrp[rp0,rnd,grey]  5
ip  4
ip  7
mdrp[min,rnd,grey]  38
shp[rp2]    27
#
srp0    48
mdrp[rp0,rnd,grey]  21
mdrp[min,rnd,grey]  32
mdrp[rp0,rnd,grey]  15
mdrp[min,rnd,grey]  43
ip  18
srp1    38
ip  36
mdap[rnd]   36
sloop   3
alignrp 9 25 1
mdrp[min,rnd,grey]  46
sloop   3
shp[rp2]    11 35 24
IUP[x]
SVTCA[y-axis]
mdap[rnd]   2
mdrp[min,rnd,grey]  25
shp[rp2]    29
shp[rp2]    5
mdrp[min,rnd,grey]  1
mdrp[rp0,rnd,grey]  9
alignrp     12
ip  36
mdrp[min,rnd,grey]  10
mdrp[min,rnd,grey]  37
shp[rp2]    6
shp[rp2]    46
mdap[rnd]   36
alignrp     40
mdrp[min,rnd,grey]  26
ip  18
shp[rp2]    35
IUP[y]
""",

    #sara_e
    "uni0E40": """
srp0    27
mirp[rp0,rnd,white]  gap_334 5
f_deltap    5 15-8
mirp[min,rnd,grey]  hstem 3
mdrp[rp0,rnd,grey]  11
f_deltap    11 13+8 11 14+8
mirp[min,rnd,grey]  headstem 17
f_deltap    17 25-4 17 26-4 17 27-4   17 28-4
mirp[rnd,grey]  headstem_plus_hole 23
f_deltap    23 25-4 23 26-4 23 27+4  23 28+4
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mirp[rnd,grey]  vheight 4
mdrp[rp0,rnd,grey]  8
f_deltap    8 18-8 8 19-8    8 23-8 8 24-8   8 28-8   8 39-8 8 40-8 8 41-8
mirp[min,rnd,grey]  headstem 20
f_deltap    20 25-4 20 26-4 20 27-4   20 28-4
mirp[rnd,grey]  headstem_plus_hole 14
f_deltap    14 25-4  14 26-4 14 27+4 14 28+4
IUP[y]
""",

    #sara_ae
    #use sara_a reference: uni0E40

    #sara_o
    "uni0E42": """
srp0    46
mdrp[rp0,grey]  5
mdrp[grey]  20
#
srp0    47
mirp[rp0,rnd,grey]  gap_334 25
f_deltap    25 15-8
mdrp[grey]  15
mirp[min,rnd,grey]  hstem 3
mdrp[rp0,rnd,grey]  31
mirp[min,rnd,grey]  headstem 37
mirp[rnd,grey]  headstem_plus_hole 43
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[rp0,rnd,grey]  28
mirp[min,rnd,grey]  headstem 40
mirp[rnd,grey]  headstem_plus_hole 34
#
mdap[rnd]   7
alignrp     14
mdrp[grey]  5
mdrp[grey]  12
mdrp[rp0,min,rnd,grey]  22
mdrp[grey]  17
#
srp0    5
mdrp[grey]  4
mdrp[rp0,grey]  24
mdrp[grey]  25
IUP[y]
""",

    #sara_ai_maimoun
    "uni0E43": """
srp0    60
mirp[rp0,rnd,grey]  gap_61 33
mdrp[min,rnd,grey]  10
#
srp0    61
mirp[rp0,rnd,grey]  gap_334 39
f_deltap    39 15-8
mirp[min,rnd,grey]  hstem 3
srp1    10
sloop   4
ip 22 23 16 27
mdrp[rp0,rnd,grey]  45
f_deltap    45 13+8 45 14+8
mirp[min,rnd,grey]  headstem 51
f_deltap    51 25-4 51 26-4 51 27-4   51 28-4
mirp[rnd,grey]  headstem_plus_hole 57
f_deltap    57 25-4 57 26-4 57 27+4  57 28+4
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[rp0,rnd,grey]  42
f_deltap    42 18-8 42 19-8    42 23-8 42 24-8   42 28-8   42 39-8 42 40-8 42 41-8
mirp[min,rnd,grey]  headstem 54
f_deltap    54 25-4 54 26-4 54 27-4   54 28-4
mirp[rnd,grey]  headstem_plus_hole 48
f_deltap    48 25-4  48 26-4 48 27+4 48 28+4
mdap[rnd]   36
mdrp[min,rnd,grey]  7
mdrp[rp0,rnd,grey]  30
mdrp[min,rnd,grey]  13
srp1    7
ip  22
ip  21
IUP[y]
""",

    #sara_ai_malai
    "uni0E44": """
srp0        19
mirp[rp0,rnd,grey]  gap_84 15
mdrp[min,rnd,grey]  23
#
srp0    57
mirp[rp0,rnd,grey]  gap_334 35
f_deltap    35 15-8
mirp[min,rnd,grey]  hstem 3
srp1    23
ip  29
ip  8
mdrp[rp0,rnd,grey]  41
f_deltap    41 13+8 41 14+8
mirp[min,rnd,grey]  headstem 47
f_deltap    47 25-4 47 26-4 47 27-4   47 28-4
mirp[rnd,grey]  headstem_plus_hole 53
f_deltap    53 25-4 53 26-4 53 27+4  53 28+4
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[rp0,rnd,grey]  38
f_deltap    38 18-8 38 19-8    38 23-8 38 24-8   38 28-8   38 39-8 38 40-8 38 41-8
mirp[min,rnd,grey]  headstem 50
f_deltap    50 25-4 50 26-4 50 27-4   50 28-4
mirp[rnd,grey]  headstem_plus_hole 44
f_deltap    44 25-4  44 26-4 44 27+4 44 28+4
mdap[rnd]   32
mdrp[grey]  20
mdrp[min,rnd,grey]  6
mdap[rnd]  12
mdrp[min,rnd,grey]  26
IUP[y]
""",

    #lakkhangyao
    "uni0E45": """
srp0    18
mdrp[grey]  9
#
srp0    19
mirp[rp0,rnd,white] gap_190 16
mirp[min,rnd,grey]  hstem 1
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   18
mirp[rp0,rnd,grey]  vheight_lu 1
srp0    18
mirp[rp0,rnd,grey]  vheight_shoot 13
mdrp[grey]  10
mirp[rp0,min,rnd,grey]  vstem_113   5
mdrp[grey]  9
IUP[y]
""",

    #maiyamok
    "uni0E46": """
f_deltap    41 9+8 
srp0    40
mdrp[rp0,rnd,grey]  12
mdrp[grey]  9
mirp[min,rnd,grey]  headstem 31
mirp[rp0,rnd,grey]  headstem_plus_hole 37
mdrp[grey]  18
#
srp0    41
mirp[rp0,rnd,grey]  gap_246 26
mirp[min,rnd,grey]  hstem 1
srp2    18
sloop   6
ip  21 22 23 5 6 7
#
f_deltap    12 20-8 31 20-8
IUP[x]
#
SVTCA[y-axis]
srp0    40
mirp[rnd,grey]  vheight_lu  1
mirp[rp0,rnd,grey]  vheight 21
alignrp 23
mdrp[min,rnd,grey]  7
shp[rp2]    5
mdrp[rp0,rnd,grey]  22
mdrp[rp0,min,rnd,grey]  6
mdrp[rp0,rnd,white] 9
mirp[min,rnd,grey] headstem 34
mirp[rp0,rnd,grey] headdia 15
f_deltap    15 26+8  15 29-8 15 30-8 15 31-8 15 34-8
mirp[min,rnd,grey] headstem 28
IUP[y]
""",

    #maitaikhu
    "uni0E47": """
srp0    64
mirp[rp0,rnd,grey]  gap_246 49
ip  24
mirp[min,rnd,grey]  headstem_small 55
mirp[rp0,rnd,grey]  headdia_small 43
mirp[min,rnd,grey]  headstem_small 61
mdrp[rnd,grey]  41
srp0    49
mdrp[rp0,rnd,grey]  10
ip  34
ip  7
mdrp[min,rnd,grey]  31  
mdap[rnd]   24
mdrp[min,rnd,grey]  17
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap    0 9+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8   0 19-8   0 21-8   0 24-8
alignrp     7
mdrp[min,rnd,grey]  41
mirp[min,rnd,grey]  headstem_small 52
mirp[rp0,rnd,grey]  headdia_small 46
sloop   3
ip      38 34 3
mirp[min,rnd,grey]  headstem_small 58
mdrp[rp0,rnd,white] 27
mdrp[min,rnd,grey]  14
mdrp[rnd,grey]  21
IUP[y]
""",

    #maiek
    "uni0E48": """
mdap[rnd]   6
f_deltap    6 13+8   6 14+8  6 21+8   6 22+8   6 23+8  6 24+8   
mdrp[min,rnd,grey]  5
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
f_deltap    0 9+8   0 10+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8   0 17+8   0 21-8   0 22-8   0 23+8   0 27+8   0 28+8   0 38+8   0 39+8   0 40+8   0 42+8
f_deltap    0 9+8   0 11+8   0 12+8   0 13+8   0 14+8
IUP[y]
""",

    #maiek
    "uni0E48.low": """
mdap[rnd]   6
mdrp[min,rnd,grey]  5
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
f_deltap    0 9+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8   0 19-8   0 21-8   0 24-8
mdrp[min,rnd,grey]  6
IUP[y]
""",

    #maitho
    "uni0E49": """
mdap[rnd]   23
f_deltap    23 13+8   23 14+8  23 21+8   23 22+8   23 23+8  23 24+8   
mdrp[grey]  19
mdrp[rp0,rnd,grey]  13
mdrp[rnd,grey]  7
ip  35
ip  29
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
f_deltap    0 9+8   0 10+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8   0 17+8   0 21-8   0 22-8   0 23+8   0 27+8   0 28+8   0 38+8   0 39+8   0 40+8   0 42+8
f_deltap    0 9+8   0 11+8   0 12+8   0 13+8   0 14+8
mdrp[rp0,rnd,grey]  3
ip  1
ip  16
mdrp[rnd,grey]  10
ip  32
ip  26
mdrp[grey]  21
IUP[y]
""",

    #maitho
    "uni0E49.low": """
mdap[rnd]   22
mdrp[min,rnd,grey]  18
mdrp[rp0,rnd,grey]  12
mirp[min,rnd,grey]  headstem_small 28
mirp[rp0,rnd,grey]  headdia_small 6
mirp[min,rnd,grey]  headstem_small 34
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
f_deltap    0 9+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8   0 19-8   0 21-8   0 24-8
mdrp[min,rnd,grey]  1
mdrp[rp0,rnd,grey]  3
ip  15
mirp[min,rnd,grey]  headstem_small 25
mirp[rp0,rnd,grey]  headdia_small 9
mirp[min,rnd,grey]  headstem_small 31
mdrp[rnd,grey]  20
IUP[y]
""",

    #maitri
    "uni0E4A": """
mdap[rnd]   48
f_deltap    48 13+8   48 14+8  48 21+8   48 22+8   48 23+8  48 24+8   
mdrp[rp0,rnd,grey]  34
ip  40
mdrp[grey]  4
mdrp[rp0,rnd,grey]  26
mdrp[rp0,rnd,grey]  14
mdrp[rnd,grey]  20
f_deltap    20 13-8 20 14-8 20 15-8 20 16-8 20 17-8 
ip  60
ip  54
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
f_deltap    0 9+8   0 10+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8   0 17+8   0 21-8   0 22-8   0 23+8   0 27+8   0 28+8   0 38+8   0 39+8   0 40+8   0 42+8
f_deltap    0 9+8   0 11+8   0 12+8   0 13+8   0 14+8
alignrp     23
mdrp[rp0,rnd,grey]  17
ip  57
ip  51
ip  37
mdrp[rp0,rnd,grey]  29
alignrp 31
ip  9
ip  7
ip  8
ip  30
mdrp[grey]  45
IUP[y]
""",

    #maitri
    "uni0E4A.low": """
mdap[rnd]   48
mdrp[rp0,rnd,grey]  34
ip  40
mdrp[grey]  4
mdrp[rp0,rnd,grey]  20
mirp[min,rnd,grey]  headstem_small 54
mirp[rp0,rnd,grey]  headdia_small 14
mirp[min,rnd,grey]  headstem_small 60
mdrp[grey]  26
f_deltap    14 9-8 14 10-8 
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
f_deltap    0 9+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8   0 19-8   0 21-8   0 24-8
alignrp     23
mirp[min,rnd,grey]  headstem_small 51
mirp[rp0,rnd,grey]  headdia_small 17
mirp[min,rnd,grey]  headstem_small 57
mdrp[rp0,rnd,grey]  31
alignrp     29
mdrp[min,rnd,grey]  7
shp[rp2]    9
mdrp[grey]  45
IUP[y]
""",

    #maichattawa
    "uni0E4B": """
mdap[rnd]   7
f_deltap    7 13+8   7 14+8  7 21+8   7 22+8   7 23+8  7 24+8   
mdrp[grey]  9
mdrp[grey]  0
ip  8
ip  11
mdrp[rp0,min,rnd,grey]  6
mdrp[grey]  4
mdrp[grey]  1
ip  5
ip  2
IUP[x]
SVTCA[y-axis]
mdap[rnd]   10
f_deltap    0 9+8   0 10+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8   0 17+8   0 21-8   0 22-8   0 23+8   0 27+8   0 28+8   0 38+8   0 39+8   0 40+8   0 42+8
f_deltap    0 9+8   0 11+8   0 12+8   0 13+8   0 14+8
alignrp 2
mdrp[grey]  0
mdrp[rp0,min,rnd,grey]  9
alignrp 5
mdrp[grey]  7
IUP[y]
""",

    #maichattawa
    "uni0E4B.low": """
mdap[rnd]   7
mdrp[grey]  9
mdrp[grey]  0
ip  8
ip  11
mdrp[rp0,rnd,grey]  6
mdrp[grey]  4
mdrp[grey]  1
ip  5
ip  2
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   10
f_deltap    10 9+8   10 10+8   10 11+8   10 12+8   10 13+8   10 14+8   10 15+8   10 16+8   10 19-8   10 21-8   10 24-8
alignrp 2
mdrp[grey]  0
mdrp[rp0,rnd,grey]  9
alignrp 5
mdrp[grey]  7
IUP[y]
""",

    #thanthakhat
    "uni0E4C": """
mdap[rnd]   15
f_deltap    15 13+8   15 14+8  15 21+8   15 22+8   15 23+8  15 24+8   
mdrp[grey]  11
mdrp[rnd,grey]  3
ip  27
ip  21
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
f_deltap    0 9+8   0 10+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8   0 17+8   0 21-8   0 22-8   0 23+8   0 27+8   0 28+8   0 38+8   0 39+8   0 40+8   0 42+8
f_deltap    0 9+8   0 11+8   0 12+8   0 13+8   0 14+8
mdrp[rp0,rnd,grey]  6
ip  13
ip  24
ip  18
mdrp[grey]  9
IUP[y]
""",

    #thanthakhat
    "uni0E4C.low": """
mdap[rnd]   11
mdrp[grey]  9
mdrp[rp0,rnd,grey]  15
mirp[min,rnd,grey]  headstem_small 21
mirp[rp0,rnd,grey]  headdia_small 3
mirp[min,rnd,grey]  headstem_small 27
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
f_deltap    0 9+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8   0 19-8   0 21-8   0 24-8
mirp[min,rnd,grey]  headstem_small 18
mirp[rp0,rnd,grey]  headdia_small 6
mirp[min,rnd,grey]  headstem_small 24
mdrp[grey]  9
IUP[y]
""",

    #nikhahit
    "uni0E4D": """
mdap[rnd]   9
mirp[min,rnd,grey]  w_129 15
mdrp[rp0,rnd,grey]  3
mirp[min,rnd,grey]  w_129 21
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
f_deltap    0 9+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8   0 19-8   0 21-8   0 24-8   
mirp[min,rnd,grey]  w_129 12
mdrp[rp0,rnd,grey]  6
mirp[min,rnd,grey]  w_129 18
IUP[y]
""",

    #nikhahit
    "uni0E4D.high": """
MDAP[rnd]   0
mdrp[rp0,rnd,grey]  9
mdrp[min,rnd,grey]  15
mdrp[rp0,rnd,grey]  3
mdrp[min,rnd,grey]  21
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[min,rnd,grey]  12
mdrp[rp0,rnd,grey]  6
mdrp[min,rnd,grey]  18
IUP[y]
""",

    #yamakkan
    "uni0E4E": """
mdap[rnd]   16
mdrp[min,rnd,grey]  21
mdrp[rp0,rnd,grey]  26
mdrp[min,rnd,grey]  10
mdrp[rp0,rnd,grey]  45
mdrp[min,rnd,grey]  3
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
f_deltap    0 9+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8   0 19-8   0 21-8   0 24-8
mdrp[min,rnd,grey]  48
mdrp[rp0,rnd,grey]  42
mdrp[min,rnd,grey]  6
mdrp[rp0,rnd,grey]  23
mdrp[min,rnd,grey]  13
IUP[y]
""",

    #fongman
    "uni0E4F": """
SRP0    52
mirp[rp0,rnd,grey]  gap_152 4
mdrp[rp0,rnd,grey]  31
ip  25
mdrp[rp0,rnd,grey]  37
ip  49
ip  43
mdrp[rp0,rnd,grey]  12
ip  19
mirp[rnd,grey]  gap_152 53
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   52
mirp[rp0,rnd,grey]  vheight_lo  0
mdrp[rp0,rnd,grey]  28
ip  16
mdrp[rp0,rnd,grey]  34
ip  40
ip  46
mdrp[rp0,rnd,grey]  8
ip  22
IUP[y]
""",

    #thaidigit_zero
    "uni0E50": """
f_deltap    29 10+8  29 11+8
SRP0    28
mirp[rp0,rnd,grey]  gap_152 4
mirp[min,rnd,grey]  hstem_num 25
#
srp0    29
mirp[rp0,rnd,grey]  gap_152 12
mirp[min,rnd,grey]  hstem_num 19
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mirp[min,rnd,grey]  vstem_num 16
mdrp[rp0,rnd,grey]  8
mirp[min,rnd,grey]  vstem_num 22
IUP[y]
""",

    #thaidigit_one
    "uni0E51": """
f_deltap    51 10+8   51 12+8   51 16+8   51 17+8  51 22+8  51 23+8   51 28+8    
srp0    50
mdrp[rp0,rnd,grey]  30
mdrp[grey]  5
#
srp0    51
mdrp[rp0,rnd,grey]  24
mdrp[grey]  9
#
mdrp[rp0,rnd,grey]  47
mdrp[rnd,grey]  41
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[grey]  15
mdrp[rnd,grey]  38
f_deltap    38 24-8
ip  33
mdrp[rp0,rnd,grey]  6
mdrp[rnd,grey]  44
ip  27
IUP[y]
""",

    #thaidigit_two
    "uni0E52": """
f_deltap    83 10+8   
SRP0    82
mirp[rp0,rnd,grey]  gap_170 4
ip  7
mdrp[min,rnd,grey]  12
#
srp0    83
mirp[rp0,rnd,grey]  gap_152 79
mdrp[min,rnd,grey]  19
#
srp1    12
sloop   2
ip      49 43
mdap[rnd]   49
mdrp[grey]  67
mdap[rnd]   43
mdrp[grey]  28
mdrp[rp0,rnd,grey]  61
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[min,rnd,grey]  16
mdrp[rp0,rnd,grey]  70
alignrp 76
mdrp[rnd,grey]  9
mdrp[min,rnd,grey]  46
ip  73
ip  25
shp[rp2]    22
mdrp[rp0,rnd,grey]  64
f_deltap    64 16+8   64 19+8    64 26+8   64 29+8  
alignrp     34
mdrp[min,rnd,grey]  58
IUP[y]
""",

    #thaidigit_three
    "uni0E53": """
f_deltap    73 9+8  73 21+8  
SRP0    72
mdrp[rp0,rnd,grey]  57
mdrp[grey]  3
mdrp[rnd,grey]  69
f_deltap    69 9-8  69 10-8  69 15-8  69 16-8   69 21-8   
ip  63
#
srp0    73
mdrp[rp0,rnd,grey]  28
mdrp[grey]  13
mdrp[rp0,rnd,grey]  51
mdrp[grey]  36
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
alignrp     19
alignrp     42
mdrp[min,rnd,grey]  66
mdrp[rp0,rnd,grey]  6
alignrp 10
mdrp[grey]  54
shp[rp2]    31
IUP[y]
""",

    #thaidigit_four
    "uni0E54": """
f_deltap    59 10+8   59 11+8   
srp0    58
mdrp[rp0,rnd,grey]  30
mdrp[grey]  9
#
srp0    58
mdrp[rp0,rnd,grey]  16
mdrp[grey]  23
mdrp[rp0,rnd,grey]  44
mdrp[rnd,grey]  38
ip  50
ip  35
mdrp[rnd,grey]  55
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
alignrp     6
mdrp[min,rnd,grey]  55
srp0    6
mdrp[min,rnd,grey]  33
mdrp[rnd,grey]  18
mdrp[rp0,rnd,grey]  41
mdrp[min,rnd,grey]  47
ip  50
mdrp[grey]  13
mdrp[grey]  26
IUP[y]
""",

    #thaidigit_five
    "uni0E55": """
f_deltap    86 10+8   86 11+8
srp0    85
mdrp[rp0,rnd,grey]  45
mdrp[grey]  9
#
srp0    86
mdrp[rp0,rnd,grey]  26
mdrp[grey]  33
mdrp[rp0,rnd,grey]  21
mdrp[min,rnd,grey]  76
mdrp[rp0,rnd,grey]  15
sloop   3
ip  12 23 39
mdrp[min,rnd,grey]  82
srp0    26
mdrp[rp0,rnd,grey]  59
mdrp[rnd,grey]  53
ip  65
ip  50
mdrp[rnd,grey]  70
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
alignrp     6
mdrp[min,rnd,grey]  70
srp0    6
mdrp[min,rnd,grey]  48
mdrp[rp0,rnd,grey]  56
mdrp[rnd,grey]  62
ip  65
mdrp[grey]  28
mdrp[rp0,rnd,grey]  18
mdrp[min,rnd,grey]  79
mdrp[rp0,rnd,grey]  73
mdrp[grey]  39
ip  23
ip  12
IUP[y]
""",

    #thaidigit_six
    "uni0E56": """
f_deltap    64 9+8  64 14+8   
SRP0    63
mdrp[rp0,rnd,grey]  36
mdrp[grey]  42
mdrp[min,rnd,grey]  51
mdrp[rp0,rnd,grey]  3
mdrp[min,rnd,grey]  9
ip  12
#
srp0    64
mdrp[rp0,rnd,grey]  18
mdrp[grey]  60
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[min,rnd,grey]  15
mdrp[rnd,grey]  6
ip  12
mdrp[rp0,rnd,grey]  57
mdrp[rnd,grey]  45
mdrp[grey]  54
mdrp[rp0,min,rnd,grey]  21
mdrp[grey]  27
IUP[y]
""",

    #thaidigit_seven
    "uni0E57": """
SRP0    85
mdrp[rp0,rnd,grey]  34
mdrp[grey]  51
mdrp[rp0,rnd,grey]  45
mdrp[rnd,grey]  39
ip  37
#
srp0    86
mdrp[rp0,rnd,grey]  69
mdrp[grey]  82
mdrp[rnd,grey]  76
mdrp[rp0,rnd,grey]  9
mdrp[grey]  63
mdrp[rp0,rnd,grey]  28
mdrp[grey]  17
ip  57
ip  15
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
alignrp     48
mdrp[min,rnd,grey]  42
ip  37
ip  66
mdrp[rp0,rnd,grey]  54

ip  57
ip  15
srp1    42
ip  20
mdrp[rnd,grey]  82
mdrp[min,rnd,grey]  34
shp[rp2]    12
mdrp[rnd,grey]  79
IUP[y]
""",

    #thaidigit_eight
    "uni0E58": """
f_deltap    67 16+8 
SRP0    66
mdrp[rp0,rnd,grey]  40
mdrp[grey]  11
mdrp[rnd,grey]  8
ip  43
#
srp0    67
mdrp[rp0,rnd,grey]  22
mdrp[grey]  29
mdrp[rp0,rnd,grey]  63
mdrp[min,rnd,grey]  57
ip  54
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp     8
mdrp[min,rnd,grey]  51
mdrp[rp0,rnd,grey]  60
ip  54
srp0    8
mdrp[rp0,rnd,grey]  46
ip  43
mdrp[min,rnd,grey]  5
srp0    0
mdrp[rp0,rnd,grey]  14
mdrp[rnd,grey]  26
mdrp[grey]  19
mdrp[rp0,grey]  37
mdrp[grey]  32
IUP[y]
""",

    #thaidigit_nine
    "uni0E59": """
SRP0    72
mdrp[rp0,rnd,grey]  54
mdrp[grey]  3
mdrp[rp0,rnd,grey]  38
mdrp[grey]  9
ip  6
#
srp0    73
mdrp[rp0,rnd,grey]  20
mdrp[grey]  27
mdrp[rp0,rnd,grey]  69
ip  43
mdrp[min,rnd,grey]  63
ip  60
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[min,rnd,grey]  57
mdrp[rnd,grey]  66
ip  60
mdrp[rp0,rnd,grey]  41
mdrp[grey]  46
ip  6
srp0    0
mdrp[rp0,rnd,grey]  12
mdrp[rnd,grey]  24
mdrp[grey]  17
mdrp[rp0,grey]  35
mdrp[grey]  30
IUP[y]
""",

#    #angkhankhu
    "uni0E5A": """
f_deltap    49 9+8   49 10+8   49 11+8   49 12+8   49 13+8   
SRP0    48
mirp[rp0,rnd,grey]  gap_102 21
mdrp[min,rnd,grey]  32
#
srp0    49
mirp[rp0,rnd,grey]  gap_246 47
mirp[min,rnd,grey]  hstem 1
mdrp[rp0,rnd,grey]  43
alignrp 6
mirp[min,rnd,grey]  hstem 8
srp1 32
sloop   3
ip  26 27 39
mdap[rnd]   39
mdrp[min,rnd,grey]  14
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
alignrp     8
mdrp[rp0,rnd,grey]  46
alignrp     42
mdrp[min,rnd,grey]  4
shp[rp2]    11
mdrp[rp0,rnd,grey]  24
mdrp[min,rnd,grey]  29
mdrp[rp0,rnd,grey]  18
mdrp[min,rnd,grey]  35
IUP[y]
""",

#    #khomut
    "uni0E5B": """
SRP0    70
mirp[rp0,min,rnd,grey]  headhole    3
mirp[rp0,min,rnd,grey]  hstem   26
mdrp[rp0,min,rnd,grey]  15
mirp[min,rnd,grey]  headstem   67
mdrp[rp0,min,rnd,grey]  9
mdrp[min,rnd,grey]  61
mdrp[min,rnd,grey]  20
mdrp[rp0,min,rnd,grey]  32
mdrp[min,rnd,grey]  33
mdrp[rp0,min,rnd,grey]  55
mdrp[min,rnd,grey]  54
mdrp[rp0,min,rnd,grey]  34
mdrp[rp0,min,rnd,grey]  37
mdrp[min,rnd,grey]  38
mdrp[rp0,min,rnd,grey]  52
mdrp[min,rnd,grey]  51
mdrp[rp0,min,rnd,grey]  39
mdrp[rp0,min,rnd,grey]  42
mdrp[min,rnd,grey]  43
mdrp[rp0,min,rnd,grey]  49
mdrp[rp0,min,rnd,grey]  46
mdrp[min,rnd,grey]  71
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   70
mirp[rp0,rnd,grey]  vheight_lo  0
mirp[rp0,min,rnd,grey]  vstem_113 29
mdrp[rp0,min,rnd,grey]  12
mirp[min,rnd,grey]  headstem 58
mirp[rp0,rnd,grey]  headdia 18
mdrp[min,rnd,grey]  20
mirp[min,rnd,grey]  headstem 64
mdrp[rp0,min,rnd,grey]  23
mirp[min,rnd,grey]  vstem_113 6
srp0    0
mdrp[rp0,min,rnd,grey]  55
alignrp     52
alignrp     49
alignrp     45
mdrp[min,rnd,grey]  54
shp[rp2]    51
mdrp[rp0,min,rnd,grey]  32
alignrp 37
alignrp 42
mdrp[rp0,min,rnd,grey]  33
alignrp 38
alignrp 43
srp0    45
mdrp[min,rnd,grey]  46
IUP[y]
""",


#    #CHAR_NAME
#    "uni0EXX": """
#SRP0    0
#
#IUP[x]
#SVTCA[y-axis]
#MDAP[rnd]   0
#
#IUP[y]
#""",


}

if __name__=="__main__":
    if sys.argv[1] == "--all":
        #$0 --all = ENCODE ALL CHARS
        sfd_file = os.path.basename(sys.argv[0]).split('.',1)[0] + '.sfd'
        print "Encoding all character in %s" % (sfd_file)
        dfont.inst_encode_all( sfd_file, pseudo_code_dict, cvt_dict )
    else:
        #$0 uni0E01 > x.txt = PRINT INSTRUCTION CODE OF uni0E01 TO x.txt
        print '\n'.join(dfont.inst_encode( pseudo_code_dict[sys.argv[1]], cvt_dict ))
