#!/usr/bin/env python
#Usage: $0 uni0E01 > code.txt
#or:    $0 --all

import os
import sys
import dfont

# cvt value
#NEW VALUE ***
#    "headdia":          257,    #384
#    "headstem":         258,    #120
#    "w_896":            256,    #896    =ko_kai
cvt_dict = {
    "w_1001":           71,     #1001   =
    "w_60":             260,    #60
    "w_123":            15,     #123
    "w_150":            78,     #150
    "w_156":            288,    #156
#
    "base":             10,     #0
    "hstem":            39,     #184
#
    "vstem":            122,    #106    =straight vstem
    "vstem_98":         143,    #98     =curve vstem
    "sarastem":         90,     #127
#
    "headdia":          127,    #344
    "headhole":         78,     #150   
    "headstem":         45,     #98    
    "headstem_plus_hole":   48,  #250
    "headstem_plus":    42,     #102   
    "headdia_plus":     188,    #410   
    "hstem_head":       89,     #164   
#
    "hnext_1":          111,    #469    =next spline of sho_sher
    "hnext_2":          68,     #479    =next spline of yo_ying
#
    "vheight":          156,    #1063   =normal height 
    "vheight_shoot":    140,    #1092   =overshoot height
    "vheight_plus":     203,    #1073   =normal height 
    "vheight_hi":       49,     #1208   =ko 
    "vheight_hi_kho":   47,     #1204   =kho 
    "vheight_po":       113,    #1556   =po_pla, fo_fa
    "vheight_o":        179,    #1638   =sara_o, sara_i
    "vheight_lo":       202,    #10 
    "vheight_shoot_lo": 96,     #29 
    "vheight_lu":       188,    #410    =lo_lu
#
    "vheight_below_do": 176,    #410
    "vheight_num":      209,    #905
    "vheight_sara1":    250,    #1262
#
    "head_diff":        131,    #254    =head of character: bo,po
    "beak_diff":        148,    #84     =beak of ko,tho
    "beak_diff_2":      38,     #340    =beak of ko,tho
#
    "gap_25":         177,    #25     =front/rear spacing
    "gap_61":         72,     #61
    "gap_74":         85,     #74
    "gap_102":          42,     #102
    "gap_125":        91,     #125
    "gap_141":        92,     #141
    "gap_150":          78,     #150
    "gap_160":          12,     #160
    "gap_170":          74,     #170
    "gap_188":          4,      #188
    "gap_203":          16,     #203
    "gap_217":          23,     #217
    "gap_229":          14,     #229
    "gap_266":          97,     #266
    "gap_377":          198,    #377
#special
    "serif":            89,     #164
    "special_2":        88,     #20
}

##SKELETON
#DEPRECATED, USE shpix INSTEAD
##v-d: top vertical stem delta shift
##f_deltap   y 9+4  y 10+4  y 11+4  y 12+4  y 13+4  y 14+4  y 15+4  y 16+4  
#
##s-d: serif delta shift
##top
##f_deltap   y 9-4  y 10-4  y 11-4  y 12-4  y 13-4  y 14-4  y 15-4  y 16-4  
##bottom
##f_deltap   y 9+4  y 10+4  y 11+4  y 12+4  y 13+4  y 14+4  y 15+4  y 16+4  
#END DEPRECATED

#hd: head interpolate at 29 30 31 32 ppem
#f_deltap    y1 29-4 y2 29+4   y1 30-4 y2 30+4   y1 31-4 y2 31+4   y1 32-4 y2 32+4

#hd2: head delta shift - y
#f_deltap    y 9+8  y 10+8   y 11+8   y 12+8   y 13+4    y 14+8   y 15+8   y 16+8   y 21-8   y 27-8   y 28-8   y 37+8   y 44-8   y 49+8

#SHPIX
#vd: top vertical stem shift
#shpix  16 y

#sd: serif delta shift, use only middle serif
#shpix  -16 y 

#r1: sara level 1
#f_deltap    y 9+8   y 11+8   y 12+8   y 13+8   y 14+8   y 15+8   y 16+8   
######### PSUEDO-CODE ##########
pseudo_code_dict = {
    #ko_kai
    "uni0E01": """
f_deltap    24 9+8   24 15-8   24 16-8   24 19+8   
srp0            23
mirp[rp0,rnd,white]  gap_229 13
mdrp[grey]  8
mdrp[grey]      15
mirp[rp0,min,rnd,grey]  hstem  11
mdrp[grey]      9
#
srp0            24
mirp[rp0,rnd,white] gap_170 21
mirp[min,rnd,grey]  hstem   1
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]           1
alignrp             13
mirp[rp0,rnd,grey]  vheight_shoot    18
ip  15
mirp[min,rnd,grey]  vstem_98  5
shpix   8  5
mdap[rnd]   15
alignrp     10
mirp[min,rnd,grey]  vstem   8
shpix   -16 8
IUP[y]
""",

    #kho_khai
    "uni0E02":  """
f_deltap    59 11+8  59 15-8  59 18+8  59 20+8  59 22+8  59 36+8
srp0    58
mdrp[rp0,rnd,grey]  20
f_deltap    20 12-8   20 13-8    20 27-8
mdrp[rnd,grey]  14
mirp[min,rnd,grey]  headstem 49
mirp[rp0,rnd,grey]  headstem_plus_hole 55
f_deltap    55 11+8   55 12+8  55 13+8  
mdrp[grey]  26
f_deltap    26 9-3   26 10-3   26 16+1
srp0    20
mdrp[rp0,rnd,grey]  9
mdrp[grey]  32
mdrp[rp0,rnd,grey]  3
f_deltap     3 17-8   3 29-8   3 31-8   3 32-8   3 36-8   3 37-8   3 38-8   3 39-8
mirp[min,rnd,grey]  hstem 37
mdrp[grey]  1
#
srp0    59
mirp[rp0,rnd,white] gap_170 43
mirp[min,rnd,grey]  hstem 41
#
f_deltap    9 14+1  9 15+2  9 16+4 9 32+4 
shpix   -8 20
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mirp[min,rnd,grey]  vstem 39
shp[rp2]            3
mirp[rp0,rnd,grey]  vheight 29
alignrp     43
mirp[min,rnd,grey]  headstem 12
mdrp[rp0,rnd,grey]  16
f_deltap    16 21+8   16 22+8   
mdrp[rp0,rnd,grey]  23
f_deltap    23 9+8   23 10+8   23 21+8   23 27+8   23 28+8    
mirp[min,rnd,grey]  headstem 46
mirp[rnd,grey]  headstem_plus_hole 52
shpix   8  12
shpix   8   23
shpix   -8  16
f_deltap   16 15-1   16 16-2
IUP[y]
""",

    #kho_khuad
    "uni0E03": """
f_deltap    62 9+8  62 11+8   62 15-8   62 18+8   62 19+8   62 21+8   62 25-8   62 26+8   62 31+8   62 35+8   
srp0    61
mdrp[rp0,rnd,grey]  21
f_deltap    21 12-8
mdrp[grey]      16
f_deltap    16 16-4
mirp[min,rnd,grey]  headstem 52
mirp[rp0,rnd,grey]  headstem_plus_hole 58
f_deltap    58 11+8   58 12+8   
mdrp[grey]  27
srp0    21
mdrp[rp0,rnd,grey]  9
mdrp[grey]  35
srp2    16
sloop   6
ip  30 31 32 12 13 14
mdrp[rp0,rnd,grey]  3
mdap[rnd]   3
f_deltap    3 17-8   3 24-8   3 26-8   3 27-8   3 28-8   3 29-8   3 36-8   3 40-8   
mirp[min,rnd,grey]  hstem 40
mdrp[grey]  1
f_deltap    21 13-8
shpix   -8  21
shpix   -16 58
shpix   -16 16
shpix   16   9
#
srp0    62
mirp[rp0,rnd,white] gap_170 46
mirp[min,rnd,grey]  hstem 44
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]           0
mirp[min,rnd,grey]  vstem 42
shp[rp2]    3
mirp[rp0,rnd,grey]  vheight 30
alignrp     32
alignrp     45
mdrp[min,rnd,grey]  14
f_deltap    14 26+6   14 27+6   14 28+6   14 29+6   14 30+6   14 43+8   14 44+8   14 45+8   14 46+8   14 47+8   14 48+8   14 49+8   14 50+8
shpix   8  14
shp[rp2]    12
mdrp[rp0,min,rnd,grey]  31
mdrp[rp0,min,rnd,grey]  13
mdrp[rp0,rnd,white]     18
f_deltap    18 9+8    18 14+8   18 15+8
mirp[min,rnd,grey]  headstem 55
mirp[rp0,rnd,grey]  headdia 24
f_deltap    24 10+8   24 14-8   24 15-8   24 16-8   24 21+8   24 27+8   24 28+8   24 29-8   24 30-8   24 31-8   24 32-8   24 37-8   24 38-8
mirp[min,rnd,grey]  headstem 49
shpix   -8  18
shpix   8   24
srp2    3
ip  5
ip  39
f_deltap    31 11-4   31 12-4  31 13-4  31 14-4   31 15-4   18 16-2  
IUP[y]

""",

    #kho_kwai
    "uni0E04": """
f_deltap    47 9+8   47 15-8   47 16-8   47 17+8   47 18+8   47 20+8   47 24-8   47 32+8   
srp0    46
mirp[rp0,rnd,white] gap_203 24
mdrp[grey]  27
mirp[rp0,min,rnd,grey]  hstem 22
mdrp[grey]  8
mirp[min,rnd,grey]  headstem 43
f_deltap    43 25+8   43 37-8   43 38-8   43 39-8 
mirp[rp0,rnd,grey]  headdia 16
f_deltap    16 9+4   16 10+4   16 11+6   16 12+8   16 13+4   16 14+8   16 15+8   16 16+8   16 21-8   16 25+8   16 28-8  16 29+8   16 30+8  16 31+8   16 32+8  16 33+8   16 45+8   16 46+8 
mirp[min,rnd,grey]  headstem 37
shpix   -8 16
shpix   -16 43
#
srp0                47
mirp[rp0,rnd,white] gap_170 33
mirp[min,rnd,grey]  hstem 1
IUP[x]
f_deltap    12 14+7 15 14-5 17 14-5   12 15+7  15 15-5  17 15-5
#
SVTCA[y-axis]
MDAP[rnd]           0
ALIGNRP             23
MIRP[rp0,rnd,grey]  vheight_shoot  30
ip  13
MIRP[min,rnd,grey]  vstem_98  5
shpix   8 5
mdap[rnd]  13
f_deltap    13 9-4   13 10-4  13 16-8
mdrp[grey]  10
mdrp[grey]  22
mdrp[grey]  25
f_deltap    10 14-4 22 14+4   10 15-4 22 15+4   10 16-4 22 16+4
MIRP[min,rnd,grey]  headstem  40
MIRP[rp0,rnd,grey]  headdia  19
f_deltap    19 9-4   19 10-8   19 11-8   19 12-8   19 13-4   19 14-8   19 15-8   19 16-8   19 21+8  19 27+8   19 28+8   19 29-8   19 30-8   19 31-8   19 32-8   19 37-8  19 38-8
MIRP[min,rnd,grey]  headstem  34
shpix   -8  13
shpix   8   19
IUP[y]
""",

    #kho_kon
    "uni0E05": """
f_deltap    51 9+8   51 15-8   51 16-8   51 17+8   51 18+8   51 20+8   51 24-8   51 32+8   
srp0                50
mirp[rp0,rnd,white] gap_203 26
mdrp[grey]  29
mirp[rp0,rnd,grey]  hstem 24
mdrp[grey]  10
mirp[min,rnd,grey]  headstem 47
f_deltap    47 25+8  47 29-8   47 30-8  47 31-8  47 32-8   47 37-8   47 38-8   47 39-8  47 45-8   47 46-8  
mirp[rp0,rnd,grey]  headdia 18
f_deltap    18 9+4   18 10+4   18 11+6   18 12+8   18 13+4   18 14+8   18 15+8   18 16+8   18 21-8   18 25+8   18 28-8   18 33+8   
mirp[min,rnd,grey]  headstem 41
shpix   -8 18
shpix   -16 47
#
srp0    51
mirp[rp0,rnd,white] gap_170 37
mirp[min,rnd,grey]  hstem 1
srp1    10
sloop   6
ip  32 33 34 5 6 7
IUP[x]
f_deltap    14 14+7 17 14-4 19 14-4    14 15+7 17 15-4 19 15-4
#
SVTCA[y-axis]
MDAP[rnd]           0
ALIGNRP             25
MIRP[rp0,rnd,grey]  vheight_shoot  32
alignrp             34
MIRP[min,rnd,grey]  vstem_98  7
shpix   8 7
shp[rp2]    5 
mdrp[rp0,min,rnd,grey]  33
mdrp[rp0,grey]  6
shpix   -24 6
mdrp[rp0,min,rnd,white]   15
mdap[rnd]   15
f_deltap    15 9+8   15 10+8
mdrp[grey]  12
mdrp[grey]  24
mdrp[grey]  27
f_deltap    12 14-4 24 14+4   12 15-4  24 15+4   12 16-4 24 16+4
MIRP[min,rnd,grey]  headstem  44
MIRP[rp0,rnd,grey]  headdia  21
f_deltap    21 9-8   21 10-8   21 11-8   21 12-8   21 13-4   21 14-8   21 15-8   21 16-8   21 21+8   21 27+8  21 28+8   21 29-8   21 30-8   21 31-8   21 32-8   21 37-8   21 38-8
MIRP[min,rnd,grey]  headstem  38
f_deltap    33 9-4 6 9-4  33 10-4 6 10-4   33 11-4 6 11-4  33 12-4 6 12-4  33 13-4 6 13-4
shpix   -8  15
shpix   8   21
f_deltap    6 12-4  6 13-4  6 14-6  6 15-4  6 16-4 6 17-4  6 18-4  6 19-4 
IUP[y]
""",

    #kho_rakhang
    "uni0E06": """
f_deltap    87 9+8  87 10+8  87 15-8  87 19+8  87 27+8  
srp0        86
mdrp[rp0,rnd,grey]  32
f_deltap    32 12-8   32 13-8  
mdrp[grey]  27
f_deltap    27 16-6  27 17-6
mirp[min,rnd,grey]  headstem 65
mirp[rp0,rnd,grey]  headstem_plus_hole 71
f_deltap    71 12+8
mdrp[grey]  38
f_deltap    38 11+8   38 13+8   38 16-4   38 17-4   38 21-4
srp0    32
mdrp[rp0,rnd,grey]  20
f_deltap    20 25-8   20 40-8 
mdrp[grey]  46
srp2    27
sloop       6
ip          41 42 43 23 24 25
mdrp[rp0,rnd,grey] 14
mdap[rnd]   14
f_deltap    14 17-8  14 19+8   14 20+8   14 23+8   14 26-8   14 27-8   14 28-8 
mirp[rp0,min,rnd,grey]  hstem 51
alignrp     3
mdrp[rp0,rnd,grey]  9
mirp[min,rnd,grey]  headstem 83
mirp[rnd,grey]  headstem_plus_hole 77
shpix   16 20
shpix   -8 32
shpix   8 9
shpix   -16 71
shpix   -16 27
f_deltap    9 12-4   9 13+4
#
srp0        87
mirp[rp0,rnd,white]  gap_170 59
mirp[min,rnd,grey]  hstem 57
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp     6
mirp[min,rnd,grey]  vstem 54
mirp[rp0,rnd,grey]  vheight 41
alignrp     43
alignrp     59
mdrp[min,rnd,grey]  25
shpix   8   25
shp[rp2]    23
mdrp[rp0,min,rnd,grey]  42
mdrp[rp0,min,rnd,grey]  24
mdrp[rp0,rnd,white]  29
f_deltap    29 9+8   29 10+8   29 11+8   29 14+8   29 15+8   
mirp[min,rnd,grey]  headstem 68
mirp[rp0,rnd,grey]  headdia 35
f_deltap    35 11-8   35 14-8   35 15-8   35 16-8   35 21+8   35 28+8  35 29-8  35 30-8  35 31-8  35 32-8 
mirp[min,rnd,grey]  headstem 62
srp0    6
mirp[min,rnd,grey]  headstem 74
mirp[rp0,rnd,grey]  headdia 12
f_deltap    12 9+8   12 10+8   12 11+8   12 12+8   12 14+8   12 15+8   12 16+8   12 21-8   12 26-8   12 27-8  12 28-8   12 37+8   
ip      52
mirp[min,rnd,grey]  headstem 80
srp0    52
mdrp[grey]  3
srp1    35
srp2    3
ip  16
ip  50
shpix   -8 29
shpix   8 35
shpix   -8 12
shpix   8 6
f_deltap    29 14-3   29 15-3   29 16-3
f_deltap    80 29+4 74 29-4   80 30+4 74 30-4   80 31+4 74 31-4
IUP[y]
""",

    #ngo_ngu
    "uni0E07": """
f_deltap    35 9+8   35 18+8   35 31+8   
srp0    34
mirp[rp0,rnd,grey]  gap_25 2
mdrp[grey]  3
#
srp0    35
mirp[rp0,rnd,white]  gap_170 19
mdrp[grey]  4
mirp[rp0,min,rnd,grey]  hstem 7
mdrp[grey]  1
srp0    19
mirp[rp0,rnd,grey]  headdia_plus 13
#f_deltap    13 22-8   13 29-8   13 30-8  13 31-8   13 38-8  13 39-8  13 40-8 
mirp[min,rnd,grey]  headstem 31
f_deltap    13 12-4   13 13+4 
mirp[rnd,grey]  headstem_plus_hole 25
shpix   8   13
shpix   16   25
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mirp[min,rnd,grey]  vstem 4
mirp[rp0,rnd,grey]  vheight 16
mirp[min,rnd,grey]  headstem 28
mdrp[rp0,rnd,grey]  10
f_deltap    10 13-4  10 14-8   10 21+8   10 27+8   10 28+8   10 37-8   10 44+8   10 49-8   
mirp[min,rnd,grey]  headstem 22
srp2    1
ip      3
ip      2
shpix   -8  16
shpix   12   10
f_deltap    22 29-4 28 29+4      22 30-4 28 30+4      22 31-4 28 31+4      22 32-4 28 32+4   
IUP[y]
""",

    #jo_jan
    "uni0E08": """
f_deltap    50 14+8   50 18+8  50 19+8  50 31+8  50 33+8   
srp0    49
mirp[rp0,rnd,white] gap_102 8
mdrp[grey]  27
mirp[min,rnd,grey]  headstem 46
mirp[rnd,grey]  headstem_plus_hole 40
f_deltap    40 11-8   40 12-8   40 13-8 
mirp[rp0,rnd,grey]  headdia_plus 14
f_deltap    14 13-8
mirp[min,rnd,grey]  hstem 2
shpix   16  40
f_deltap    8 12-4 27 12-4   8 13-4 27 13-4
#
srp0    50
mirp[rp0,rnd,white]  gap_170 34
mirp[min,rnd,grey]  hstem 19
shpix   8 8
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  0
mirp[min,rnd,grey]  vstem 17
mirp[rp0,rnd,grey]  vheight_shoot 31
mdrp[grey]  28
mirp[rp0,min,rnd,grey]  vstem_98 23
shpix   8 23
mdrp[rp0,grey]  26
#f_deltap    26 9+2  26 10+2  26 11+2  
mdrp[rp0,rnd,white]  11
mdap[rnd]   11
f_deltap    11 12-8   11 14-8
mirp[min,rnd,grey]  headstem 43
mirp[rp0,rnd,grey]  headdia 5
f_deltap    5 9-8  5 10-8  5 11-8  5 12-8  5 13-4  5 14-8  5 15-8  5 16-8  5 21+8  5 27+8  5 28+8   5 37-8   5 44+8   5 49-8   
mirp[min,rnd,grey]  headstem 37
shpix   -8  11
shpix   16   5
f_deltap    37 29-4 43 29+4   37 30-4 43 30+4   37 31-4 43 31+4   37 32-4 43 32+4
IUP[y]
""",

    #cho_ching
    "uni0E09": """
f_deltap    70 9+8   70 11-8   70 14+8   70 16-8   70 18+8   70 19+8   70 29+8   
srp0    69
mirp[rp0,rnd,white] gap_74 7
f_deltap    7 12+8
mdrp[grey]  24
mirp[min,rnd,grey]  headstem 54
mirp[rnd,grey]  headstem_plus_hole 48
f_deltap    48 9+4  48 11-8  
mirp[rp0,rnd,grey]  headdia_plus 13
alignrp     0
mirp[min,rnd,grey]  hstem 1
shpix   8   7
shpix   16  48
f_deltap    7 12-4 24 12-4   7 13+4 24 13+4  
#
srp0    70
mirp[rp0,rnd,white] gap_203 31
f_deltap    31 17+8   31 26+8  31 27+8  
mirp[min,rnd,grey]  hstem 16
mdrp[rp0,rnd,grey]  36
f_deltap    36 9+4   36 10+4   36 29+8   36 30+8 
mirp[min,rnd,grey]  headstem 60
mirp[rp0,min,rnd,grey]  headdia 42
f_deltap    42 9-8   42 10-8   42 11-8   42 12-8   42 13-8   42 14-8   42 15-8   42 16-8   42 27+8   42 28+8    42 31-8   42 32-8   
mirp[min,rnd,grey]  headstem 66
shpix   -8 36
shpix   8 42
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp     40
mdrp[min,rnd,grey]  14
mirp[rp0,rnd,grey]  vheight_shoot  28
mdrp[grey]  25
mirp[rp0,min,rnd,grey]  vstem_98 20
shpix   8  20
mdrp[rp0,grey]  23
mdrp[rp0,rnd,white]  10
f_deltap    10 12-8   
mdap[rnd]   10
mirp[min,rnd,grey]  headstem 51
mirp[rp0,rnd,grey]  headdia 4
f_deltap    4 9-8   4 10-8   4 11-8   4 12-8   4 13-4   4 14-8   4 15-8   4 16-8   4 21+8   4 27+8   4 28+8   4 37-8    4 44+8   4 49-8
mirp[min,rnd,grey]  headstem 45
srp0    39
mirp[min,rnd,grey]  headstem 57
mirp[rp0,rnd,grey]  headdia 33
f_deltap    33 9+8   33 10+8   33 11+8   33 12+8   33 13+4   33 14+8   33 15+8   33 16+8   33 27-8   33 28-8   33 31+8   33 32+8   
ip      16
ip      43
mirp[min,rnd,grey]  headstem 63
shpix   -8 10
shpix   16 4
shpix   -8 33
shpix   8  39
f_deltap    45 29-4 51 29+4   45 30-4 51 30+4   45 31-4 51 31+4   45 32-4 51 32+4
IUP[y]
""",

    #cho_chang
    "uni0E0A": """
f_deltap    73 11+8   73 13+8   
srp0    72
mdrp[rp0,rnd,grey]  20
f_deltap    20 12-8   
mdrp[grey]  14
mirp[min,rnd,grey]  headstem 63
mirp[rp0,rnd,grey]  headstem_plus_hole 69
f_deltap    69 9-4   69 11+8   69 12+8   69 13+4  
mdrp[grey]  26
srp0    20
mdrp[rp0,rnd,white] 9
f_deltap    9 36-8  9 37-8  
mdrp[grey]  32
mdrp[grey]  39
mdrp[grey]  53
mdrp[rp0,rnd,grey]  3
f_deltap    3 17-8   3 29-8   3 31-8  3 32-8  3 51-8
mdrp[grey]  1
mirp[min,rnd,grey]  hstem 58
#
srp0 73
mirp[rp0,rnd,white] gap_188 42
f_deltap    42 17+8   42 18+8   42 26+8   42 27+8   42 28+8   42 36+8   42 37+8   42 38+8   42 39+8   42 40+8   42 51+8   
mirp[min,rnd,grey]  hstem   49
mdrp[rp0,grey]  36
mdrp[grey]  35
shpix   -16 69
shpix   -8 20
shpix   -16 14
shpix   8   9
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mirp[min,rnd,grey]  vstem 46
shp[rp2]    3
mirp[rp0,rnd,grey]  vheight 29
sloop   3
ip      32 39 53
mdrp[min,rnd,grey]  36
mirp[rp0,rnd,grey]  headstem 12
mdrp[rp0,rnd,white]     16
mirp[min,rnd,grey]      headstem 67
f_deltap    67 29+8  67 30+8  67 31+8  67 32+8  67 33+8   67 34+8   67 35+8   67 36+8   
mirp[rp0,rnd,grey]      headdia 23
f_deltap    23 11-4  23 12-8   23 14-8   23 15-8   23 16-8   23 21+8   23 27+8   23 28+8   23 33+8   23 34+8   23 35+8   23 36+8   23 37-8   23 38-8   23 49-8   23 50-8   23 54-8  23 55-8   
mirp[min,rnd,grey]      headstem 61
srp2    3
ip  5
ip  57
shpix   8  12
shpix   -8  16
shpix   8   23
shpix   16 67
f_deltap    16 14-2
f_deltap    12 14+1  12 15+1  12 16+1
IUP[y]
""",

    #so_zo
    "uni0E0B": """
f_deltap    76 9+8   76 21+8  76 26+8   76 31+8   
srp0                75
mdrp[rp0,rnd,grey]  21
f_deltap    21 12-8   
mdrp[grey]  16
shpix   -16 16
mirp[min,rnd,grey]  headstem 66
mirp[rp0,rnd,grey]  headstem_plus_hole 72
f_deltap    72 11+8   72 12+8
mdrp[grey]  27
srp0    21
mdrp[rp0,rnd,white] 9
f_deltap    9 26-8   9 27-8   9 28-8   
srp2    16
sloop   6
ip      30 31 32 12 13 14
mdrp[grey]  35
mdrp[grey]  42
mdrp[grey]  56
mdrp[rp0,rnd,grey]  3
f_deltap    3 17-8   3 19+8   3 20+8   3 26-8   3 29-8   3 40-8   
mirp[min,rnd,grey]  hstem 61
#
srp0    76
mirp[rp0,rnd,white]  gap_188 45
f_deltap    45 17+8   45 19+8   45 27+8   45 36+8   45 37+8   45 38+8   45 39+8    
mirp[min,rnd,grey]  hstem 52
mdrp[rp0,grey]  39
mdrp[grey]  38
shpix   -16 72
shpix   -8  21
shpix   8   9
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mirp[min,rnd,grey]  vstem 49
shp[rp2]    3
mirp[rp0,rnd,grey]  vheight 30
sloop       3
ip          35 42 56
alignrp     32
mdrp[min,rnd,grey]  39
mdrp[min,rnd,grey]  14
shpix   8   14
f_deltap    14 26+6  14 27+6  14 28+6  14 29+6  14 30+6
shp[rp2]    12
mdrp[rp0,min,rnd,grey]     31
mdrp[rp0,rnd,grey]     13
mdrp[rp0,rnd,white]    18
f_deltap    18 14+8   18 15+8   18 16+8   
mirp[min,rnd,grey]      headstem 69
f_deltap    69 29+8  69 30+8  69 31+8  69 32+8  69 33+8  69 34+8  69 35+8  69 36+8
mirp[rp0,rnd,grey]      headdia 24
f_deltap    24 13+8   24 14-8   24 15-8   24 16-8   24 21+8   24 27+8   24 28+8   24 33+8  24 34+8  24 35+8  24 36+8  24 37-8   24 38-8   24 49-8   24 50-8   
mirp[min,rnd,grey]      headstem 63
shpix   -8  18
shpix   8   24
shpix   -16 31
shpix   -16 13
shpix   8  69
IUP[y]
""",

    #cho_choe
    "uni0E0C": """
f_deltap    80 9+8   80 13-8   80 18+8   80 19+8   
srp0    79
mirp[rp0,rnd,white] gap_229 36
f_deltap    36 16+8   
mdrp[rnd,grey]  21
mdrp[grey]  38
mirp[rp0,min,rnd,grey]  hstem 24
mdrp[grey]  22
srp0    36
mirp[rp0,rnd,grey]  headdia_plus 30
f_deltap    30 12+4   30 13-4
mirp[min,rnd,grey]  headstem 58
mirp[rnd,grey]  headstem_plus_hole 64
#
srp0    80
mirp[rp0,rnd,white] gap_170 52
mirp[min,rnd,grey]  hstem 50
srp1    36
ip  14
mdap[rnd]   14
f_deltap    14 11+8   
mirp[min,rnd,grey]  hstem 44
srp1    51
ip  1
ip  48
srp1    30
ip  11
mdap[rnd]   11
f_deltap    11 9+4   11 10+4   11 13+4
mirp[min,rnd,grey]  headstem 76
mirp[rp0,rnd,grey]  headdia 4
f_deltap    4 9+8   4 10+8   4 11+8   4 12+8   4 14+8   4 15+8   4 16+8   4 21-8   4 27-8   4 28-8   4 29+8   4 30+8   4 31+8   4 32+8   4 37+8   4 38+8   4 49+8   4 50+8   
mirp[min,rnd,grey]  headstem 70
shpix   -16 64
shpix   -8  30
shpix   8 11
shpix   -8 4
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  0
alignrp 8
alignrp 33
mirp[rnd,grey]  vheight 52
mirp[min,rnd,grey]  vstem 47
mirp[rp0,rnd,grey]  vheight_shoot 41
ip  38
mirp[min,rnd,grey]  vstem_98 18
srp0    8
mirp[min,rnd,grey] headstem 67
f_deltap    67 29-4   67 30-4   67 31-4   67 32-4
shp[rp2]    55
mirp[rp0,rnd,grey] headdia 14
f_deltap    14 9+8   14 10+8  14 11+8  14 12+8   14 13+4   14 14+8   14 15+8   14 16+8   14 21-8   14 27-8   14 28-8   14 37+8   14 38+8   14 49+8   14 50+8   
alignrp 45
alignrp 27
mirp[min,rnd,grey] headstem 73
f_deltap    73 29+4   73 30+4   73 31+4   73 32+4
shp[rp2]    61
mdrp[min,rnd,grey] 3
mdap[rnd]   38
alignrp 24
mirp[min,rnd,grey]  vstem 21
shpix   8 18
shpix   -16 21
shpix   -8 27
shpix   8  33
shpix   -8  14
shpix   8   8
shpix   16  3
IUP[y]
""",

    #yo_ying
    "uni0E0D": """
f_deltap    92 9+8   92 13-8   92 15-8   92 16-8  
srp0    91
mirp[rp0,rnd,white] gap_229 25
mdrp[grey]  27
mdrp[grey]  10
mirp[rp0,min,rnd,grey]  hstem 13
mdrp[grey]  11
srp0    25
mirp[rp0,rnd,grey]  headdia_plus 19
mirp[min,rnd,grey]  headstem 47
mirp[rnd,grey]  headstem_plus_hole 53
#
srp0    92
mirp[rp0,rnd,white] gap_170 41
mirp[min,rnd,grey]  hstem 39
srp1    25
ip  3
mdap[rnd]   3
mirp[min,rnd,grey]  hstem 33
shpix   -16 53
shpix   -8  19
#
srp2    41
ip  59
ip  76
mdap[rnd]   59
mdrp[grey]  70
mdrp[min,rnd,grey]  88
mdrp[rp0,rnd,grey]  65
f_deltap    65 28-8  65 29-8  65 35-8  65 36-8  65 37-8   
mdrp[min,rnd,grey]  82
mdap[rnd]   76
mdrp[grey]  75
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp     22
mirp[min,rnd,grey]  vstem 37
mirp[rnd,grey]  vheight 41
mirp[rp0,rnd,grey]  vheight_shoot 30
ip          27
mirp[min,rnd,grey]  vstem_98 7
srp0        22
mirp[min,rnd,grey] headstem 44
mirp[rp0,rnd,grey] headdia 16
f_deltap    16 9+8  16 10+8   16 11+8   16 12+8   16 13+4    16 14+8   16 15+8   16 16+8   16 21-8   16 27-8   16 28-8   16 37+8   16 44-8   16 49+8
mirp[min,rnd,grey] headstem 50
mdap[rnd]   27
alignrp     13
mirp[min,rnd,grey]  vstem 10
shpix   8  7
shpix   -16 16
shpix   8   22
shpix   -16 10
f_deltap    50 29+4 44 29-4   50 30+4 44 30-4   50 31+4 44 31-4   50 32+4 44 32-4
#
srp0        0
mdrp[rp0,min,rnd,white] 62
alignrp     76
mdrp[min,rnd,grey]  85
mdrp[rp0,rnd,grey]  68
f_deltap    68 39+8   68 40+8   68 41+8  68 42+8
mdrp[min,rnd,grey]  79
mdrp[rp0,grey]  56
mdrp[grey]  72
f_deltap    79 9-8  79 10-8  79 11-8
IUP[y]
""",

    #yo_ying
    "uni0E0D.descless": """
f_deltap    57 9+8   57 13-8   57 15-8   57 16-8
srp0    56
mirp[rp0,rnd,white] gap_229 25
mdrp[grey]  27
mdrp[grey]  10
mirp[rp0,min,rnd,grey]  hstem 13
mdrp[grey]  11
srp0    25
mirp[rp0,rnd,grey]  headdia_plus 19
mirp[min,rnd,grey]  headstem 47
mirp[rnd,grey]  headstem_plus_hole 53
#
srp0    57
mirp[rp0,rnd,white] gap_170 41
mirp[min,rnd,grey]  hstem 39
srp1    25
ip  3
mdap[rnd]   3
mirp[min,rnd,grey]  hstem 33
shpix   -16 53
shpix   -8  19
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp     22
mirp[min,rnd,grey]  vstem 37
mirp[rnd,grey]  vheight 41
mirp[rp0,rnd,grey]  vheight_shoot 30
ip          27
mirp[min,rnd,grey]  vstem_98 7
srp0        22
mirp[min,rnd,grey] headstem 44
mirp[rp0,rnd,grey] headdia 16
f_deltap    16 9+8  16 10+8   16 11+8   16 12+8   16 13+4    16 14+8   16 15+8   16 16+8   16 21-8   16 27-8   16 28-8   16 37+8   16 44-8   16 49+8
mirp[min,rnd,grey] headstem 50
mdap[rnd]   27
alignrp     13
mirp[min,rnd,grey]  vstem 10
shpix   8  7
shpix   -16 16
shpix   8   22
shpix   -16 10
f_deltap    50 29+4 44 29-4   50 30+4 44 30-4   50 31+4 44 31-4   50 32+4 44 32-4
IUP[y]
""",

    #do_chada
    "uni0E0E": """
f_deltap    81 15+8   81 18+8   81 20+8   
srp0    80
mirp[rp0,rnd,white]  gap_74 41
mirp[min,rnd,grey]  headstem 66
mirp[rnd,grey]  headstem_plus_hole 60
mirp[rp0,rnd,grey]  headdia_plus 34
mdrp[grey]  32
mirp[min,rnd,grey]  hstem 46
mdrp[grey]  48
mdrp[grey]  31
#
srp0    81
mirp[rp0,rnd,white] gap_170 54
mirp[rp0,min,rnd,grey]  hstem 24
mdrp[rp0,rnd,grey]  77
mdrp[min,rnd,grey]  9
f_deltap    9 9+8   9 10+8
mdrp[rnd,grey]  72
f_deltap    72 17-8 11 17+8   11 21+8  
srp1    24
sloop   7
ip  14 16 17 19 3 21 1
shpix   8   41
shpix   16  60
shpix   8   9
shpix   8   72
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   38
mirp[rnd,grey]  vheight_lu 6
shp[rp2]    1
mirp[rp0,rnd,grey]  vheight_shoot 51
ip  48
mirp[min,rnd,grey]  vstem_98   28
shpix   8  28
mdap[rnd]   48
alignrp 34
mirp[min,rnd,grey]  vstem 31
shpix   -16 31
srp0    38
mirp[min,rnd,grey]  headstem 57
mirp[rp0,rnd,grey]  headdia 44
f_deltap    44 9+8  44 10+8   44 11+8   44 12+8   44 13+4    44 14+8   44 15+8   44 16+8   44 21-8   44 27-8   44 28-8   44 37+8   44 44-8   44 49+8
mirp[min,rnd,grey]  headstem 63
srp0    6
mirp[min,rnd,grey]  headstem   69
shp[rp2]    22
mdrp[rp0,rnd,grey]  12
f_deltap    12 27-8
sloop   6
ip  72 14 16 17 19 3
mirp[min,rnd,grey]  headstem   74
shpix   8   38
shpix   -8  44
shpix   8   6
shpix   -8  12
shpix   8   3
shpix   -8  14
f_deltap    57 29-4 63 29+4   57 30-4 63 30+4   57 31-4 63 31+4   57 32-4 63 32+4
IUP[y]
""",

    #to_patak
    "uni0E0F": """
f_deltap    85 15+8   85 18+8   85 20+8
srp0    84
mirp[rp0,rnd,white]  gap_74 45
mirp[min,rnd,grey]  headstem 70
mirp[rnd,grey]  headstem_plus_hole 64
mirp[rp0,rnd,grey]  headdia_plus 38
mdrp[grey]  36
mirp[min,rnd,grey]  hstem 50
mdrp[grey]  52
mdrp[grey]  35
#
srp0    85
mirp[rp0,rnd,white] gap_170 58
mirp[rp0,min,rnd,grey]  hstem 28
mdrp[rp0,rnd,grey]  81
mdrp[min,rnd,grey]  11
mdrp[rnd,grey]  76
srp1    28
sloop   13
ip  16 18 19 21 22 23 24 25 1 2 3 4 5
shpix   8   45
shpix   16  64
shpix   8   11
shpix   8   76
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   42
mirp[rnd,grey]  vheight_lu 8
shp[rp2]    4
shp[rp2]    1
mirp[rp0,rnd,grey]  vheight_shoot 55
ip  52
mirp[min,rnd,grey]  vstem_98   32
shpix   8  32
mdap[rnd]   52
alignrp     38
mirp[min,rnd,grey]  vstem 35
shpix   -16 35
srp0    42
mirp[min,rnd,grey]  headstem 61
mirp[rp0,rnd,grey]  headdia 48
f_deltap    48 9+8  48 10+8   48 11+8   48 12+8   48 13+4    48 14+8   48 15+8   48 16+8   48 21-8   48 27-8   48 28-8   48 37+8   48 44-8   48 49+8
mirp[min,rnd,grey]  headstem 67
#
srp0    8
mirp[min,rnd,grey]  headstem   73
shp[rp2]    22
shp[rp2]    25
mdrp[rp0,rnd,grey]  14
f_deltap    14 9-4   14 10-4   14 11-4   14 12-4   14 15-4   14 16-4   14 17-4   14 21-8   14 22-8   14 27-8   
sloop   6
ip  16 18 19 21 23 25
mirp[min,rnd,grey]  headstem   78
shpix   8   42
shpix   -8  48
shpix   8   8
shpix   -8  14
shpix   8   5
shpix   -8  16
f_deltap    61 29-4 67 29+4   61 30-4 67 30+4   61 31-4 67 31+4   61 32-4 67 32+4
IUP[y]
""",

    #tho_than
    "uni0E10": """
f_deltap    126 18+8   
srp0        125
mirp[rp0,rnd,white]  gap_102 8
mdrp[grey]  21
mdrp[grey]  42
mirp[min,rnd,grey]  headstem 55
mirp[rnd,grey]  headstem_plus_hole 49
mirp[rp0,rnd,grey]  headdia_plus 14
mirp[min,rnd,grey]  hstem  2
#
srp0        126
mirp[rp0,rnd,white] gap_170 43
alignrp     102
mdrp[grey]  32
mirp[min,rnd,grey]  hstem 19
f_deltap    102 15-1 102 16-1
#
srp0        102
mdrp[min,rnd,grey] 118
mdrp[rp0,rnd,grey]  96
mdrp[min,rnd,grey]  114
srp0        102
mdrp[min,rnd,grey]  90
mdrp[rp0,rnd,grey]  123
mdrp[min,rnd,grey]  71
mdrp[rnd,grey]  119
srp1        90
sloop       11
ip  76 78 79 81 83 87 59 61 63 64 66
#
shpix   8   8
shpix   16  49
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mirp[min,rnd,grey]  vstem 17
mirp[rp0,rnd,grey]  vheight_shoot   24
alignrp     31
mdrp[grey]  21
mdrp[grey]  29
mirp[rp0,min,rnd,grey]  vstem_98 39
shpix   8  39
mdrp[grey]  34
srp0    21
mdrp[grey]      20
mdrp[rp0,grey]      42
mdrp[grey]      43
srp1    21
mdrp[rp0,rnd,grey]  11
f_deltap    11 11-8   11 12-8   11 14-8   11 15-8   11 20-8   11 21-8   
mdap[rnd]   11
mirp[min,rnd,grey]  headstem    52
mirp[rp0,rnd,grey]  headdia 5
f_deltap    5 9-8  5 10-8   5 11-8   5 12-8   5 13-4    5 14-8   5 15-8   5 16-8   5 21+8   5 27+8   5 28+8   5 37-8   5 44+8   5 49-8
mirp[min,rnd,grey]  headstem 46
shpix   -8  11
shpix   16   5
f_deltap    46 29-4 52 29+4   46 30-4 52 30+4   46 31-4 52 31+4   46 32-4 52 32+4
#
srp0    0
mdrp[rp0,min,rnd,white]  99
mdrp[min,rnd,grey]  111
mdrp[rp0,rnd,grey]  93
mdrp[min,rnd,grey]  105
srp0    99
mdrp[rp0,rnd,grey]  59
alignrp 64
alignrp 68
mdrp[min,rnd,grey]  87
shp[rp2]    83
srp0    68
mdrp[min,rnd,grey]  117
mdrp[rp0,rnd,grey]  74
sloop   7
ip  76 78 79 81 85 61 66
mdrp[min,rnd,grey]  121
IUP[y]
""",

    #tho_than_descless
    "uni0E10.descless": """
f_deltap    59 18+8
srp0        58
mirp[rp0,rnd,white]  gap_102 8
mdrp[grey]  21
mdrp[grey]  42
mirp[min,rnd,grey]  headstem 55
mirp[rnd,grey]  headstem_plus_hole 49
mirp[rp0,rnd,grey]  headdia_plus 14
mirp[min,rnd,grey]  hstem  2
#
srp0        59
mirp[rp0,rnd,white] gap_170 43
mdrp[grey]  32
mirp[min,rnd,grey]  hstem 19
#
shpix   8   8
shpix   16  49
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mirp[min,rnd,grey]  vstem 17
mirp[rp0,rnd,grey]  vheight_shoot   24
alignrp     31
mdrp[grey]  21
mdrp[grey]  29
mirp[rp0,min,rnd,grey]  vstem_98 39
shpix   8  39
mdrp[grey]  34
srp0    21
mdrp[grey]      20
mdrp[rp0,grey]      42
mdrp[grey]      43
srp1    21
mdrp[rp0,rnd,grey]  11
f_deltap    11 11-8   11 12-8   11 14-8   11 15-8   11 20-8   11 21-8
mdap[rnd]   11
mirp[min,rnd,grey]  headstem    52
mirp[rp0,rnd,grey]  headdia 5
f_deltap    5 9-8  5 10-8   5 11-8   5 12-8   5 13-4    5 14-8   5 15-8   5 16-8   5 21+8   5 27+8   5 28+8   5 37-8   5 44+8   5 49-8
mirp[min,rnd,grey]  headstem 46
shpix   -8  11
shpix   16   5
f_deltap    46 29-4 52 29+4   46 30-4 52 30+4   46 31-4 52 31+4   46 32-4 52 32+4
#
IUP[y]
""",

    #tho_nangmontho
    "uni0E11": """
f_deltap    73 9+8   73 18+8   73 31+8   73 33+8   73 43+8   
srp0    72
mdrp[rp0,rnd,grey]  29
f_deltap    29 12-8   29 13-8
mdrp[grey]  24
mirp[min,rnd,grey]  headstem 63
mirp[rp0,rnd,grey]  headstem_plus_hole 69
f_deltap    69 11+8   69 12+8   69 13+8   
mdrp[grey]  35
mdrp[rp0,rnd,white]  17
f_deltap    17 19-8   17 20-8   17 21-8   17 26-8  17 27-8   17 36-8   
mdrp[grey]  43
mdrp[rp0,rnd,grey]  11
f_deltap    11 17-8   11 28-8   
mirp[min,rnd,grey]  hstem 48
shp[rp2]    10
#
srp0    73
mirp[rp0,rnd,white] gap_170 59
mirp[min,rnd,grey]  hstem 1
srp1    43
ip  53
srp0    53
mdrp[grey]  6
shpix   -16 69
shpix   -8  29
shpix   8   17
shpix   -16 24
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   10
alignrp 1
mdrp[grey]  49
mirp[rp0,rnd,grey]  vheight  56
alignrp 38
alignrp 40
mdrp[min,rnd,grey]  4
shpix   8  4
srp0    38
mdrp[min,rnd,grey]  22
shpix   8 22
f_deltap    22 26+6   22 27+6   22 28+6   22 29+6   22 30+6
shpix   16  22
shp[rp2]    20
mdrp[rp0,min,rnd,grey]  39
mdrp[rp0,min,rnd,grey]  21
mdrp[rp0,rnd,white]  26
f_deltap    26 9+8   26 10+8   26 14+8   26 15+8   
mirp[min,rnd,grey]  headstem    66
mirp[rp0,rnd,grey]  headdia 32
f_deltap    32 14-8   32 15-8   32 16-8   32 21+8   32 27+8   32 28+8   32 37-8   32 38-8   32 49-8   32 50-8   
mirp[min,rnd,grey]  headstem 60
srp2    49
ip  13
ip  47
shpix   -16 26
shpix   8   32
f_deltap    60 29-4 66 29+4   60 30-4 66 30+4   60 31-4 66 31+4   60 32-4 66 32+4
IUP[y]
""",

    #tho_phuthao
    "uni0E12": """
f_deltap    100 9+8   100 13-8   100 19+8   
SRP0                99
MIRP[rp0,rnd,white]  gap_203 50
mdrp[grey]  56
mirp[rp0,min,rnd,grey]  hstem 49
mdrp[grey]  23
ip  29
mdrp[rp0,rnd,grey]  41
f_deltap    41 10-8   41 14+8  41 15+8  41 16+8   41 17-8  41 18-8  41 26-8  41 27-8  41 28-8  41 29-8  41 30-8  41 31-8   41 33+8  41 36-8   41 37-8  41 40-8
mirp[min,rnd,grey]  headstem 78
mirp[rp0,rnd,grey]  headdia 35
f_deltap    35 11-8   35 12-8   35 14-8  35 15-8  35 16-8    35 21+8   35 27+8   35 28+8  35 32+8   35 44+8
ip  32
mirp[min,rnd,grey]  headstem 84
shpix   8   35
shpix   -8  41
#
srp0    100
mirp[rp0,rnd,white] gap_170 72
mdrp[grey]  67
mdrp[grey]  1
mirp[min,rnd,grey]  hstem 70
srp1    50
ip      14
mdap[rnd]   14
srp2    23
sloop   6
ip      59 60 61 18 19 20
mirp[min,rnd,grey]  hstem 64
mdrp[rp0,rnd,grey]  11
mirp[min,rnd,grey]  headstem 96
mirp[rp0,rnd,grey]  headdia 5
f_deltap    5 10+8   5 11+8   5 12+8   5 14+8  5 15+8  5 16+8   5 29+8  5 30+8  5 31+8  5 32+8  
mirp[min,rnd,grey]  headstem 90
shpix   8 11
shpix   -16 5
f_deltap    90 9+8 23 9-2 35 9-4   90 10+8 23 10-1 35 10-4   23 17-5   23 18-4
f_deltap    84 29-4 78 29+4   84 30-4 78 30+4   84 31-4 78 31+4   84 32-4 78 32+4
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
ALIGNRP     8
ALIGNRP     49
mirp[min,rnd,grey]      vstem 67
mirp[rnd,grey]          vheight 72
MIRP[rp0,rnd,grey]      vheight_shoot  59
alignrp     61
MIRP[min,rnd,grey]      vstem  20
shpix   8  20
shp[rp2]    18
mdrp[rp0,min,rnd,white]     60
mdrp[rp0,min,rnd,grey]      19
mdrp[rp0,rnd,white]     38
f_deltap    38 38-8   38 39-8   38 40-8  
mirp[min,rnd,grey]      headstem 81
mirp[rp0,rnd,grey]      headdia 32
f_deltap    32 12-8   32 14-8  32 15-8  32 16-8   32 21+8  32 27+8   32 28+8    32 38-8   
mirp[min,rnd,grey]      headstem 75
srp2        49
ip          29
shpix   -16 19
shpix   -8  38
shpix   8   32
#
srp0        8
mirp[min,rnd,grey]  headstem 87
mirp[rp0,rnd,grey]  headdia 14
f_deltap    14 9+4   14 10+6   14 11+6   14 12+8   14 14+8   14 15+8   14 16+8   14 29+8   14 30+8   14 31+8   14 32+8
ip      65
ip      3
mirp[min,rnd,grey]  headstem 93
shpix   -16 65
shpix   8   8
f_deltap    75 9-8   75 10-8
f_deltap    75 29-4 81 29+4   75 30-4 81 30+4   75 31-4 81 31+4   75 32-4 81 32+4
IUP[y]
""",

    #no_nane
    "uni0E13": """
f_deltap    76 17+8
srp0    75
mirp[rp0,rnd,white] gap_229 23
f_deltap    23 16+8
mdrp[rnd,grey]  8
mdrp[grey]  25
mirp[rp0,min,rnd,grey]  hstem 11
mdrp[grey]  9
srp0    23
mirp[rp0,rnd,grey]  headdia_plus 17
f_deltap    17 12+4   17 13-4
mirp[min,rnd,grey]  headstem 54
mirp[rnd,grey]  headstem_plus_hole 60
#
srp0    76
mirp[rp0,rnd,white] gap_203 36
f_deltap    36 13-8   36 15-8  
mirp[min,rnd,grey]  hstem 34
srp1    23
ip  1
mdrp[rp0,rnd,grey]  42
f_deltap    42 9+4   42 10+4   42 11+4
mirp[min,rnd,grey]  headstem 66
mirp[rp0,rnd,grey]  headdia 48
f_deltap    48 9-8   48 10-8   48 11-8   48 12-8   48 13-4  48 14-8   48 15-8   48 16-8   48 21+8   48 27+8   48 28+8   48 29-8   48 30-8   48 31-8   48 32-8   48 37-8   48 38-8   48 49-8   48 50-8
mirp[min,rnd,grey]  headstem 72
#
mdap[rnd]   1
mirp[min,rnd,grey]  hstem 31
shp[rp2]    0
#
shpix   -16 60
shpix   -8  17
shpix   8 48
shpix   -8 42
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  0
alignrp 20
alignrp 45
mirp[min,rnd,grey]  vstem 32
mirp[rnd,grey]  vheight 36
mirp[rp0,rnd,grey]  vheight_shoot 28
ip  25
mirp[min,rnd,grey]  vstem_98 5
shpix   8  5
#
mdap[rnd]   25
alignrp 11
mirp[min,rnd,grey]  vstem 8
shpix   -16  8
#
srp0    45
mirp[min,rnd,grey] headstem 63
f_deltap    63 29-4  63 30-4  63 31-4  63 32-4 
shp[rp2]    51
mirp[rp0,rnd,grey] headdia 38
f_deltap    38 9+8   38 10+8  38 11+8  38 12+8   38 13+4   38 14+8   38 15+8   38 16+8   38 21-8   38 27-8   38 28-8   38 37+8   38 38+8   38 49+8   38 50+8
alignrp 14
mirp[min,rnd,grey] headstem 69
f_deltap    69 29+4   69 30+4   69 31+4   69 32+4
shp[rp2]    57
#
shpix   8 20
shpix   -16 14
shpix   8  45
shpix   -8 38
IUP[y]
""",

    #do_dek
    "uni0E14": """
f_deltap    61 9+8   61 15-8   61 19+8   61 26+8   61 31+8   61 36+8   61 38+8   
SRP0        60
MIRP[rp0,rnd,white]  gap_203 35
f_deltap    35 16+8
mdrp[grey]  41
mirp[min,rnd,grey]  hstem 34
mdrp[grey]  8
ip      14
f_deltap    8 9-1  8 10-1  8 11-1  8 12-1   8 13-1  8 14-2  8 15-2  8 16-2  8 17-2   8 18-2  
mdrp[rp0,rnd,grey]  26
f_deltap    26 10-8   26 18-8   26 26-8   26 27-8
mirp[min,rnd,grey]  headstem 51
mirp[rp0,rnd,grey]  headdia 20
f_deltap    20 9-4   20 10-4   20 11-8   20 12-8   20 14-8  20 15-8   20 16-8   20 21+8   20 27+8   20 28+8   20 32+8   20 44+8
ip  17
mirp[min,rnd,grey]  headstem 57
shpix   8 20 
shpix   -8 26
f_deltap    51 9+8
#
srp0    61
mirp[rp0,rnd,white]  gap_170 47
mirp[min,rnd,grey]  hstem 1
f_deltap    57 29-4 51 29+4   57 30-4 51 30+4   57 31-4 51 31+4   57 32-4 51 32+4
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]           1
ALIGNRP             34
MIRP[rp0,rnd,grey]  vheight_shoot  44
MIRP[rp0,min,rnd,grey]  vstem_98  5
mdrp[rp0,rnd,grey]  23
f_deltap    23 33+8   23 35+8   
mirp[min,rnd,grey]  headstem 54
mirp[rp0,rnd,grey]  headdia 17
f_deltap    17 12-8   17 14-8   17 15-8   17 16-8   17 21+8   17 27+8   17 28+8   17 38-8 
mirp[min,rnd,grey]  headstem 48
srp2                34
ip                  14
shpix   8  5
shpix   -8 23
shpix   16 17
f_deltap    26 13+4   14 16-3
f_deltap    48 29-4 54 29+4   48 30-4 54 30+4   48 31-4 54 31+4   48 32-4 54 32+4
IUP[y]
""",

    #to_tao
    "uni0E15": """
f_deltap    65 9+8   65 15-8   65 19+8   65 26+8   65 31+8   65 36+8   65 38+8
SRP0        64
MIRP[rp0,rnd,white]  gap_203 37
f_deltap    37 16+8
mdrp[grey]  43
mirp[min,rnd,grey]  hstem 36
mdrp[grey]  10
ip      16
f_deltap    10 9-1  10 10-1  10 11-1  10 12-1   10 13-1  10 14-2  10 15-2  10 16-2  10 17-2   10 18-2
mdrp[rp0,rnd,grey]  28
f_deltap    28 10-8   28 18-8   28 26-8   28 27-8   28 45+8   28 46-8   
mirp[min,rnd,grey]  headstem 55
mirp[rp0,rnd,grey]  headdia 22
f_deltap    22 9-4   22 10-4   22 11-8   22 12-8   22 14-8  22 15-8   22 16-8   22 21+8   22 27+8   22 28+8   22 32+8   22 44+8
ip  19
mirp[min,rnd,grey]  headstem 61
shpix   8 22
shpix   -8 28
f_deltap    55 9+8
#
srp0    65
mirp[rp0,rnd,white]  gap_170 51
mirp[min,rnd,grey]  hstem 1
srp1    10
sloop   6
ip  46 47 48 5 6 7
#
f_deltap    61 29-4 55 29+4   61 30-4 55 30+4   61 31-4 55 31+4   61 32-4 55 32+4
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]           1
ALIGNRP             36
MIRP[rp0,rnd,grey]  vheight_shoot  46
alignrp 48
MIRP[min,rnd,grey]  vstem_98  7
shpix   8  7
shp[rp2]    5
mdrp[rp0,min,rnd,grey]  47
mdrp[rp0,min,rnd,grey]  6
f_deltap    6 38-8
mdrp[rp0,rnd,white]  25
f_deltap     25 36-8   25 38-8   25 40-8   
mirp[min,rnd,grey]  headstem 58
mirp[rp0,rnd,grey]  headdia 19
f_deltap    19 12-8   19 14-8   19 15-8   19 16-8   19 21+8   19 27+8   19 28+8   19 38-8
mirp[min,rnd,grey]  headstem 52
srp2                36
ip                  16
#
shpix   -8 25
shpix   16 19
f_deltap    52 29-4 58 29+4   52 30-4 58 30+4   52 31-4 58 31+4   52 32-4 58 32+4
IUP[y]
""",

    #to_tung
    "uni0E16": """
f_deltap    46 9+8   46 13-8   46 15-8   46 16-8   46 19+8   
srp0            45
mirp[rp0,rnd,white]  gap_229 23
mdrp[grey]      25
mdrp[grey]      8
mirp[rp0,min,rnd,grey]  hstem  11
mdrp[grey]      9
srp0    23
mirp[rp0,rnd,grey]  headdia_plus    17
mirp[min,rnd,grey]  headstem 36
mirp[rnd,grey]  headstem_plus_hole 42
#
srp0            46
mirp[rp0,rnd,white] gap_170 31
mirp[min,rnd,grey]  hstem   1
#
shpix   -16 42
shpix   -8 17
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]           1
alignrp             20
mirp[rp0,rnd,grey]  vheight_shoot    28
ip  25
mirp[min,rnd,grey]  vstem_98  5
shpix   8  5
mdap[rnd]   25
alignrp     11
mirp[min,rnd,grey]  vstem   8
shpix   -16 8
srp0    20
mirp[min,rnd,grey]  headstem 33
mirp[rp0,rnd,grey]  headdia 14
f_deltap    14 9+8  14 10+8   14 11+8   14 12+8   14 13+4    14 14+8   14 15+8   14 16+8   14 21-8   14 27-8   14 28-8   14 37+8   14 44-8   14 49+8
mirp[min,rnd,grey]  headstem 39
f_deltap    33 29-4 39 29+4   33 30-4 39 30+4   33 31-4 39 31+4   33 32-4 39 32+4
shpix   8 20
shpix   -16 14
IUP[y]
""",

    #tho_thahan
    "uni0E17": """
f_deltap    44 12-8  44 18+8   44 19+8   44 20+8   44 43+8   
srp0        43
mirp[rp0,rnd,white]     gap_74 16
f_deltap    16 14-8
mirp[min,rnd,grey]  headstem 40
mirp[rnd,grey]  headstem_plus_hole 34
mirp[rp0,rnd,grey]  headdia_plus 22
f_deltap    22 37+8   22 41+8   22 43-8   22 44-8
alignrp     9
mirp[min,rnd,grey]  hstem 10
#
srp0        44
mirp[rp0,rnd,white] gap_170 30
mirp[min,rnd,grey]  hstem 1
srp1        22
ip  24
srp0    24
mdrp[grey]  8
shpix   8 16
shpix   16 64
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp     9
mirp[rp0,rnd,grey]  vheight 27
alignrp     19
ip  23
mdrp[min,rnd,grey]  5
shpix   8  5
srp0        19
mirp[min,rnd,grey]  headstem 37
mirp[rp0,rnd,grey]  headdia 13
f_deltap    13 9-8  13 10-8   13 11-8   13 12-8   13 13-4    13 14-8   13 15-8   13 16-8   13 21+8   13 27+8   13 28+8   13 37-8   13 44+8   13 49-8
mirp[min,rnd,grey]  headstem 31
#
shpix   -8 19
shpix   16 13
f_deltap    31 29-4 37 29+4   31 30-4 37 30+4   31 31-4 37 31+4   31 32-4 37 32+4
IUP[y]
""",

    #to_thong
    "uni0E18": """
f_deltap    43 12+8   43 16-8   43 17+8   43 26+8   43 27+8   43 28+8   43 36+8   43 37+8   43 38+8   43 39+8   43 40+8
srp0        42
mirp[rp0,rnd,white] gap_266 3
alignrp     37
mdrp[grey]  1
mdrp[grey]  5
mdrp[grey]  41
mirp[min,rnd,grey]  hstem 35
shp[rp2]    26
#
srp0        43
mirp[rp0,rnd,white] gap_188 28
mdrp[grey]  16
mirp[min,rnd,grey]  hstem 33
shpix   8 37
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mirp[min,rnd,grey]  vstem 31
shp[rp2]    3
mirp[rp0,rnd,grey]  vheight_shoot 8
alignrp     15
mdrp[grey]  5
mdrp[grey]  13
mirp[min,rnd,grey]  vstem_98 23
shpix   8 23
mdrp[grey]  18
#
srp0    5
mdrp[grey]  34
ip  4
ip  35
mdrp[rp0,grey]  41
srp2    23
ip  38
ip  25
mdrp[grey]  28
ip  37
ip  27
IUP[y]
""",

    #no_nu
    "uni0E19": """
f_deltap    57 17+8   57 18+8   57 22-8   
srp0    56
mirp[rp0,rnd,white] gap_74 7
mirp[min,rnd,grey]  headstem 41
mirp[rnd,grey]  headstem_plus_hole 35
mirp[rp0,rnd,grey]  headdia_plus 13
alignrp 0
mirp[min,rnd,grey]  hstem 1
#
srp0    57
mirp[rp0,rnd,white]  gap_203 18
mirp[min,rnd,grey]  hstem 16
mdrp[rp0,rnd,grey]  23
f_deltap    23 9+4  23 10+4  23 11-4   23 12-4
mirp[min,rnd,grey]  headstem 47
mirp[rp0,rnd,grey]  headdia 29
f_deltap    29 9-8  29 10-8  29 11-8   29 12-8   29 13-4   29 14-8   29 15-8   29 16-8   29 27+8   29 28+8   29 37-8   29 49-8
mirp[min,rnd,grey]  headstem 53
shpix   8   7
shpix   16  35
shpix   8   29
shpix   -8  23
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp     26
mdrp[grey]  14
mirp[rp0,rnd,grey]  vheight 10
alignrp     18
mirp[min,rnd,grey]  headstem 38
mirp[rp0,rnd,grey]  headdia 4
f_deltap    4 9-8  4 10-8   4 11-8   4 12-8   4 13-4    4 14-8   4 15-8   4 16-8   4 21+8   4 27+8   4 28+8   4 37-8   4 44+8   4 49-8
mirp[min,rnd,grey]  headstem 32
#
srp0    26
mirp[min,rnd,grey]  headstem 44
mirp[rp0,rnd,grey]  headdia 20
f_deltap    20 9+8  20 10+8   20 11+8   20 12+8   20 13+4    20 14+8   20 15+8   20 16+8   20 21-8   20 27-8   20 28-8   20 37+8   20 44-8   20 49+8
ip  16
ip  30
mirp[min,rnd,grey]  headstem 50
f_deltap    32 29-4 38 29+4   32 30-4 38 30+4   32 31-4 38 31+4   32 32-4 38 32+4
shpix   -8 10
shpix   16   4
shpix   8 26
shpix   -8 20
IUP[y]
""",

    #bo_baimai
    "uni0E1A": """
f_deltap    37 18+8   37 20+8   
srp0    36
mirp[rp0,rnd,white] gap_74 9
mirp[min,rnd,grey]  headstem 33
mirp[rnd,grey]  headstem_plus_hole 27
mirp[rp0,rnd,grey]  headdia_plus 15
f_deltap    15 37+8   15 41+8   15 43-8  15 44-8   15 48-8   
mirp[rp0,min,rnd,grey]  hstem 3
mdrp[grey]      1 
#
srp0    37
mirp[rp0,rnd,grey]  gap_170 21
mirp[min,rnd,grey]  hstem 19
#
shpix   8 9
shpix   16 27
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  0
mirp[min,rnd,grey]  vstem 17
shp[rp2]    3
mirp[rp0,rnd,grey]  vheight 12
alignrp 21
mirp[min,rnd,grey]  headstem 30
mirp[rp0,rnd,grey]  headdia 6
f_deltap    6 9-8  6 10-8   6 11-8   6 12-8   6 13-4    6 14-8   6 15-8   6 16-8   6 21+8   6 27+8   6 28+8   6 37-8   6 44+8   6 49-8
mirp[min,rnd,grey]  headstem 24
#
shpix   -8  12
shpix   16  6
f_deltap    24 29-4 30 29+4   24 30-4 30 30+4   24 31-4 30 31+4   24 32-4 30 32+4
IUP[y]
""",

    #po_pla
    "uni0E1B": """
f_deltap    37 18+8   37 20+8
srp0    36
mirp[rp0,rnd,white] gap_74 9
mirp[min,rnd,grey]  headstem 33
mirp[rnd,grey]  headstem_plus_hole 27
mirp[rp0,rnd,grey]  headdia_plus 15
f_deltap    15 37+8   15 41+8   15 43-8  15 44-8   15 48-8
mirp[rp0,min,rnd,grey]  hstem 3
mdrp[grey]      1
#
srp0    37
mirp[rp0,rnd,grey]  gap_170 21
mirp[min,rnd,grey]  hstem 19
#
shpix   8 9
shpix   16 27
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  0
mirp[min,rnd,grey]  vstem 17
shp[rp2]    3
mirp[rnd,grey]  vheight_po  21
mirp[rp0,rnd,grey]  vheight 12
mirp[min,rnd,grey]  headstem 30
mirp[rp0,rnd,grey]  headdia 6
f_deltap    6 9-8  6 10-8   6 11-8   6 12-8   6 13-4    6 14-8   6 15-8   6 16-8   6 21+8   6 27+8   6 28+8   6 37-8   6 44+8   6 49-8
mirp[min,rnd,grey]  headstem 24
#
shpix   -8  12
shpix   16  6
f_deltap    24 29-4 30 29+4   24 30-4 30 30+4   24 31-4 30 31+4   24 32-4 30 32+4
IUP[y]
""",

    #po_pung
    "uni0E1C": """
f_deltap    38 9+8   38 14-8   38 16-8   38 18+8   38 20+8   38 27+8   38 31+8   38 32+8   
srp0    37
mirp[rp0,rnd,white]  gap_170 6
mirp[min,rnd,grey]  hstem 4
shp[rp2]    18
mirp[rp0,rnd,grey]  headdia_plus 13
mirp[min,rnd,grey]  headstem 28
mirp[rnd,grey]  headstem_plus_hole 34
#
srp0    38
mdrp[rp0,rnd,white] 23
mirp[min,rnd,grey]  hstem   21
shp[rp2]    1
srp1    18
ip  20
ip  3
shpix   -16 34
shpix   -8 13
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     5
mirp[rp0,rnd,grey]  vheight 10
alignrp 23
mirp[min,rnd,grey]  headstem 31
mirp[rp0,rnd,grey]  headdia 16
f_deltap    16 9-8  16 10-8   16 11-8   16 12-8   16 13-4    16 14-8   16 15-8   16 16-8   16 21+8   16 27+8   16 28+8   16 37-8   16 44+8   16 49-8
mirp[min,rnd,grey]  headstem 25
srp2    1
sloop   6
ip  19 20 21 2 3 4
f_deltap    25 29-4 31 29+4   25 30-4 31 30+4   25 31-4 31 31+4   25 32-4 31 32+4
shpix   -8 10
shpix   16 16
IUP[y]
""",

    #fo_fa
    "uni0E1D": """
f_deltap    38 9+8   38 14-8   38 16-8   38 18+8   38 20+8   38 27+8   38 31+8   38 32+8
srp0    37
mirp[rp0,rnd,white]  gap_170 6
mirp[min,rnd,grey]  hstem 4
shp[rp2]    18
mirp[rp0,rnd,grey]  headdia_plus 13
mirp[min,rnd,grey]  headstem 28
mirp[rnd,grey]  headstem_plus_hole 34
#
srp0    38
mdrp[rp0,rnd,white] 23
mirp[min,rnd,grey]  hstem   21
shp[rp2]    1
srp1    18
ip  20
ip  3
shpix   -16 34
shpix   -8 13
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     5
mirp[rnd,grey]  vheight_po 23
mirp[rp0,rnd,grey]  vheight 10
mirp[min,rnd,grey]  headstem 31
mirp[rp0,rnd,grey]  headdia 16
f_deltap    16 9-8  16 10-8   16 11-8   16 12-8   16 13-4    16 14-8   16 15-8   16 16-8   16 21+8   16 27+8   16 28+8   16 37-8   16 44+8   16 49-8
mirp[min,rnd,grey]  headstem 25
srp2    1
sloop   6
ip  19 20 21 2 3 4
f_deltap    25 29-4 31 29+4   25 30-4 31 30+4   25 31-4 31 31+4   25 32-4 31 32+4
shpix   -8 10
shpix   16 16
IUP[y]
""",

    #po_pan
    "uni0E1E": """
f_deltap    36 14+8   36 16+8   36 18+8   36 19+8   36 20+8   36 23+8   36 33+8   
srp0    35
mirp[rp0,rnd,white]  gap_74 10
mirp[min,rnd,grey]  headstem 32
mirp[rnd,grey]  headstem_plus_hole 26
mirp[rp0,rnd,grey]  headdia_plus 16
alignrp     3
mirp[min,rnd,grey]  hstem 4
#
srp0    36
mirp[rp0,rnd,white] gap_170 22
mirp[min,rnd,grey]  hstem   20
shp[rp2]    1
#
srp1    16
sloop   3
ip      18 19 2
shpix   8 10
shpix   16 26
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mirp[rp0,rnd,grey]  vheight 13
alignrp 19
alignrp 22
ip  2
ip  17
mirp[min,rnd,grey]  headstem 29
mirp[rp0,rnd,grey]  headdia 7
f_deltap    7 9-8  7 10-8   7 11-8   7 12-8   7 13-4    7 14-8   7 15-8   7 16-8   7 21+8   7 27+8   7 28+8   7 37-8   7 44+8   7 49-8
mirp[min,rnd,grey]  headstem 23
srp0    17
f_deltap    17 12-4   17 14-3  17 15-3  17 16-6
alignrp 20
#
f_deltap    23 29-4 29 29+4   23 30-4 29 30+4   23 31-4 29 31+4   23 32-4 29 32+4
shpix   -8 13
shpix   16 7
IUP[y]
""",

    #fo_fun
    "uni0E1F": """
f_deltap    36 14+8   36 16+8   36 18+8   36 19+8   36 20+8   36 23+8   36 33+8
srp0    35
mirp[rp0,rnd,white]  gap_74 10
mirp[min,rnd,grey]  headstem 32
mirp[rnd,grey]  headstem_plus_hole 26
mirp[rp0,rnd,grey]  headdia_plus 16
alignrp     3
mirp[min,rnd,grey]  hstem 4
#
srp0    36
mirp[rp0,rnd,white] gap_170 22
mirp[min,rnd,grey]  hstem   20
shp[rp2]    1
#
srp1    16
sloop   3
ip      18 19 2
shpix   8 10
shpix   16 26
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mirp[rnd,grey]  vheight_po  22
mirp[rp0,rnd,grey]  vheight 13
alignrp 19
ip  2
ip  17
mirp[min,rnd,grey]  headstem 29
mirp[rp0,rnd,grey]  headdia 7
f_deltap    7 9-8  7 10-8   7 11-8   7 12-8   7 13-4    7 14-8   7 15-8   7 16-8   7 21+8   7 27+8   7 28+8   7 37-8   7 44+8   7 49-8
mirp[min,rnd,grey]  headstem 23
srp0    17
f_deltap    17 12-4   17 14-3  17 15-3  17 16-6
alignrp 20
#
f_deltap    23 29-4 29 29+4   23 30-4 29 30+4   23 31-4 29 31+4   23 32-4 29 32+4
shpix   -8 13
shpix   16 7
IUP[y]
""",

    #po_sampao
    "uni0E20": """
f_deltap    46 18+8   48 20+8   
srp0    45
mirp[rp0,rnd,white]  gap_74 18
mirp[min,rnd,grey]  headstem 42
mirp[rnd,grey]  headstem_plus_hole 36
mirp[rp0,rnd,grey]  headdia_plus 11
mdrp[grey]  9
mirp[rp0,min,rnd,grey]  hstem 23
mdrp[grey]  25
mdrp[grey]  8
#
srp0    46
mirp[rp0,rnd,white]  gap_170   31
mirp[min,rnd,grey]  hstem   1
shpix   8 18
shpix   16 36
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     15
mirp[rp0,rnd,grey]  vheight_shoot 28
ip      25
mirp[min,rnd,grey]  vstem_98   5
shpix   8   5
#
srp0    15
mirp[min,rnd,grey]  headstem 33
mirp[rp0,rnd,grey]  headdia 21
f_deltap    21 9+8  21 10+8   21 11+8   21 12+8   21 13+4    21 14+8   21 15+8   21 16+8   21 21-8   21 27-8   21 28-8   21 37+8   21 44-8   21 49+8
mirp[min,rnd,grey]  headstem 39
#
mdap[rnd]   25
alignrp     11
mirp[min,rnd,grey]  vstem 8
shpix   -16 8
#
shpix   8 15
shpix   -16 21
f_deltap    33 29-4 39 29+4   33 30-4 39 30+4   33 31-4 39 31+4   33 32-4 39 32+4
IUP[y]
""",

    #mo_ma
    "uni0E21": """
f_deltap    62 12+8   62 13+8    62 18+8   62 20+8    62 33+8    62 38+8   
srp0        61
mirp[rp0,rnd,white]  gap_102 9
alignrp     20
mirp[min,rnd,grey]  headstem 58
shp[rp2]    46
mirp[rnd,grey]  headstem_plus_hole 52
shp[rp2]    40
mirp[rp0,rnd,grey]  headdia_plus 26
f_deltap    26 17+8   26 22+8   26 26+8   26 27+8   26 33-8    26 37+8   26 42+8   
alignrp     3
mirp[min,rnd,grey]  hstem 14
#
srp0        62
mirp[rp0,rnd,white]  gap_170 34
mirp[min,rnd,grey]  hstem 32
#
srp1    26
ip  1
ip  29
#
shpix   8 20
shpix   16 40
shpix   8 9
shpix   16 62
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     6
mirp[min,rnd,grey]  vstem 29
mirp[rp0,rnd,grey]  vheight 23
alignrp     34
mirp[min,rnd,grey]  headstem 43
mirp[rp0,rnd,grey]  headdia 17
f_deltap    17 9-8  17 10-8   17 11-8   17 12-8   17 13-4    17 14-8   17 15-8   17 16-8   17 21+8   17 27+8   17 28+8   17 37-8   17 44+8   17 49-8
mirp[min,rnd,grey]  headstem 37
srp0        6
mirp[min,rnd,grey]  headstem 49
mirp[rp0,rnd,grey]  headdia 12
f_deltap    12 9+8  12 10+8   12 11+8   12 12+8   12 13+4    12 14+8   12 15+8   12 16+8   12 21-8   12 26-8   12 27-8   12 28-8   12 29+8   12 30+8   12 31+8   12 37+8   12 44-8   12 49+8
ip  27
ip  3
mirp[min,rnd,grey]  headstem 55
#
shpix   -8 23
shpix   16 17
shpix   -16 12
shpix   8 6
f_deltap    37 29-4 43 29+4   37 30-4 43 30+4   37 31-4 43 31+4   37 32-4 43 32+4
IUP[y]
""",

    #yo_yak
    "uni0E22": """
f_deltap    52 9+8   52 11+8   52 18+8   52 23+8   52 25-8   
srp0        51
mirp[rp0,rnd,white]  gap_141 3
mirp[min,rnd,grey]  hstem 28
mdrp[rp0,rnd,grey]  21
f_deltap    21 9-4   21 10-4   21 22-8   21 23-8   21 24-8   
mdrp[grey]  10
mdrp[grey]  7
mdrp[grey]  24
mdrp[min,rnd,grey]  48
mdrp[rp0,rnd,grey]  16
f_deltap    16 9+4   16 10-4   16 13+4   16 14+8   16 15+8   16 22+8   
mirp[min,rnd,grey]  headstem 42
#
srp0        52
mirp[rp0,rnd,white]  gap_170 36
mirp[min,rnd,grey]  hstem 34
shpix   -8 16
shpix   -16 48
f_deltap    22 13-4   22 14-4   22 15-4   22 16-4
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mirp[min,rnd,grey]  vstem 32
mirp[rp0,rnd,grey]  vheight 13
alignrp     36
mirp[min,rnd,grey]  headstem 45
mirp[rp0,rnd,grey]  headdia 19
f_deltap    19 9-4  19 10-4   19 11-8   19 12-8   19 13-4    19 14-8   19 15-8   19 16-8   19 21+8   19 26+8   19 27+8   19 28+8   19 37-8   19 44+8   19 49-8
mirp[min,rnd,grey]  headstem 39
mdrp[grey]  21
f_deltap    21 13+8   21 14+8   21 15+8   21 16+8
mdrp[rp0,rnd,grey]  24
mdap[rnd]   24
f_deltap    24 25-8   24 26-8   24 27-8  
mirp[min,rnd,grey]  vstem 25
ip  7
shpix   8   7
#
shpix   -8 13
shpix   8 19
f_deltap    39 29-4 45 29+4   39 30-4 45 30+4   39 31-4 45 31+4   39 32-4 45 32+4
f_deltap    22 13-4   22 14-4    22 15-4   22 16-4 
IUP[y]
""",

    #ro_ruar
    "uni0E23": """
srp0    48
mdrp[rp0,grey] 10
mdrp[grey]  31 
#
srp0        49
mirp[rp0,rnd,white]  gap_188 32
mdrp[grey]  21
mirp[min,rnd,grey]  hstem 8
mirp[rp0,rnd,grey]  headdia_plus 3
mirp[min,rnd,grey]  headstem 45
mirp[rnd,grey]  headstem_plus_hole 39
#
shpix   8   3
shpix   16  39
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  0
mirp[rp0,rnd,grey]  vheight_shoot 13
alignrp     20
mdrp[grey]  10
mdrp[grey]  18
mirp[rp0,min,rnd,grey]  vstem_98 28
shpix   8  28
mdrp[grey]  23
#
srp0    10
mdrp[grey]  9
mdrp[rp0,grey]  31
mdrp[grey]  32
#
srp0    0
mirp[min,rnd,grey]  headstem 36
mirp[rp0,rnd,grey]  headdia 6
f_deltap    6 9+8  6 10+8   6 11+8   6 12+8   6 13+4    6 14+8   6 15+8   6 16+8   6 21-8   6 27-8   6 28-8   6 37+8   6 44-8   6 49+8
mirp[min,rnd,grey]  headstem 42
shpix   8   0
shpix   -16 6
f_deltap    36 29-4 42 29+4   36 30-4 42 30+4   36 31-4 42 31+4   36 32-4 42 32+4
IUP[y]
""",

    #ro_ru
    "uni0E24": """
f_deltap    46 9+8   46 13-8   46 15-8   46 16-8   46 19+8
srp0            45
mirp[rp0,rnd,white]  gap_229 23
mdrp[grey]      25
mdrp[grey]      8
mirp[rp0,min,rnd,grey]  hstem  11
mdrp[grey]      9
srp0    23
mirp[rp0,rnd,grey]  headdia_plus    17
mirp[min,rnd,grey]  headstem 36
mirp[rnd,grey]  headstem_plus_hole 42
#
srp0            46
mirp[rp0,rnd,white] gap_170 31
mirp[min,rnd,grey]  hstem   1
#
shpix   -16 42
shpix   -8 17
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]           20
mirp[rnd,grey]      vheight_lu 1
mirp[rp0,rnd,grey]  vheight_shoot    28
ip  25
mirp[min,rnd,grey]  vstem_98  5
shpix   8  5
mdap[rnd]   25
alignrp     11
mirp[min,rnd,grey]  vstem   8
shpix   -16 8
srp0    20
mirp[min,rnd,grey]  headstem 33
mirp[rp0,rnd,grey]  headdia 14
f_deltap    14 9+8  14 10+8   14 11+8   14 12+8   14 13+4    14 14+8   14 15+8   14 16+8   14 21-8   14 27-8   14 28-8   14 37+8   14 44-8   14 49+8
mirp[min,rnd,grey]  headstem 39
f_deltap    33 29-4 39 29+4   33 30-4 39 30+4   33 31-4 39 31+4   33 32-4 39 32+4
shpix   8 20
shpix   -16 14
IUP[y]
""",

    #lo_ling
    "uni0E25": """
f_deltap    56 9+8   56 11+8   56 15-8   56 18+8   
srp0    55
mirp[rp0,rnd,white] gap_125 20
mdrp[grey]  35
mirp[min,rnd,grey]  hstem 8
mirp[rp0,rnd,grey]  headdia_plus 14
mirp[min,rnd,grey]  headstem 46
mirp[rnd,grey]  headstem_plus_hole 52
#
srp0    56 
mirp[rp0,rnd,white] gap_170    42
mirp[min,rnd,grey]  hstem   27
shp[rp2]    1
shpix   -16 52
shpix   -8 14
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     17
mirp[rp0,rnd,grey]  vheight_shoot 39
mdrp[grey]  36
mirp[rp0,min,rnd,grey]  vstem_98 31
shpix   8  31
mdrp[rp0,rnd,white] 24
mdap[rnd]   24
mirp[min,rnd,grey]  vstem_98 5
shpix   16  5
mdrp[grey]  27
#
srp0    17
mirp[min,rnd,grey]  headstem 43
mirp[rp0,rnd,grey]  headdia 11
f_deltap    11 9+8  11 10+8   11 11+8   11 12+8   11 13+4    11 14+8   11 15+8   11 16+8   11 21-8   11 27-8   11 28-8   11 37+8   11 44-8   11 49+8
mirp[min,rnd,grey]  headstem 49
shpix   -16 27
#
shpix   8   17
shpix   -16 11
f_deltap    43 29-4 49 29+4   43 30-4 49 30+4   43 31-4 49 31+4   43 32-4 49 32+4
IUP[y]
""",

    #lo_lu
    "uni0E26": """
f_deltap    46 18+8   48 20+8
srp0    45
mirp[rp0,rnd,white]  gap_74 18
mirp[min,rnd,grey]  headstem 42
mirp[rnd,grey]  headstem_plus_hole 36
mirp[rp0,rnd,grey]  headdia_plus 11
mdrp[grey]  9
mirp[rp0,min,rnd,grey]  hstem 23
mdrp[grey]  25
mdrp[grey]  8
#
srp0    46
mirp[rp0,rnd,white]  gap_170   31
mirp[min,rnd,grey]  hstem   1
shpix   8 18
shpix   16 36
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   15
mirp[rnd,grey]  vheight_lu 1
mirp[rp0,rnd,grey]  vheight_shoot 28
ip      25
mirp[min,rnd,grey]  vstem_98   5
shpix   8   5
#
srp0    15
mirp[min,rnd,grey]  headstem 33
mirp[rp0,rnd,grey]  headdia 21
f_deltap    21 9+8  21 10+8   21 11+8   21 12+8   21 13+4    21 14+8   21 15+8   21 16+8   21 21-8   21 27-8   21 28-8   21 37+8   21 44-8   21 49+8
mirp[min,rnd,grey]  headstem 39
#
mdap[rnd]   25
alignrp     11
mirp[min,rnd,grey]  vstem 8
shpix   -16 8
#
shpix   8 15
shpix   -16 21
f_deltap    33 29-4 39 29+4   33 30-4 39 30+4   33 31-4 39 31+4   33 32-4 39 32+4
IUP[y]
""",

    #wo_wan
    "uni0E27": """
srp0    39
mirp[rp0,white]  gap_74 16
#
srp0    40
mirp[rp0,rnd,white]  gap_170 23
mirp[min,rnd,grey]  hstem 8
mirp[rp0,rnd,grey]  headdia_plus 3
mirp[min,rnd,grey]  headstem 36
mirp[rnd,grey]  headstem_plus_hole 30
shpix   8   3
shpix   16  30
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mirp[rp0,rnd,grey]  vheight_shoot 20
mdrp[grey]  17
mirp[rp0,min,rnd,grey]  vstem_98   12
shpix   8  12
mdrp[grey]  16
#
srp0    0
mirp[min,rnd,grey]  headstem 27
mirp[rp0,rnd,grey]  headdia 6
f_deltap    6 9+8  6 10+8   6 11+8   6 12+8   6 13+4    6 14+8   6 15+8   6 16+8   6 21-8   6 27-8   6 28-8   6 37+8   6 44-8   6 49+8
mirp[min,rnd,grey]  headstem 33
#
shpix   8  0
shpix   -16 6
f_deltap    27 29-4 33 29+4   27 30-4 33 30+4   27 31-4 33 31+4   27 32-4 33 32+4
IUP[y]
""",

    #so_sala
    "uni0E28": """
f_deltap    65 14-8   65 15-8   65 16-8   65 17+8   65 18+8   65 20+8   65 24-8   65 35-8   65 36+8   
srp0    64
mirp[rp0,rnd,white] gap_203 18
mdrp[grey]  21
mirp[rp0,min,rnd,grey]  hstem 16
mdrp[grey]  47
ip  49
mirp[min,rnd,grey]  headstem 61
f_deltap    61 37-8   61 38-8   61 39-8 
mirp[rp0,rnd,grey]  headdia 10
f_deltap    10 9+4  10 10+4   10 11+8   10 12+8   10 13+4    10 14+8   10 15+8   10 16+8   10 21-8   10 28-8   10 33+8   10 45+8   10 46+8   10 49+8
ip  7 
mirp[min,rnd,grey]  headstem 55
shpix   -8 10
shpix   -16 61
f_deltap    61 29-4 55 29+4   61 30-4 55 30+4   61 31-4 55 31+4   61 32-4 55 32+4
#
srp0     65
mirp[rp0,rnd,white] gap_170 37
mirp[rp0,min,rnd,grey]  hstem 1
sloop   4
ip  27 34 4 41
mdrp[rp0,grey]  31
mdrp[grey]  30
#
shpix   -16 34
shpix   8   41
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]           0
ALIGNRP             17
MIRP[rp0,rnd,grey]  vheight_shoot  24
ip  38
mdrp[min,rnd,grey]  31
MIRP[min,rnd,grey]  vstem_98  44
shpix   8 44
mdap[rnd]  38
f_deltap    38 9-4   38 10-4  38 16-8
mdrp[grey]  19
mdrp[grey]  49
mdrp[grey]  16
f_deltap    49 14-4 16 14+4   49 15-4 16 15+4   49 16-4 16 16+4
MIRP[min,rnd,grey]  headstem  58
MIRP[rp0,rnd,grey]  headdia  13
f_deltap    13 9-8  13 10-8   13 11-8   13 12-8   13 13-4    13 14-8   13 15-8   13 16-8   13 21+8   13 27+8   13 28+8   13 37-8   13 38-8   13 49-8
ip  7
MIRP[min,rnd,grey]  headstem  52
shpix   -8  38
shpix   8   13
f_deltap    52 29-4 58 29+4   52 30-4 58 30+4   52 31-4 58 31+4   52 32-4 58 32+4
IUP[y]
""",

    #so_rusi
    "uni0E29": """
f_deltap    68 18+8   68 20+8
srp0    67
mirp[rp0,rnd,white] gap_74 9
mirp[min,rnd,grey]  headstem 64
mirp[rnd,grey]  headstem_plus_hole 58
mirp[rp0,rnd,grey]  headdia_plus 15
f_deltap    15 37+8   15 41+8   15 43-8  15 44-8   15 48-8
alignrp     53
mirp[rp0,min,rnd,grey]  hstem 3
mdrp[grey]  1
#
srp0    68
mirp[rp0,rnd,grey]  gap_170 38
alignrp 41
mirp[min,rnd,grey]  hstem 36
shp[rp2]    46
#
shpix   8 9
shpix   16 58
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  0
mirp[min,rnd,grey]  vstem 44
shp[rp2]    3
mirp[rp0,rnd,grey]  vheight 12
alignrp 38
sloop   10
ip  16 19 22 33 36 39 53 50 47 41
mirp[min,rnd,grey]  headstem 61
mirp[rp0,rnd,grey]  headdia 6
f_deltap    6 9-8  6 10-8   6 11-8   6 12-8   6 13-4    6 14-8   6 15-8   6 16-8   6 21+8   6 27+8   6 28+8   6 37-8   6 44+8   6 49-8
mirp[min,rnd,grey]  headstem 55
#
shpix   -8  12
shpix   16  6
f_deltap    55 29-4 61 29+4   55 30-4 61 30+4   55 31-4 61 31+4   55 32-4 61 32+4
IUP[y]
""",

    #so_sua
    "uni0E2A": """
f_deltap    74 9+8   74 11+8   74 15-8
srp0    73
mirp[rp0,rnd,white] gap_125 20
mdrp[grey]  34
mirp[min,rnd,grey]  hstem 8
mirp[rp0,rnd,grey]  headdia_plus 14
mirp[min,rnd,grey]  headstem 64
mirp[rnd,grey]  headstem_plus_hole 70
#
srp0    74
mirp[rp0,rnd,white] gap_170    51
mirp[min,rnd,grey]  hstem   52
shp[rp2]    1
sloop       4
ip  41 48 55 27
srp1    8
ip  58
mdrp[rp0,grey]  45
mdrp[grey]  44
#
shpix   -16 70
shpix   -8 14
shpix   8   27
shpix   -8  48
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     17
mirp[rp0,rnd,grey]  vheight_shoot 38
mdrp[grey]  41
mdrp[grey]  48
mdrp[grey]  35
mdrp[min,rnd,grey]  44
mirp[rp0,min,rnd,grey]  vstem_98 30
shpix   8  30
mdrp[grey]  27
mdrp[grey]  55
mdrp[grey]  34
mdrp[rp0,rnd,white] 24
mdap[rnd]   24
mirp[min,rnd,grey]  vstem_98 5
shpix   16  5
ip  58
mdrp[grey]  52
#
srp0    17
mirp[min,rnd,grey]  headstem 61
mirp[rp0,rnd,grey]  headdia 11
f_deltap    11 9+8  11 10+8   11 11+8   11 12+8   11 13+4    11 14+8   11 15+8   11 16+8   11 21-8   11 27-8   11 28-8   11 37+8   11 44-8   11 49+8
mirp[min,rnd,grey]  headstem 67
shpix   -16 52
#
shpix   8   17
shpix   -16 11
f_deltap    61 29-4 67 29+4   61 30-4 67 30+4   61 31-4 67 31+4   61 32-4 67 32+4
IUP[y]
""",

    #ho_hib
    "uni0E2B": """
f_deltap    68 12-8   68 18+8   68 19+8   69 21+8
srp0        67
mirp[rp0,rnd,white]     gap_74 16
f_deltap    16 14-8
mirp[min,rnd,grey]  headstem 52
mirp[rnd,grey]  headstem_plus_hole 46
mirp[rp0,rnd,grey]  headdia_plus 22
f_deltap    22 17+8   22 26+8   22 27+8   22 36+8   22 37+8   22 39+8  22 40+8  22 41+8  22 43-8   22 44-8   22 48-8
alignrp     9
mirp[min,rnd,grey]  hstem 10
#
srp0        68
mirp[rp0,rnd,white] gap_170 42
mirp[min,rnd,grey]  hstem 1
mdrp[rp0,rnd,grey]  36
mirp[min,rnd,grey]  headstem 58
mirp[rp0,rnd,grey]  headdia 30
f_deltap    30 9-8  30 10-8  30 11-8  30 12-8  30 13-4   30 14-8   30 15-8   30 16-8   30 27+8   30  28+8   30 29-8   30 30-8   30 31-8   30 32-8   30 37-8   30 38-8   30 49-8   30 50-8   
ip  39
ip  27
mirp[min,rnd,grey]  headstem 64
srp0    27
mdrp[grey]  24
mdrp[grey]  8
#
shpix   8   16
shpix   16  46
shpix   8   30
shpix   -8  36
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   9
alignrp     0
mdrp[grey]  23
mirp[rp0,rnd,grey]  vheight 19
alignrp     33
mirp[min,rnd,grey]  headstem 49
shp[rp2]    61
mirp[rp0,rnd,grey]  headdia 13
f_deltap    13 9-8  13 10-8   13 11-8   13 12-8   13 13-4    13 14-8   13 15-8   13 16-8   13 21+8   13 27+8   13 28+8   13 37-8   13 44+8   13 49-8
mirp[min,rnd,grey]  headstem 43
shp[rp2]    55
srp0    55
mdrp[rp0,grey]  5
ip      27
ip      39
mdrp[grey]  24
mdrp[grey]  8
shpix   -8  19
shpix   16  13
shpix   -8   33
f_deltap    43 29-4 49 29+4   43 30-4 49 30+4   43 31-4 49 31+4   43 32-4 49 32+4
f_deltap    55 29-4 61 29+4   55 30-4 61 30+4   55 31-4 61 31+4   55 32-4 61 32+4
IUP[y]
""",

    #lo_jula
    "uni0E2C": """
f_deltap    63 14+8   63 17+8   63 18+8   63 20+8   63 23+8   63 28+8   63 43+8   
srp0    62
mirp[rp0,rnd,white]  gap_74 10
mirp[min,rnd,grey]  headstem 47
mirp[rnd,grey]  headstem_plus_hole 41
mirp[rp0,rnd,grey]  headdia_plus 16
f_deltap    16 17+8
alignrp     3
mirp[min,rnd,grey]  hstem 4
#
srp0    63
mirp[rp0,rnd,white] gap_188 37
mdrp[grey]  35
ip  34
ip  32
mirp[min,rnd,grey]  hstem   20
shp[rp2]    1
srp1    16
sloop   3
ip      18 19 2
mirp[rp0,rnd,grey]  headdia_plus 26
mirp[min,rnd,grey]  headstem 59
mirp[rnd,grey]  headstem_plus_hole 53
#
shpix   8   10
shpix   16  41
shpix   8   26
shpix   16  53
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mdrp[grey]  20
shp[rp2]    17
mirp[rp0,rnd,grey]  vheight 13
alignrp     23
sloop       4
ip  18 2 17 20
mirp[min,rnd,grey]  headstem 44
mirp[rp0,rnd,grey]  headdia 7
f_deltap    7 9-8  7 10-8   7 11-8   7 12-8   7 13-4    7 14-8   7 15-8   7 16-8   7 21+8   7 27+8   7 28+8   7 37-8   7 44+8   7 49-8
mirp[min,rnd,grey]  headstem 38
srp0    23
mirp[min,rnd,grey]  headstem 50
mirp[rp0,rnd,grey]  headdia 29
f_deltap    29 9+8  29 10+8   29 11+8   29 12+8   29 13+4    29 14+8   29 15+8   29 16+8   29 21-8   29 27-8   29 28-8   29 37+8   29 44-8   29 49+8
sloop   3
ip  34 35 32
mirp[min,rnd,grey]  headstem 56
#
shpix   -8  13
shpix   16  7
shpix   -8  29
shpix   16  23
shpix   -8  32
f_deltap    38 29-4 44 29+4   38 30-4 44 30+4   38 31-4 44 31+4   38 32-4 44 32+4
f_deltap    50 29-4 56 29+4   50 30-4 56 30+4   50 31-4 56 31+4   50 32-4 56 32+4
IUP[y]
""",

    #aw_ang
    "uni0E2D": """
f_deltap    52 9+8   
srp0    51
mirp[rp0,rnd,white] gap_125 3
mdrp[grey]  29
mirp[min,rnd,grey]  hstem 15
mirp[rp0,rnd,grey]  headdia_plus 10
mirp[min,rnd,grey]  headstem   42
mirp[rnd,grey]  headstem_plus_hole 48
#
srp0     52
mirp[rp0,rnd,white]  gap_170 36
mirp[min,rnd,grey]  hstem 21
#
shpix   -16 48
shpix   -8  10
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mirp[min,rnd,grey]  vstem   19
mirp[rp0,rnd,grey]  vheight_shoot  33
mdrp[grey]  30
mirp[rp0,min,rnd,grey]  vstem_98   25
shpix   8  25
mdrp[rp0,grey]  29
mdrp[rp0,rnd,white]  7
mdap[rnd]   7
f_deltap    7 12-8   7 14-8   
mirp[min,rnd,grey]  headstem    45
mirp[rp0,rnd,grey]  headdia 13
f_deltap    13 9-8  13 10-8   13 11-8   13 12-8   13 13-4    13 14-8   13 15-8   13 16-8   13 21+8   13 27+8   13 28+8   13 37-8   13 44+8   13 49-8
mirp[min,rnd,grey]  headstem    39
#
f_deltap    39 29-4 45 29+4   39 30-4 45 30+4   39 31-4 45 31+4   39 32-4 45 32+4
shpix   -8  7
shpix   16  13
IUP[y]
""",

    #ho_nokhuk
    "uni0E2E": """
f_deltap    73 9+8   
srp0    72
mirp[rp0,rnd,white]  gap_125 3
mdrp[grey]  30
mirp[rp0,min,rnd,grey]  hstem 15
mdrp[grey]  56
srp0    3
mirp[rp0,rnd,grey]  headdia_plus 10
mirp[min,rnd,grey]  headstem   63
mirp[rnd,grey]  headstem_plus_hole 69
#
srp0     73
mirp[rp0,rnd,white]  gap_188 44
mirp[min,rnd,grey]  hstem 21
sloop   4
ip  50 36 41 24
mdrp[rp0,grey]  39
mdrp[grey]  39
#
shpix   -16 69
shpix   -8  10
f_deltap    41 11-4   41 12-4   41 13-4   41 14-4   41 15-4   41 16-4   50 17+8   50 18+8   
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mirp[min,rnd,grey]  vstem   19
mirp[rp0,rnd,grey]  vheight_shoot  33
mdrp[min,rnd,grey]  39
mirp[min,rnd,grey]  vstem_98   53
shpix   8  53
mdap[rnd]   7
f_deltap    7 13-8   7 18-8   7 19-8   7 30-8   
srp2    53
sloop   6
ip  36 50 41 24 47 27
mirp[min,rnd,grey]  headstem    66
mirp[rp0,rnd,grey]  headdia 13
f_deltap    13 9-8  13 10-8   13 11-8   13 12-8   13 13-4    13 14-8   13 15-8   13 16-8   13 21+8   13 27+8   13 28+8   13 37-8   13 44+8   13 49-8
mirp[min,rnd,grey]  headstem    60
#
shpix   -8  7
shpix   16  13
f_deltap    60 29-4 66 29+4   60 30-4 66 30+4   60 31-4 66 31+4   60 32-4 66 32+4
f_deltap   47 12-4   47 13-3 27 13-1   47 14-3 27 14-2   47 15-4 27 15-2    47 16-4 27 16-2   47 17-3   47 18-3 27 18+2   47 19-4 27 19-2   47 20-4 27 20-2    47 21-4 27 21-2   47 22-4 27 22-2    47 23-3   47 24-2   47 25-2   47 26-2   47 27-2   47 28-2   47 29-2   47 30-2   47 31-2   47 33-2
IUP[y]
""",

    #paiyannoi
    "uni0E2F": """
srp0    37
mdrp[rp0,rnd,grey]  25
mdrp[grey]  14
#
srp0    38
mirp[rp0,rnd,white]  gap_170 36
mirp[min,rnd,grey]  hstem 1
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mirp[rp0,rnd,grey]  vheight 35
mdrp[min,rnd,grey]  4
mdrp[rp0,rnd,grey]  22
mdrp[grey]  17
mdrp[rp0,rnd,grey]  28
mdrp[min,rnd,grey]  11
IUP[y]
""",

    #sara_a
    "uni0E30": """
f_deltap    61 9+8
srp0    60
mirp[rp0,rnd,white]  gap_125 3
alignrp 33
mirp[min,rnd,grey]  headstem 27
f_deltap    27 29-4 27 30-4 27 31-4 27 32-4
shp[rp2]    57
mirp[rp0,rnd,grey]  headdia 9
f_deltap    9 9+8  9 10+8   9 11+8   9 12+8   9 13+4    9 14+8   9 15+8   9 16+8   9 21-8   9 27-8   9 28-8   9 37+8   9 44-8   9 49+8
alignrp 39
mirp[min,rnd,grey]  headstem 21
f_deltap    21 29+4 21 30+4 21 31+4 21 32+4
shp[rp2]    51
mdrp[grey]  11
shp[rp2]    41
#
srp0    61
mirp[rp0,rnd,white] gap_170 15
alignrp 45
mirp[min,rnd,grey]  w_150 14
shp[rp2]    44
#
shpix   8   3
shpix   8   33
shpix   -8  9
shpix   -8  39
shpix   -16 11
shpix   -16 41
f_deltap    12 13+8   12 14+8   12 15+8
f_deltap    42 13+8   42 14+8   42 15+8
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]  0
mirp[min,rnd,grey]  vstem_98 11
mdrp[rp0,rnd,grey]  6
f_deltap    6 22+8  6 23+8
mirp[min,rnd,grey]  headstem 24
mirp[rnd,grey]  headstem_plus_hole 18
mdrp[grey]  15
shpix   8 0
#
mdap[rnd]   36
mirp[min,rnd,grey]  headstem 54
mirp[rnd,grey]  headstem_plus_hole 48
mdrp[grey]  45
mdrp[rp0,rnd,grey]  30
f_deltap    30 22-8  30 23-8
mirp[min,rnd,grey]  vstem_98 41
shpix   8 30
#
shpix   -16 18
shpix   -16 48
shpix   -8  6
shpix   -8  36
f_deltap    18 29+4 24 29+4   18 30+4 24 30+4   18 31+4 24 31+4   18 32+4 24 32+4
f_deltap    48 29+4 54 29+4   48 30+4 54 30+4   48 31+4 54 31+4   48 32+4 54 32+4
IUP[y]
""",

    #sara_maihanakat
    "uni0E31": """
mdap[rnd]   14
mirp[min,rnd,grey]  w_150 15
mdrp[rp0,rnd,grey]  3
mdap[rnd]   3
f_deltap    3 9-8
mirp[min,rnd,grey]  headstem 27
mirp[rp0,rnd,grey]  headdia 9
f_deltap    9 9+8  9 10+8   9 11+8   9 12+8   9 13+4    9 14+8   9 15+8   9 16+8   9 21-8   9 27-8   9 28-8   9 37+8   9 38+8   9 44-8   9 49+8
mirp[min,rnd,grey]  headstem 21
mdrp[grey]  11
#
shpix   8 3
shpix   -16 9
shpix   -16  11
f_deltap    27 29-4 21 29+4   27 30-4 21 30+4   27 31-4 21 31+4   27 32-4 21 32+4
f_deltap    12 14+3 17 14+1   12 15+3 17 15+1  12 16+3 17 16+1  12 17+3 17 17+1
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
f_deltap    0 9+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8   
mdrp[min,rnd,grey]  18
f_deltap    18 20+8   18 21+8   18 25+8   
ip  11
mdrp[rp0,rnd,grey]  6
f_deltap    6 31-8   6 32-8   6 42-8   6 45+8   6 46+8  6 47+8
mirp[min,rnd,grey]  headstem 24
f_deltap    24 29+4   24 30+4   24 31+4   24 32+4   
mdrp[grey]  14
#
shpix   8   0
shpix   -16 18
shpix   -8   6
IUP[y]
""",

    #sara_aa
    "uni0E32": """
f_deltap    19 18+8
srp0    18
mirp[rp0,white]  gap_74 9
#
srp0    19
mirp[rp0,rnd,white] gap_170 16
mirp[min,rnd,grey]  hstem 1
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rp0,rnd,grey]  vheight_shoot 13
mdrp[grey]  10
mirp[rp0,min,rnd,grey]  vstem_98   5
shpix   8  5
mdrp[grey]  9
IUP[y]
""",

    #sara_am
    #uni0E33: use sara_aa with nikahit
    
    #sara_i
    "uni0E34": """
mdap[rnd]   0
mdrp[grey]  8
mdrp[rp0,rnd,grey]  4
mdrp[grey]  12
IUP[x]
#
SVTCA[y-axis]
f_deltap    14 9+8   14 10+8   14 11+8   14 12+8   14 13+8   14 14+8   14 16+8   
mdap[rnd]   14
mdrp[grey]  2
mdrp[rp0,rnd,white] 10 
mdrp[min,rnd,grey]  6
shpix   8 10
IUP[y]
""",

    #sara_ii
    "uni0E35": """
mdap[rnd]   0
mdrp[grey]  13
mdrp[rp0,rnd,grey]  10
mdrp[min,rnd,grey]  8
srp0    0
mdrp[rp0,rnd,grey]  4
mdrp[grey]  17
shpix   -8  10
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   19
f_deltap    19 9+8   19 10+8   19 11+8   19 12+8   19 13+8   19 14+8   19 16+8   
mdrp[grey]  2
mdrp[rp0,rnd,white]  15
mdrp[rp0,min,rnd,grey]  6
mdrp[min,rnd,grey]  10
shpix   8  15
IUP[y]
shpix   -16 8
""",

    #sara_ue
    "uni0E36": """
mdap[rnd]   0
mdrp[grey]  20
mdrp[rp0,rnd,grey]  14
mdrp[grey]  8
ip  31
ip  37
srp0    0
mdrp[rp0,rnd,grey]  4
mdrp[grey]  24
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   26
f_deltap    26 9+8   26 10+8   26 11+8   26 12+8   26 13+8   26 14+8   26 16+8   
mdrp[grey]  2
mdrp[rp0,rnd,white]  22
mdrp[rp0,min,rnd,grey]  6
mdrp[rp0,min,rnd,grey]  11
mdrp[grey]  18
ip  34
ip  28
ip  8
shpix   8 22
IUP[y]
""",

    #sara_uee
    "uni0E37": """
mdap[rnd]   0
mdrp[grey]  18
mdrp[rp0,rnd,grey]  15
mdrp[rp0,min,rnd,grey]  13
mdrp[rp0,min,rnd,white]  10
mdrp[min,rnd,grey]  8
srp0    0
mdrp[rp0,rnd,grey]  4
mdrp[grey]  22
shpix   -8 15
shpix   -8 10
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   24
f_deltap    24 9+8   24 10+8   24 11+8   24 12+8   24 13+8   24 14+8   24 16+8   
mdrp[rp0,rnd,white]  20
mdrp[rp0,min,rnd,grey]  6
mdrp[min,rnd,grey]  9
shp[rp2]    14
shpix   8 20
IUP[y]
""",

    #sara_u
    "uni0E38": """
mdap[rnd]   0
mdrp[min,rnd,grey]  1
mdrp[min,rnd,grey]  17
f_deltap    17 21-8   17 22-8  17 24+8  17 25+8  
mdrp[rp0,rnd,grey]  7
f_deltap    7 20+8   7 37+8  7 38+8  7 39+8  
mdrp[min,rnd,grey]  23
shpix   -8  0
shpix   8   7
shpix   8   17
IUP[x]
SVTCA[y-axis]
mdap[rnd]   10
f_deltap    10 9-8   10 10-8  10 11-8  10 12-8  10 13-8  10 14-8  10 15-8
mdrp[min,rnd,grey]  20
mdrp[rp0,rnd,grey]  4
f_deltap    4 29+8   4 30+8   4 42+8
mdrp[min,rnd,grey]  14
mdrp[min,rnd,grey]  0
shpix   -8 10
shpix   16  4
IUP[y]
""",

    #sara_uu
    "uni0E39": """
mdap[rnd]   21
mdrp[rp0,min,rnd,grey]  19
mdrp[rp0,rnd,grey]  14
mdrp[min,rnd,grey]  3
mdrp[min,rnd,grey]  27
mdrp[rp0,rnd,grey]  8
f_deltap    8 22+8   
mdrp[min,rnd,grey]  33
shpix   8   8
shpix   8   27
shpix   -8  21
shpix   -8  14
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   11
f_deltap    11 9-8   11 10-8   11 11-8   11 12-8   11 13-8   11 14-8   11 15-8
alignrp 21
mdrp[min,rnd,grey]  30
mdrp[rp0,rnd,grey]  5
mdrp[min,rnd,grey]  24
mdrp[rp0,rnd,grey]  0
mdrp[min,rnd,grey]  17
shpix   -8  11
shpix   8   5
IUP[y]
""",

    #pinthu
    "uni0E3A": """
mdap[rnd]   9
mdrp[min,rnd,grey]  3
IUP[x]
SVTCA[y-axis]
mdap[rnd]   6
f_deltap    6 9-8   6 10-8   6 11-8   6 12-8   6 13-8   6 14-8   6 15-8
mdrp[min,rnd,grey]  0
IUP[y]
""",

    #thai_baht
    "uni0E3F": """
f_deltap    52 9+8   
srp0    51
mdrp[rp0,rnd,grey]  5
f_deltap    5 11-8   5 18-8   5 19-8   
mdrp[grey]  3
shp[rp2]    7
mdrp[min,rnd,grey]  29
shp[rp2]    42
#
srp0    52
mdrp[rp0,rnd,white] 22
mdrp[min,rnd,grey]  35
mdrp[rp0,rnd,grey]  16
mdrp[min,rnd,grey]  47
srp1        30
ip  1
#
mdap[rnd]   1
alignrp 27
alignrp 40
alignrp 9
mdrp[rp0,grey]  0
alignrp 39
alignrp 50
alignrp 11
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   2
alignrp     26
mdrp[rnd,grey]  1
mdrp[min,rnd,grey]  27
shp[rp2]    31
shp[rp2]    5
mdrp[rp0,rnd,grey]  40
alignrp 44
mdrp[min,rnd,grey]  28
ip  19
shp[rp2]    38
srp0        2
mdrp[rp0,rnd,grey]  9
alignrp 12
mdrp[rnd,grey]  10
mdrp[min,rnd,grey]  41
shp[rp2]    50
shp[rp2]    7
IUP[y]
""",

    #sara_e
    "uni0E40": """
srp0    27
mirp[rp0,rnd,white]  gap_102 11
mirp[min,rnd,grey]  headstem 17
mirp[rnd,grey]  headstem_plus_hole 23
mirp[rp0,rnd,grey]  headdia_plus 3
mirp[min,rnd,grey]  hstem 5
shpix   -16 23
shpix   -8  11
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mirp[rnd,grey]  vheight 4
mirp[min,rnd,grey]  headstem 14
mirp[rp0,rnd,grey]  headdia 8
f_deltap    8 9+8  8 10+8   8 11+8   8 12+8   8 13+4    8 14+8   8 15+8   8 16+8   8 21-8   8 27-8   8 28-8   8 37+8   8 44-8   8 49+8
mirp[min,rnd,grey]  headstem 20
shpix   -8  8
shpix   8   0
f_deltap    14 29-4 20 29+4   14 30-4 20 30+4   14 31-4 20 31+4   14 32-4 20 32+4
IUP[y]
""",

    #sara_ae
    #use sara_a reference: uni0E40

    #sara_o
    "uni0E42": """
srp0    46
mirp[rp0,white]  gap_74 5
mdrp[grey]  24
#
srp0    47
mirp[rp0,rnd,white] gap_74 31
mirp[min,rnd,grey]  headstem 37
mirp[rnd,grey]  headstem_plus_hole 43
mirp[rp0,rnd,grey]  headdia_plus 3
mirp[rp0,min,rnd,grey]  hstem   25
mdrp[grey]  15
shpix   -16 43
shpix   -8  31
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mirp[min,rnd,grey]  headstem   34
mirp[rp0,rnd,grey]  headdia 28
f_deltap    28 9+8  28 10+8   28 11+8   28 12+8   28 13+4    28 14+8   28 15+8   28 16+8   28 21-8   28 27-8   28 28-8   28 37+8   28 44-8   28 49+8
mirp[min,rnd,grey]  headstem   40
mdap[rnd]   7
mdrp[grey]  14
mdrp[grey]  12
mdrp[grey]  5
mirp[min,rnd,grey]  vstem 22
shpix   16  22
mdrp[grey]  17
#
srp0    5
mdrp[grey]  4
mdrp[rp0,grey]  24
mdrp[grey]  25
#
shpix   -8 28
shpix   8   0
f_deltap    34 29-4 40 29+4   34 30-4 40 30+4   34 31-4 40 31+4   34 32-4 40 32+4
IUP[y]
""",

    #sara_ai_maimoun
    "uni0E43": """
f_deltap    61 14+8   61 16+8   
srp0    60
mirp[rp0,rnd,white] gap_74 33
f_deltap    33 14-8   33 15-8   33 16-8   33 18-8   33 19-8   33 20-8 
mdrp[min,rnd,grey]  10
#
srp0    61
mirp[rp0,rnd,white] gap_74 45
mirp[min,rnd,grey]  headstem 51
mirp[rnd,grey]  headstem_plus_hole 57
mirp[rp0,rnd,grey]  headdia_plus 3
mirp[min,rnd,grey]  hstem 39
srp2    10
sloop   4
ip      21 22 16 27
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mirp[min,rnd,grey]  headstem 48
mirp[rp0,rnd,grey]  headdia 42
f_deltap    42 9+8  42 10+8   42 11+8   42 12+8   42 13+4    42 14+8   42 15+8   42 16+8   42 21-8   42 27-8   42 28-8   42 37+8   42 44-8   42 49+8
mirp[min,rnd,grey]  headstem 54
#
mdap[rnd]   36
mdrp[min,rnd,grey]  7
shpix   8   7
mdrp[rp0,grey]  30
ip  24
ip  19
mdrp[grey]  13
f_deltap    48 29-4 54 29+4   48 30-4 54 30+4   48 31-4 54 31+4   48 32-4 54 32+4
IUP[y]
""",

    #sara_ai_malai
    "uni0E44": """
f_deltap    61 12-8
srp0    60
mirp[rp0,rnd,grey]  gap_102 17
mdrp[grey]  21
mdrp[min,rnd,grey]  25
#
srp0    61
mirp[rp0,rnd,white] gap_74 45
f_deltap    45 14+8   45 15+8
mirp[min,rnd,grey]  headstem 51
mirp[rnd,grey]  headstem_plus_hole 57
mirp[rp0,rnd,grey]  headdia_plus 3
mirp[min,rnd,grey]  hstem 39
srp2    25
ip      10
ip      32
shpix   -8  25
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mirp[min,rnd,grey]  headstem 48
mirp[rp0,rnd,grey]  headdia 42
f_deltap    42 9+8  42 10+8   42 11+8   42 12+8   42 13+4    42 14+8   42 15+8   42 16+8   42 21-8   42 27-8   42 28-8   42 37+8   42 44-8   42 49+8
mirp[min,rnd,grey]  headstem 54
#
mdap[rnd]   36
mdrp[grey]  22
mdrp[grey]  7
mdrp[rp0,rnd,grey]  14
mdrp[grey]  29
f_deltap    48 29-4 54 29+4   48 30-4 54 30+4   48 31-4 54 31+4   48 32-4 54 32+4
IUP[y]
""",

    #lakkhangyao
    "uni0E45": """
srp0    18
mirp[rp0,white]  gap_150 9
#
srp0    19
mirp[rp0,rnd,white] gap_188 16
mirp[min,rnd,grey]  hstem 1
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   18
mirp[rnd,grey]  vheight_lu  1
mirp[rp0,rnd,grey]  vheight_shoot 13
mdrp[grey]  10
mirp[rp0,min,rnd,grey]  vstem_98   5
shpix   8  5
mdrp[grey]  9
IUP[y]
""",

    #maiyamok
    "uni0E46": """
srp0    39
mdrp[rp0,rnd,grey]  13
mdrp[grey]  8
mirp[min,rnd,grey]  headstem 30
mirp[rp0,rnd,grey]  headstem_plus_hole 36
mdrp[grey]  19
#
srp0    40
mirp[rp0,rnd,white] gap_188 25
mirp[min,rnd,grey]  hstem 1
srp1    8
sloop   6
ip  21 6 22 5 23 4
#
shpix   -8 36
shpix   -8 13
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   39
mirp[rnd,grey]  vheight_lu 1
mirp[rp0,rnd,grey]  vheight 21
alignrp 23
mirp[min,rnd,grey]  vstem   6
shpix   8   6
shp[rp2]    4
mdrp[rp0,rnd,grey]  22
mirp[min,rnd,grey]  vstem_98   5
mdrp[rp0,rnd,white] 10
mirp[min,rnd,grey]  headstem    33
mirp[rp0,rnd,grey]  headdia 16
f_deltap    16 9-8  16 10-8   16 11-8   16 12-8   16 13-4    16 14-8   16 15-8   16 16-8   16 21+8   16 27+8   16 28+8   16 37-8   16 38-8   16 49-8   16 50-8
mirp[min,rnd,grey]  headstem    27
#
shpix   -16 10
shpix   8   16
f_deltap    27 29-4 33 29+4   27 30-4 33 30+4   27 31-4 33 31+4   27 32-4 33 32+4
IUP[y]
""",

    #maitaikhu
    "uni0E47": """
mdap[rnd]   48
mdrp[rp0,rnd,grey]  23
mdrp[min,rnd,grey]  17
srp0    48
mdrp[min,rnd,grey]  54
mdrp[rp0,rnd,grey]  42
mdrp[min,rnd,grey]  60
srp0    48
mdrp[rp0,rnd,grey]  10
mdrp[min,rnd,grey]  30
shpix   -8 48
shpix   8   42
shpix   8   10
shpix   -4  30
shpix   -8  23
shpix   4   17
f_deltap   3 11+4 36 11+4   3 12+4 36 12+4   3 13+4 36 13+4   3 14+8 36 14+8   3 15+4 36 15+4   3 16+8 36 16+8
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
dyx
f_deltap    0 9+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8
alignrp     7
mdrp[min,rnd,grey]  51
mdrp[rp0,rnd,grey]  45
mdrp[min,rnd,grey]  57
srp0    7
mdrp[min,rnd,grey]  32
mdrp[rp0,rnd,grey]  3
mdrp[min,rnd,grey]  36
srp0    45
mdrp[rp0,min,rnd,grey]  26
mdrp[rp0,min,rnd,grey]  14
mdrp[min,rnd,grey]  21
shpix   4 26
shpix   -8 14
shpix   -8  45
shpix   8   0
shpix   8   3
f_deltap    51 9-8  51 10-8
IUP[y]
""",

    #maiek
    "uni0E48": """
mdap[rnd]   6
f_deltap    6 14+8   6 15+8   6 16+8   6 17+8  6 20-8  6 21-8  6 22-8   6 31-8  
mdrp[grey]  5
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap    0 9+8   0 10+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8
f_deltap    0 9+8   0 11+8   0 12+8   0 20+8   0 21+8  0 26+8
mdrp[grey]  6
IUP[y]
""",

    #maiek
    "uni0E48.low": """
mdap[rnd]   6
mdrp[min,rnd,grey]  5
shpix   -8  6
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap    0 9+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8
mdrp[min,rnd,grey]  6
IUP[y]
""",

    #maitho
    "uni0E49": """
MDAP[rnd]   23
f_deltap    23 14+8   23 15+8   23 16+8   23 17+8  23 20-8  23 21-8  23 22-8   23 31-8  
mdrp[grey]  19
mdrp[rp0,rnd,grey]  14
mdrp[min,rnd,grey]  8
ip  35
ip  29
ip  1
shpix   -8 14
shpix   8   8
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
f_deltap    0 9+8   0 10+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8
f_deltap    0 9+8   0 11+8   0 12+8   0 20+8   0 21+8  0 26+8
mdrp[rp0,rnd,grey]  5
mdrp[rp0,min,rnd,grey]  11
ip  32
ip  26
mdrp[grey]  21
shpix   -8 11
shpix   8 5
shpix   8 0
IUP[y]
""",

    #maitho
    "uni0E49.low": """
MDAP[rnd]   23
mdrp[min,rnd,grey]  19
mdrp[rp0,rnd,grey]  14
mdrp[min,rnd,grey]  29
mdrp[rp0,rnd,grey]  8
f_deltap    8 24+8  8 25+8  8 26+8  
ip  3
ip  16
mdrp[grey]  0
mdrp[min,rnd,grey]  35
shpix   -4  23
shpix   8   19
shpix   -8  14
shpix   8   8
shpix   8   29
f_deltap    29 9-6   14 10-8  0 11+6   3 17+4  3 18+4  3 19+4
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
f_deltap    0 9+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8
mdrp[min,rnd,grey]  16
mdrp[rp0,rnd,grey]  5
f_deltap    5 17+8  5 18+8
mdrp[min,rnd,grey]  26
ip  3
mdrp[rp0,rnd,grey]  11
mdrp[min,rnd,grey]  32
mdrp[grey]  21
shpix   -8  11
shpix   8   5
shpix   8   0
f_deltap    5 12+8   5 13+8  5 14+8  5 15+8  5 16+8  
IUP[y]
""",

    #maitri
    "uni0E4A": """
MDAP[rnd]   31
f_deltap    31 14+8   31 15+8   31 16+8   31 17+8  31 20-8  31 21-8  31 22-8   31 31-8  
mdrp[rp0,min,rnd,grey]  36
mdrp[grey]  46
srp0    31
mdrp[rp0,rnd,grey]  23
f_deltap    23 9-8  23 10-8  23 11-8  
ip  4
ip  12
mdrp[min,rnd,grey]  17
f_deltap    17 12-8  17 13-8  17 14-8  17 15-8  17 19-8  17 20-8   
ip  58
ip  52
shpix   8 23
shpix   -8 31
shpix   -8 46
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
f_deltap    0 9+8   0 10+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8
f_deltap    0 9+8   0 11+8   0 12+8   0 20+8   0 21+8  0 26+8
alignrp     20
mdrp[min,rnd,grey]  14
ip  55
ip  49
ip  33
mdrp[rp0,rnd,grey]  26
sloop   5
ip  28 9 7 27 8
mdrp[min,rnd,grey]  43
shpix   8 20
shpix   -8 14
IUP[y]
""",

    #maitri
    "uni0E4A.low": """
MDAP[rnd]   46
mdrp[grey]  36
mdrp[rp0,min,rnd,grey]  31
mdrp[grey]  4
mdrp[rp0,rnd,grey]  23
mdrp[grey]  12
mdrp[min,rnd,grey]  58
mdrp[rp0,rnd,grey]  17
mdrp[min,rnd,grey]  52
shpix   -8 58
shpix   -8 17
f_deltap    17 16-8  17 17-8  17 18-8
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
f_deltap    0 9+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8
alignrp     20
mdrp[grey]  33
srp0    20
mdrp[min,rnd,grey]  49
mdrp[rp0,rnd,grey]  14
mdrp[min,rnd,grey]  55
#
mdrp[rp0,rnd,grey]  26
alignrp     28
mdrp[grey]  43
mdrp[grey]  9
shp[rp2]    7
ip  27
ip  8
shpix   -8  14
shpix   8   20
IUP[y]
""",

    #maichattawa
    "uni0E4B": """
mdap[rnd]   7
f_deltap    31 14+8   31 15+8   31 16+8   31 17+8  31 20-8  31 21-8  31 22-8   31 31-8  
shpix       -8 7
mdrp[grey]  9
mdrp[rp0,min,grey]  6
shpix       16 6
sloop   6
ip  8 11 0 1 2 5
mdrp[grey]  4
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   10
f_deltap    10 9+8   10 10+8   10 11+8   10 12+8   10 13+8   10 14+8   10 15+8   10 16+8
f_deltap    10 9+8   10 11+8   10 12+8   10 20+8   10 21+8  10 26+8
shpix       8 10
alignrp     2
mdrp[grey]  0
mdrp[rp0,min,grey]  9
shpix       -16 9
alignrp     5
mdrp[grey]  7
IUP[y]
""",

    #maichattawa
    "uni0E4B.low": """
mdap[rnd]   7
mdrp[grey]  9
mdrp[rp0,rnd,grey]  6
sloop   6
ip  8 11 0 1 2 5
mdrp[grey]  4
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   10
f_deltap    10 9+8   10 10+8   10 11+8   10 12+8   10 13+8   10 14+8   10 16+8
alignrp     2
mdrp[grey]  0
mdrp[rp0,rnd,grey]  9
f_deltap    9 9+8  9 10+8  9 11+8  9 12+8
shpix   -8  9
alignrp     5
mdrp[grey]  7
IUP[y]
""",

    #thanthakhat
    "uni0E4C": """
mdap[rnd]   13
f_deltap    13 14+8   13 15+8   13 16+8   13 17+8  13 20-8  13 21-8  13 22-8   13 31-8  
mdrp[grey]  10
mdrp[rp0,rnd,grey]  3
mdrp[min,rnd,grey]  18
ip  30
ip  24
shpix   -8 13
shpix   -8 18
shpix   8  3
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap    0 9+8   0 10+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8
f_deltap    0 9+8   0 11+8   0 12+8   0 20+8   0 21+8  0 26+8
mdrp[rp0,rnd,grey]  6
ip  27
ip  21
mdrp[grey]  10
mdrp[grey]  16
shpix   8 0
shpix   -8 6
shpix   -8 16
IUP[y]
""",

    #thanthakhat
    "uni0E4C.low": """
mdap[rnd]   13
mdrp[grey]  10
mdrp[rp0,rnd,grey]  3
mdrp[grey]  30
mdrp[rp0,rnd,grey]  18
mdrp[grey]  24
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap    0 9+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8
mdrp[grey]  21
mdrp[rp0,rnd,grey]  6
mdrp[grey]  27
mdrp[min,rnd,grey]  10
IUP[y]
""",

    #nikhahit
    "uni0E4D": """
mdap[rnd]   9
mdrp[min,rnd,grey]  15
mdrp[rp0,rnd,grey]  3
mdrp[min,rnd,grey]  21
shpix   -4 9
shpix   4 3
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
f_deltap    0 9+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8
mdrp[min,rnd,grey]  12
mdrp[rp0,rnd,grey]  6
mdrp[min,rnd,grey]  18
shpix   4 0
shpix   -4 6
IUP[y]
""",

    #nikhahit
    "uni0E4D.high": """
mdap[rnd]   9
f_deltap    9 14+8   9 15+8   9 16+8   9 17+8  9 20-8  9 21-8  9 22-8   9 31-8  
mdrp[min,rnd,grey]  15
mdrp[rp0,rnd,grey]  3
mdrp[min,rnd,grey]  21
shpix   -4 9
shpix   4 3
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
f_deltap    0 9+8   0 10+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8
f_deltap    0 9+8   0 11+8   0 12+8   0 20+8   0 21+8  0 26+8
mdrp[min,rnd,grey]  12
mdrp[rp0,rnd,grey]  6
mdrp[min,rnd,grey]  18
shpix   4 0
shpix   -4 6
IUP[y]
""",

    #yamakkan
    "uni0E4E": """
mdap[rnd]   17
mdrp[rp0,rnd,grey]  11
sloop   4
ip  22 28 34 52
mdrp[rp0,rnd,grey]  3
mdrp[grey]  46
IUP[x]
SVTCA[y-axis]
mdap[rnd]   0
f_deltap    0 9+8   0 11+8   0 12+8   0 13+8   0 14+8   0 15+8   0 16+8
mdrp[grey]  49
mdrp[rp0,rnd,grey]  6
sloop   3
ip  43 37 9
mdrp[rp0,rnd,grey]  14
ip  9
ip  25
mdrp[min,rnd,grey]  25
IUP[y]
""",

    #fongman
    "uni0E4F": """
SRP0    52
mirp[rp0,rnd,grey]  gap_150 4
mirp[min,rnd,grey]  headstem 25
mdrp[rp0,rnd,grey]  31
mirp[min,rnd,grey]  headstem 49
#
srp0    4
mdrp[rp0,rnd,grey]  12
mirp[min,rnd,grey]  headstem 19
mdrp[rp0,rnd,grey]  37
mirp[min,rnd,grey]  headstem 43
srp0    12
mirp[rnd,grey]  gap_150 53
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   52
mirp[rp0,rnd,grey]  vheight_lo  0
mirp[min,rnd,grey]  headstem 16
mdrp[rp0,rnd,grey]  28
mirp[min,rnd,grey]  headstem 40
srp0    0
mdrp[rp0,rnd,grey]  8
mirp[min,rnd,grey]  headstem 22
mdrp[rp0,rnd,grey]  34
mirp[min,rnd,grey]  headstem 46
IUP[y]
""",

    #thaidigit_zero
    "uni0E50": """
SRP0    28
mirp[rp0,rnd,grey]  gap_125 4
mdrp[min,rnd,grey]  25
#
srp0    29
mirp[rp0,rnd,grey]  gap_125 12
mdrp[min,rnd,grey]  19
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[min,rnd,grey]  16
mdrp[rp0,rnd,grey]  8
mdrp[min,rnd,grey]  22
IUP[y]
""",

    #thaidigit_one
    "uni0E51": """
f_deltap    51 9+8   51 10+8   51 11+8   51 12+8   51 13+8   51 25+8   51 27+8
srp0    50
mirp[rp0,rnd,grey]  gap_125 3
mdrp[min,rnd,grey]  30
#
srp0    51
mirp[rp0,rnd,grey]  gap_125 9
mdrp[min,rnd,grey]  24
#
srp1    30
ip  47
mdap[rnd]   47
mdrp[min,rnd,grey]  41
ip  36
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[min,rnd,grey]  15
mdrp[min,rnd,grey]  33
mdrp[rp0,rnd,grey]  6
mdrp[min,rnd,grey]  27
srp1    33
ip  38
mdap[rnd]   38
f_deltap    38 25+8
mdrp[min,rnd,grey]  44
IUP[y]
""",

    #thaidigit_two
    "uni0E52": """
f_deltap    84 9+8   84 10+8   84 11+8   84 12+8   84 13+8
SRP0    83
mirp[rp0,rnd,grey]  gap_170 4
ip  8
mdrp[min,rnd,grey]  14
#
srp0    84
mirp[rp0,rnd,grey]  gap_125 80
mdrp[min,rnd,grey]  22
#
srp1    14
sloop   3
ip      70 58 45
mdap[rnd]   70
mdrp[min,rnd,grey]  51
mdap[rnd]   58
mdrp[min,rnd,grey]  64
mdap[rnd]   45
mdrp[min,rnd,grey]  30
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[min,rnd,grey]  19
mdrp[rp0,rnd,grey]  73
alignrp 77
mdrp[rnd,grey]  11
mdrp[min,rnd,grey]  48
shp[rp2]    25
mdrp[rp0,rnd,grey]  67
f_deltap    67 15+8   67 16+8   67 18+8   67 19+8   67 21+8   
alignrp     36
mdrp[min,rnd,grey]  61
IUP[y]
""",

    #thaidigit_three
    "uni0E53": """
f_deltap    75 9+8   75 10+8   75 11+8   75 13+8   75 14+8
SRP0    74
mirp[rp0,rnd,grey]  gap_125 3
mdrp[min,rnd,grey]  57
#
srp0    75
mirp[rp0,rnd,grey]  gap_125 13
mdrp[min,rnd,grey]  28
#
srp1    57
ip  71
ip  51
mdap[rnd]   71
f_deltap    71 10-8   71 13-8   71 14-8   71 20-8
mdrp[min,rnd,grey]  65
mdap[rnd]   51
f_deltap    51 13-8   51 14-8   51 22+8
mdrp[min,rnd,grey]  36
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
alignrp     19
alignrp     42
mdrp[min,rnd,grey]  68
mdrp[rp0,rnd,grey]  6
alignrp 10
mdrp[min,rnd,grey]  54
shp[rp2]    31
IUP[y]
""",

    #thaidigit_four
    "uni0E54": """
f_deltap    61 9+8   61 10+8   61 11+8   61 12+8   61 13+8   61 15+8   61 18+8
srp0    60
mirp[rp0,rnd,grey]  gap_125 9
mdrp[min,rnd,grey]  30
#
srp0    61
mirp[rp0,rnd,grey]  gap_102 23
mdrp[min,rnd,grey]  16
srp1    30
sloop   3
ip  38 50 57
mdap[rnd]   38
mdrp[min,rnd,grey]  54
mdap[rnd]   50
mdrp[min,rnd,grey]  44
mdap[rnd]   57
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
alignrp     6
mdrp[min,rnd,grey]  57
srp0    6
mdrp[min,rnd,grey]  33
mdrp[rp0,rnd,grey]  18
ip  27
mdap[rnd]   27
mdrp[min,rnd,grey]  12
srp2    33
ip  41
mdap[rnd]   41
mdrp[min,rnd,grey]  47
IUP[y]
""",

    #thaidigit_five
    "uni0E55": """
f_deltap    88 9+8   88 11+8   88 12+8   88 13+8   88 14+8    
srp0    84
mirp[rp0,rnd,grey]  gap_125 9
mdrp[min,rnd,grey]  43
#
srp0    85
mirp[rp0,rnd,grey]  gap_102 33
mdrp[min,rnd,grey]  26
srp1    43
sloop   4
ip  51 63 70 21
mdap[rnd]   51
mdrp[min,rnd,grey]  67
mdap[rnd]   63
mdrp[min,rnd,grey]  57
mdap[rnd]   70
mdap[rnd]   21
#f_deltap    21 10-8   21 11-8   21 12-8
mirp[min,rnd,grey]  headstem 75
mirp[rp0,rnd,grey]  headdia 15
f_deltap    15 10-8   15 11-8   15 12-8   15 15-8   15 16-8
mirp[min,rnd,grey]  headstem 81
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
alignrp     6
mdrp[min,rnd,grey]  70
srp0    6
mdrp[min,rnd,grey]  46
mdrp[rp0,rnd,grey]  28
ip  37
mdap[rnd]   37
srp2    46
ip  54
mdrp[min,rnd,grey]  72
mdrp[rp0,rnd,grey]  18
mirp[min,rnd,grey]  headstem 78
mdap[rnd]   54
mdrp[min,rnd,grey]  60
IUP[y]
""",

    #thaidigit_six
    "uni0E56": """
f_deltap    63 9+8   63 10+8   63 17+8
SRP0    62
mirp[rp0,rnd,grey]  gap_61  43
mdrp[rp0,rnd,grey]  32
mdrp[min,rnd,grey]  53
mdrp[rp0,rnd,grey]  3
mdrp[min,rnd,grey]  9
#
srp0    63
mirp[rp0,rnd,grey]  gap_125 59
mdrp[min,rnd,grey]  20
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[min,rnd,grey]  17
mdrp[rp0,rnd,grey]  56
ip  6
ip  29
mdrp[min,rnd,grey]  23
mdrp[min,rnd,grey]  48
mdap[rnd]   29
mdap[rnd]   6
f_deltap    6 14-8   6 15-8   6 16-8
mdrp[min,rnd,grey]  12
IUP[y]
""",

    #thaidigit_seven
    "uni0E57": """
f_deltap    92 9+8   92 10+8   92 11+8   92 12+8
SRP0    91
mirp[rp0,rnd,grey]  gap_125 54
mdrp[min,rnd,grey]  37
#
srp0    92
mirp[rp0,rnd,grey]  gap_125 85
mdrp[min,rnd,grey]  72
mdrp[rp0,rnd,grey]  66
f_deltap    66 20-8
mdrp[min,rnd,grey]  9
srp1    37
ip  17
ip  48
mdap[rnd]   17
mdrp[min,rnd,grey]  31
mdap[rnd]   48
mdrp[min,rnd,grey]  42
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
alignrp     51
mdrp[min,rnd,grey]  69
srp0    51
mdrp[min,rnd,grey]  40
mdrp[min,rnd,grey]  45
mdrp[rp0,rnd,grey]  57
alignrp 63
mdrp[rnd,grey]  82
mdrp[min,rnd,grey]  34
shp[rp2]    12
srp1    45
ip      23
IUP[y]
""",

    #thaidigit_eight
    "uni0E58": """
f_deltap    73 11+8   73 13+8   73 14+8
SRP0    72
mirp[rp0,rnd,grey]  gap_125 13
mdrp[min,rnd,grey]  42
mdrp[rp0,rnd,grey]  10
mdrp[min,rnd,grey]  47
#
srp0    73
mirp[rp0,rnd,grey]  gap_102 31
srp2    10
ip  69
mdrp[min,rnd,grey]  24
mdap[rnd]   69
mdrp[min,rnd,grey]  63
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]    0
alignrp 10
mdrp[min,rnd,grey]  55
mdrp[rp0,rnd,grey]  66
mdrp[min,rnd,grey]  60
srp0    10
mdrp[rp0,rnd,grey]  50
mdrp[min,rnd,grey]  5
mdrp[min,rnd,grey]  45
srp0    16
mdrp[min,rnd,grey]  39
mdrp[rnd,grey]      28
mdrp[rp0,rnd,grey]  21
mdrp[min,rnd,grey]  34
IUP[y]
""",

    #thaidigit_nine
    "uni0E59": """
f_deltap    75 9+8   75 11+8   75 12+8   75 13+8   75 16+8
SRP0    74
mirp[rp0,rnd,grey]  gap_125 3
mdrp[min,rnd,grey]  54
mdrp[rp0,rnd,grey]  9
mdrp[min,rnd,grey]  38
#
srp0    75
mirp[rp0,rnd,grey]  gap_102 27
mdrp[min,rnd,grey]  20
srp2    54
ip  43
ip  71
mdap[rnd]   43
mdap[rnd]   71
mdrp[min,rnd,grey]  65
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[min,rnd,grey]  57
mdrp[rp0,rnd,grey]  12
mdrp[rnd,grey]  24
mdrp[min,rnd,grey]  35
srp1    57
ip  41
ip  43
mdap[rnd]   41
mdrp[min,rnd,grey]  47
srp1    57
ip      68
mdap[rnd]   68
f_deltap    68 12-8   68 13-8
mdrp[min,rnd,grey]  62
IUP[y]
""",

#    #angkhankhu
    "uni0E5A": """
f_deltap    49 9+8   49 10+8   49 11+8   49 12+8   49 13+8
SRP0    48
mirp[rp0,rnd,grey]  gap_102 21
mdrp[min,rnd,grey]  32
#
srp0    49
mirp[rp0,rnd,grey]  gap_170 47
mirp[min,rnd,grey]  hstem 1
mdrp[rp0,rnd,grey]  43
alignrp 6
mirp[min,rnd,grey]  hstem 8
srp1 32
sloop   3
ip  26 27 39
mdap[rnd]   39
mdrp[min,rnd,grey]  14
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
alignrp     8
mdrp[rp0,rnd,grey]  46
alignrp     42
mdrp[min,rnd,grey]  4
shp[rp2]    11
mdrp[rp0,rnd,grey]  24
mdrp[min,rnd,grey]  29
mdrp[rp0,rnd,grey]  18
mdrp[min,rnd,grey]  35
IUP[y]
""",

#    #khomut
    "uni0E5B": """
SRP0    70
mirp[rp0,min,rnd,grey]  headhole    3
mirp[rp0,min,rnd,grey]  hstem   26
mdrp[rp0,min,rnd,grey]  15
mirp[min,rnd,grey]  headstem   67
mdrp[rp0,min,rnd,grey]  9
mdrp[min,rnd,grey]  61
mdrp[min,rnd,grey]  20
mdrp[rp0,min,rnd,grey]  32
mdrp[min,rnd,grey]  33
mdrp[rp0,min,rnd,grey]  55
mdrp[min,rnd,grey]  54
mdrp[rp0,min,rnd,grey]  34
mdrp[rp0,min,rnd,grey]  37
mdrp[min,rnd,grey]  38
mdrp[rp0,min,rnd,grey]  52
mdrp[min,rnd,grey]  51
mdrp[rp0,min,rnd,grey]  39
mdrp[rp0,min,rnd,grey]  42
mdrp[min,rnd,grey]  43
mdrp[rp0,min,rnd,grey]  49
mdrp[rp0,min,rnd,grey]  46
mdrp[min,rnd,grey]  71
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   70
mirp[rp0,rnd,grey]  vheight_lo  0
mirp[rp0,min,rnd,grey]  vstem_98 29
mdrp[rp0,min,rnd,grey]  12
mirp[min,rnd,grey]  headstem 58
mirp[rp0,rnd,grey]  headdia 18
mdrp[min,rnd,grey]  20
mirp[min,rnd,grey]  headstem 64
mdrp[rp0,min,rnd,grey]  23
mirp[min,rnd,grey]  vstem_98 6
srp0    0
mdrp[rp0,min,rnd,grey]  55
alignrp     52
alignrp     49
alignrp     45
mdrp[min,rnd,grey]  54
shp[rp2]    51
mdrp[rp0,min,rnd,grey]  32
alignrp 37
alignrp 42
mdrp[rp0,min,rnd,grey]  33
alignrp 38
alignrp 43
srp0    45
mdrp[min,rnd,grey]  46
IUP[y]
""",


#    #CHAR_NAME
#    "uni0EXX": """
#SRP0    0
#
#IUP[x]
#SVTCA[y-axis]
#MDAP[rnd]   0
#
#IUP[y]
#""",


}

if __name__=="__main__":
    if sys.argv[1] == "--all":
        #$0 --all = ENCODE ALL CHARS
        sfd_file = os.path.basename(sys.argv[0]).split('.',1)[0] + '.sfd'
        print "Encoding all character in %s" % (sfd_file)
        dfont.inst_encode_all( sfd_file, pseudo_code_dict, cvt_dict )
    else:
        #$0 uni0E01 > x.txt = PRINT INSTRUCTION CODE OF uni0E01 TO x.txt
        print '\n'.join(dfont.inst_encode( pseudo_code_dict[sys.argv[1]], cvt_dict ))
